# coding: utf8
from __future__ import unicode_literals


NOUNS_IRREG = {
    "aa": ("aa",),
    "abatis": ("abatis",),
    "abattis": ("abattis",),
    "abax": ("abax",),
    "abcès": ("abcès",),
    "abc": ("abc",),
    "abducens": ("abducens",),
    "abies": ("abies",),
    "aboteaux": ("aboteau",),
    "abrasax": ("abrasax",),
    "abras": ("abras",),
    "abraxas": ("abraxas",),
    "abribus": ("abribus",),
    "abris-bus": ("abri-bus",),
    "abricotis": ("abricotis",),
    "abris-jardins": ("abri-jardin",),
    "abrus": ("abrus",),
    "abruzzaises": ("abruzzais",),
    "abruzzais": ("abruzzais",),
    "abus": ("abus",),
    "abusseaux": ("abusseau",),
    "abusus": ("abusus",),
    "acalles": ("acalles",),
    "acanthocéras": ("acanthocéras",),
    "acanthopanax": ("acanthopanax",),
    "acanthostaurus": ("acanthostaurus",),
    "acarus": ("acarus",),
    "acathexis": ("acathexis",),
    "accès": ("accès",),
    "accipiens": ("accipiens",),
    "accords-cadres": ("accord-cadre",),
    "acéras": ("acéras",),
    "acilius": ("acilius",),
    "acini": ("acinus",),
    "acorus": ("acorus",),
    "acquereaux": ("acquereau",),
    "acquis": ("acquis",),
    "acridinium": ("acridinium",),
    "acris": ("acris",),
    "actias": ("actias",),
    "actinelia": ("actinelium",),
    "actinobacillus": ("actinobacillus",),
    "actinocéras": ("actinocéras",),
    "actinophrys": ("actinophrys",),
    "acylium": ("acylium",),
    "adapis": ("adapis",),
    "addax": ("addax",),
    "addenda": ("addenda",),
    "adénovirus": ("adénovirus",),
    "adieux": ("adieu",),
    "adil": ("adil",),
    "adjudantes-chefs": ("adjudant-chef",),
    "adler": ("adler",),
    "admises": ("admis",),
    "admis": ("admis",),
    "adn": ("adn",),
    "adonis": ("adonis",),
    "adoratio": ("adoratio",),
    "ados": ("ados",),
    "adoxus": ("adoxus",),
    "aegocéras": ("aegocéras",),
    "aeolis": ("aeolis",),
    "aepus": ("aepus",),
    "aepyornis": ("aepyornis",),
    "aérobus": ("aérobus",),
    "aéromonas": ("aéromonas",),
    "afflux": ("afflux",),
    "affreuses": ("affreux",),
    "affreux": ("affreux",),
    "affûts-trucks": ("affût-truck",),
    "afrikans": ("afrikans",),
    "agathaumas": ("agathaumas",),
    "agenaises": ("agenais",),
    "agenais": ("agenais",),
    "ageniaspis": ("ageniaspis",),
    "agiaux": ("agiau",),
    "agneaux": ("agneau",),
    "agnelles": ("agneau",),
    "agnostus": ("agnostus",),
    "agnus": ("agnus",),
    "agrès": ("agrès",),
    "agriolimax": ("agriolimax",),
    "agrostis": ("agrostis",),
    "agrotis": ("agrotis",),
    "aideaux": ("aideau",),
    "aides-comptables": ("aide-comptable",),
    "aides-cuisiniers": ("aide-cuisinier",),
    "aides-jardiniers": ("aide-jardinier",),
    "aides-maçons": ("aide-maçon",),
    "aides monitrices": ("aide-moniteur",),
    "aides soignantes": ("aide-soignant",),
    "aides-soignantes": ("aide-soignant",),
    "aigues-marines": ("aigue-marine",),
    "aïkido": ("aïkido",),
    "aînées": ("aînés",),
    "aînés": ("aînés",),
    "airbus": ("airbus",),
    "ais": ("ais",),
    "aisseaux": ("aisseau",),
    "aisy": ("aisy",),
    "aixoises": ("aixois",),
    "aixois": ("aixois",),
    "ajusteuses-mécaniciennes": ("ajusteur-mécanicien",),
    "akritas": ("akritas",),
    "alaüs": ("alaüs",),
    "albanaises": ("albanais",),
    "albanais": ("albanais",),
    "albatros": ("albatros",),
    "albigeoises": ("albigeois",),
    "albigeois": ("albigeois",),
    "albinos": ("albinos",),
    "albums-photos": ("album-photos",),
    "albus": ("albus",),
    "alcalinoterreux": ("alcalinoterreux",),
    "alcarazas": ("alcarazas",),
    "aldermen": ("alderman",),
    "aleph": ("aleph",),
    "aléseuses-fraiseuses": ("aléseuse-fraiseuse",),
    "alestes": ("alestes",),
    "alexandrov": ("alexandrov",),
    "alexei": ("alexei",),
    "algéroises": ("algérois",),
    "algérois": ("algérois",),
    "alios": ("alios",),
    "alkermès": ("alkermès",),
    "allers-retours": ("aller-retour",),
    "alleux": ("alleu",),
    "allocations maternité": ("allocation-maternité",),
    "allocations-maternité": ("allocation-maternité",),
    "alloptes": ("alloptes",),
    "alnico": ("alnico",),
    "aloès": ("aloès",),
    "aloyaux": ("aloyau",),
    "alpax": ("alpax",),
    "alpha": ("alpha",),
    "alpheus": ("alpheus",),
    "alquifoux": ("alquifoux",),
    "altocumulus": ("altocumulus",),
    "altostratus": ("altostratus",),
    "altuglas": ("altuglas",),
    "alveus": ("alveus",),
    "amadis": ("amadis",),
    "amaltheus": ("amaltheus",),
    "amaryllis": ("amaryllis",),
    "amas": ("amas",),
    "amaurobius": ("amaurobius",),
    "amban": ("amban",),
    "ambiéquales": ("ambiéqual",),
    "ambiéquaux": ("ambiéqual",),
    "ambitieuses": ("ambitieux",),
    "ambitieux": ("ambitieux",),
    "ambix": ("ambix",),
    "amblyopsis": ("amblyopsis",),
    "amblyornis": ("amblyornis",),
    "amen": ("amen",),
    "american": ("american",),
    "amiantes-ciment": ("amiante-ciment",),
    "amirales": ("amiral",),
    "amiraux": ("amiral",),
    "amnios": ("amnios",),
    "amorphophallus": ("amorphophallus",),
    "amoureuses": ("amoureux",),
    "amoureux": ("amoureux",),
    "ampélopsis": ("ampélopsis",),
    "ampères-heures": ("ampère-heure",),
    "ampères-tours": ("ampère-tour",),
    "amphidasis": ("amphidasis",),
    "amphioxus": ("amphioxus",),
    "amphipnous": ("amphipnous",),
    "ampulex": ("ampulex",),
    "anabas": ("anabas",),
    "anableps": ("anableps",),
    "anagallis": ("anagallis",),
    "anagyris": ("anagyris",),
    "analges": ("analges",),
    "analystes-programmeurs": ("analyste-programmeur",),
    "anampsès": ("anampsès",),
    "a": ("a",),
    "ana": ("ana",),
    "ananas": ("ananas",),
    "ananchytes": ("ananchytes",),
    "anaspis": ("anaspis",),
    "anax": ("anax",),
    "anchois": ("anchois",),
    "ancres-chaînes": ("ancre-chaîne",),
    "ancylocéras": ("ancylocéras",),
    "ancylus": ("ancylus",),
    "androctonus": ("androctonus",),
    "androsphinx": ("androsphinx",),
    "anesthésistes-réanimateurs": ("anesthésiste-réanimateur",),
    "angélus": ("angélus",),
    "angineuses": ("angineux",),
    "angineux": ("angineux",),
    "angiomateuses": ("angiomateux",),
    "angiomateux": ("angiomateux",),
    "anglaises": ("anglais",),
    "anglais": ("anglais",),
    "angolaises": ("angolais",),
    "angolais": ("angolais",),
    "angrois": ("angrois",),
    "animaux": ("animal",),
    "anis": ("anis",),
    "anisoptéryx": ("anisoptéryx",),
    "anneaux": ("anneau",),
    "années-lumière": ("année-lumière",),
    "anoectochilus": ("anoectochilus",),
    "anolis": ("anolis",),
    "anormales": ("anormal",),
    "anormaux": ("anormal",),
    "antapex": ("antapex",),
    "antaxius": ("antaxius",),
    "antebois": ("antebois",),
    "antéros": ("antéros",),
    "anthécéros": ("anthécéros",),
    "anthélix": ("anthélix",),
    "anthémis": ("anthémis",),
    "anthocéros": ("anthocéros",),
    "anthocharis": ("anthocharis",),
    "anthocoris": ("anthocoris",),
    "anthraciteux": ("anthraciteux",),
    "anthrax": ("anthrax",),
    "anthyllis": ("anthyllis",),
    "antiangineux": ("antiangineux",),
    "antiangoreux": ("antiangoreux",),
    "antiaris": ("antiaris",),
    "antibois": ("antibois",),
    "antibourgeoises": ("antibourgeois",),
    "antibourgeois": ("antibourgeois",),
    "anticancéreux": ("anticancéreux",),
    "anticléricales": ("anticlérical",),
    "anticléricaux": ("anticlérical",),
    "anticlimax": ("anticlimax",),
    "anticlinaux": ("anticlinal",),
    "anticorps": ("anticorps",),
    "anticytomégalovirus": ("anticytomégalovirus",),
    "antidosis": ("antidosis",),
    "antifrançaises": ("antifrançais",),
    "antifrançais": ("antifrançais",),
    "antihélix": ("antihélix",),
    "antihéros": ("antihéros",),
    "antijeux": ("antijeu",),
    "antillaises": ("antillais",),
    "antillais": ("antillais",),
    "antimoniaux": ("antimonial",),
    "antinoyaux": ("antinoyau",),
    "antiprurigineux": ("antiprurigineux",),
    "antiscabieux": ("antiscabieux",),
    "antisudoraux": ("antisudoral",),
    "antitragus": ("antitragus",),
    "antituberculeux": ("antituberculeux",),
    "antiulcéreux": ("antiulcéreux",),
    "antiviraux": ("antiviral",),
    "anus": ("anus",),
    "anversoises": ("anversois",),
    "anversois": ("anversois",),
    "anxieuses": ("anxieux",),
    "anxieux": ("anxieux",),
    "apanteles": ("apanteles",),
    "apax": ("apax",),
    "apex": ("apex",),
    "aphidius": ("aphidius",),
    "aphis": ("aphis",),
    "aphodius": ("aphodius",),
    "aphritis": ("aphritis",),
    "api": ("api",),
    "apiocrinus": ("apiocrinus",),
    "apis": ("apis",),
    "aporrhais": ("aporrhais",),
    "appeaux": ("appeau",),
    "appentis": ("appentis",),
    "apprentis-maçons": ("apprenti-maçon",),
    "appuis-livres": ("appui-livres",),
    "aptéryx": ("aptéryx",),
    "apus": ("apus",),
    "aquereaux": ("aquereau",),
    "arabis": ("arabis",),
    "aragonaises": ("aragonais",),
    "aragonais": ("aragonais",),
    "arbitres rapporteurs": ("arbitre-rapporteur",),
    "arbovirus": ("arbovirus",),
    "arbres-manivelles": ("arbre-manivelle",),
    "arbrisseaux": ("arbrisseau",),
    "arcs-boutants": ("arc-boutant",),
    "arceaux": ("arceau",),
    "arcs-en-ciel": ("arc-en-ciel",),
    "arcestes": ("arcestes",),
    "arcs formerets": ("arc-formeret",),
    "archais": ("archais",),
    "archéocortex": ("archéocortex",),
    "archéoptéris": ("archéoptéris",),
    "archéoptéryx": ("archéoptéryx",),
    "archicortex": ("archicortex",),
    "architectes-conseils": ("architecte-conseil",),
    "architectes urbanistes": ("architecte-urbaniste",),
    "architeuthis": ("architeuthis",),
    "archontophoenix": ("archontophoenix",),
    "arcs-ogives": ("arc-ogive",),
    "arctostaphylos": ("arctostaphylos",),
    "ardéchoises": ("ardéchois",),
    "ardéchois": ("ardéchois",),
    "ardennaises": ("ardennais",),
    "ardennais": ("ardennais",),
    "arénavirus": ("arénavirus",),
    "argas": ("argas",),
    "argulus": ("argulus",),
    "argus": ("argus",),
    "ariégeoises": ("ariégeois",),
    "ariégeois": ("ariégeois",),
    "ariel": ("ariel",),
    "aristeus": ("aristeus",),
    "armoires-penderies": ("armoire-penderie",),
    "armoriaux": ("armorial",),
    "arnm": ("arnm",),
    "arn": ("arn",),
    "arnr": ("arnr",),
    "arns": ("arns",),
    "arnt": ("arnt",),
    "arrachis": ("arrachis",),
    "arrière-cerveaux": ("arrière-cerveau",),
    "arrière-grands-mères": ("arrière-grand-mère",),
    "arrière-grands-pères": ("arrière-grand-père",),
    "arrière-neveux": ("arrière-neveu",),
    "arrière-petits-enfants": ("arrière-petit-enfant",),
    "arrière-petites-nièces": ("arrière-petite-nièce",),
    "arrière-petits-fils": ("arrière-petit-fils",),
    "arrière-petits-neveux": ("arrière-petit-neveu",),
    "arrière-vassaux": ("arrière-vassal",),
    "arsenaux": ("arsenal",),
    "arsenicaux": ("arsenical",),
    "ars": ("ars",),
    "artérioscléreuses": ("artérioscléreux",),
    "artérioscléreux": ("artérioscléreux",),
    "artistes-peintres": ("artiste-peintre",),
    "artocarpus": ("artocarpus",),
    "ascaris": ("ascaris",),
    "asclépias": ("asclépias",),
    "as": ("as",),
    "asociales": ("asocial",),
    "asociaux": ("asocial",),
    "asparagus": ("asparagus",),
    "aspergès": ("aspergès",),
    "aspergillus": ("aspergillus",),
    "aspidiotus": ("aspidiotus",),
    "aspirantes-pilotes": ("aspirant-pilote",),
    "aspirants-pilotes": ("aspirant-pilote",),
    "assamaises": ("assamais",),
    "assamais": ("assamais",),
    "asseaux": ("asseau",),
    "associés gérants": ("associé-gérant",),
    "associés-gérants": ("associé-gérant",),
    "assurances-auto": ("assurance-auto",),
    "assurances-décès": ("assurance-décès",),
    "assurances-vie": ("assurance-vie",),
    "astérixis": ("astérixis",),
    "astor": ("astor",),
    "astra": ("astra",),
    "astucieuses": ("astucieux",),
    "astucieux": ("astucieux",),
    "ateuchus": ("ateuchus",),
    "athérix": ("athérix",),
    "athéromateuses": ("athéromateux",),
    "athéromateux": ("athéromateux",),
    "athéroscléreuses": ("athéroscléreux",),
    "athéroscléreux": ("athéroscléreux",),
    "athous": ("athous",),
    "atlas": ("atlas",),
    "atomes-grammes": ("atome-gramme",),
    "atomic": ("atomic",),
    "atrax": ("atrax",),
    "atriaux": ("atriau",),
    "atropos": ("atropos",),
    "attachés-cases": ("attaché-case",),
    "attacus": ("attacus",),
    "attaques surprises": ("attaque-surprise",),
    "attaques-surprises": ("attaque-surprise",),
    "atypus": ("atypus",),
    "auboises": ("aubois",),
    "aubois": ("aubois",),
    "audacieuses": ("audacieux",),
    "audacieux": ("audacieux",),
    "audoises": ("audois",),
    "audois": ("audois",),
    "audomaroises": ("audomarois",),
    "audomarois": ("audomarois",),
    "aulax": ("aulax",),
    "aurochs": ("aurochs",),
    "auteurs-compositeurs": ("auteur-compositeur",),
    "auteurs-interprètes": ("auteur-interprète",),
    "autoanticorps": ("autoanticorps",),
    "autobus": ("autobus",),
    "autocross": ("autocross",),
    "autofocus": ("autofocus",),
    "autos tamponneuses": ("auto-tamponneuse",),
    "autos-tamponneuses": ("auto-tamponneuse",),
    "avantageuses": ("avantageux",),
    "avantageux": ("avantageux",),
    "avant-pieux": ("avant-pieu",),
    "avaricieuses": ("avaricieux",),
    "avaricieux": ("avaricieux",),
    "ave": ("ave",),
    "avé": ("avé",),
    "avers": ("avers",),
    "aveux": ("aveu",),
    "aveyronnaises": ("aveyronnais",),
    "aveyronnais": ("aveyronnais",),
    "avions-canons": ("avion-canon",),
    "avions-cargos": ("avion-cargo",),
    "avions-citernes": ("avion-citerne",),
    "avions-éclaireurs": ("avion-éclaireur",),
    "avions-espions": ("avion-espion",),
    "avions-météos": ("avion-météo",),
    "avions-radars": ("avion-radar",),
    "avions-stops": ("avion-stop",),
    "avions-taxis": ("avion-taxi",),
    "avis": ("avis",),
    "avisos escorteurs": ("aviso-escorteur",),
    "avocats-conseils": ("avocat-conseil",),
    "avoirdupoids": ("avoirdupoids",),
    "avos": ("avos",),
    "axis": ("axis",),
    "ay": ("ay",),
    "ayous": ("ayous",),
    "azerbaïdjanaises": ("azerbaïdjanais",),
    "azerbaïdjanais": ("azerbaïdjanais",),
    "azerty": ("azerty",),
    "azygos": ("azygos",),
    "babas-cool": ("baba-cool",),
    "bâbordais": ("bâbordais",),
    "babies": ("baby",),
    "bacillus": ("bacillus",),
    "baculovirus": ("baculovirus",),
    "badoises": ("badois",),
    "badois": ("badois",),
    "baëtis": ("baëtis",),
    "bafouillis": ("bafouillis",),
    "bagadais": ("bagadais",),
    "bagues-agrafes": ("bague-agrafe",),
    "baguettes-leviers": ("baguette-levier",),
    "baux": ("bau",),
    "bains-douches": ("bain-douche",),
    "balaeniceps": ("balaeniceps",),
    "balais-éponges": ("balai-éponge",),
    "balanciers-spiraux": ("balancier-spiral",),
    "balcons-terrasses": ("balcon-terrasse",),
    "baleineaux": ("baleineau",),
    "balès": ("balès",),
    "balèzes": ("balès",),
    "balinaises": ("balinais",),
    "balinais": ("balinais",),
    "baliveaux": ("baliveau",),
    "ballus": ("ballus",),
    "balmoraux": ("balmoral",),
    "bâloises": ("bâlois",),
    "bâlois": ("bâlois",),
    "bancs-balances": ("banc-balance",),
    "banco": ("banco",),
    "bancs-titres": ("banc-titre",),
    "bandes-amorces": ("bande-amorce",),
    "bandes-annonces": ("bande-annonce",),
    "bandeaux": ("bandeau",),
    "bandes-culottes": ("bande-culotte",),
    "bandes-étalons": ("bande-étalon",),
    "bandes-son": ("bande-son",),
    "bangadais": ("bangadais",),
    "bangalaises": ("bangalais",),
    "bangalais": ("bangalais",),
    "bangladaises": ("bangladais",),
    "bangladais": ("bangladais",),
    "bankers": ("bankers",),
    "banlieues-dortoirs": ("banlieue-dortoir",),
    "banquettes-coffres": ("banquette-coffre",),
    "banyuls": ("banyuls",),
    "barattes-malaxeurs": ("baratte-malaxeur",),
    "barbeaux": ("barbeau",),
    "barbes-de-capucin": ("barbe-de-capucin",),
    "barbes-de-jupiter": ("barbe-de-jupiter",),
    "barbouillis": ("barbouillis",),
    "barcelonaises": ("barcelonais",),
    "barcelonais": ("barcelonais",),
    "barclay": ("barclay",),
    "bardeaux": ("bardeau",),
    "bardis": ("bardis",),
    "baribaux": ("baribal",),
    "baris": ("baris",),
    "barmen": ("barman",),
    "bars-mode": ("bar-mode",),
    "baroqueuses": ("baroqueux",),
    "baroqueux": ("baroqueux",),
    "barrages-coupoles": ("barrage-coupole",),
    "barrages-réservoirs": ("barrage-réservoir",),
    "barreaux": ("barreau",),
    "bars-tabacs": ("bar-tabac",),
    "basileus": ("basileus",),
    "basket-balleuses": ("basket-balleur",),
    "bas": ("bas",),
    "bassaris": ("bassaris",),
    "basses-cours": ("basse-cour",),
    "basses-tailles": ("basse-taille",),
    "bass": ("bass",),
    "bastiaises": ("bastiais",),
    "bastiais": ("bastiais",),
    "bastos": ("bastos",),
    "bataillons-écoles": ("bataillon-école",),
    "batardeaux": ("batardeau",),
    "bâtardeaux": ("bâtardeau",),
    "batch": ("batch",),
    "bateaux-boeuf": ("bateau-boeuf",),
    "bateaux-citernes": ("bateau-citerne",),
    "bateaux-écoles": ("bateau-école",),
    "bateaux-espions": ("bateau-espion",),
    "bateaux-feux": ("bateau-feu",),
    "bateaux-lavoirs": ("bateau-lavoir",),
    "bateaux-mouches": ("bateau-mouche",),
    "bateaux": ("bateau",),
    "bateaux-phares": ("bateau-phare",),
    "bateaux-pièges": ("bateau-piège",),
    "bateaux-pompes": ("bateau-pompe",),
    "bateaux-remorqueurs": ("bateau-remorqueur",),
    "bateaux-usines": ("bateau-usine",),
    "bathycrinus": ("bathycrinus",),
    "bathyptéroïs": ("bathyptéroïs",),
    "bathysynactites": ("bathysynactites",),
    "bâtonnets-registres": ("bâtonnet-registre",),
    "batrisus": ("batrisus",),
    "batteurs-mélangeurs": ("batteur-mélangeur",),
    "bavaroises": ("bavarois",),
    "bavarois": ("bavarois",),
    "béarnaises": ("béarnais",),
    "béarnais": ("béarnais",),
    "beaux-fils": ("beau-fils",),
    "beaux-frères": ("beau-frère",),
    "beaujolais": ("beaujolais",),
    "beaux-pères": ("beau-père",),
    "bébés-cadum": ("bébé-cadum",),
    "bécasseaux": ("bécasseau",),
    "bécasseaux-sanderlings": ("bécasseau-sanderling",),
    "becs-croisés": ("bec-croisé",),
    "becs d'âne": ("bec-d'âne",),
    "becs-de-grue": ("bec-de-grue",),
    "becs-de-perroquet": ("bec-de-perroquet",),
    "becs-en-sabot": ("bec-en-sabot",),
    "bêches-de-mer": ("bêche-de-mer",),
    "becs-noueurs": ("bec-noueur",),
    "bedeaux": ("bedeau",),
    "belargus": ("belargus",),
    "belgoluxembourgeoises": ("belgoluxembourgeois",),
    "belgoluxembourgeois": ("belgoluxembourgeois",),
    "belgradoises": ("belgradois",),
    "belgradois": ("belgradois",),
    "belinurus": ("belinurus",),
    "belles-dames": ("belle-dame",),
    "belles-de-nuit": ("belle-de-nuit",),
    "belles-mères": ("belle-mère",),
    "bellicositermes": ("bellicositermes",),
    "belliqueuses": ("belliqueux",),
    "belliqueux": ("belliqueux",),
    "belmont": ("belmont",),
    "bembex": ("bembex",),
    "benedicite": ("benedicite",),
    "bengalaises": ("bengalais",),
    "bengalais": ("bengalais",),
    "béninoises": ("béninois",),
    "béninois": ("béninois",),
    "bennes-dragues": ("benne-drague",),
    "benthos": ("benthos",),
    "bentley": ("bentley",),
    "berceaux": ("berceau",),
    "béris": ("béris",),
    "berkeley": ("berkeley",),
    "berlinoises": ("berlinois",),
    "berlinois": ("berlinois",),
    "bernard": ("bernard",),
    "bernoises": ("bernois",),
    "bernois": ("bernois",),
    "bers": ("bers",),
    "berus": ("berus",),
    "besogneuses": ("besogneux",),
    "besogneux": ("besogneux",),
    "bestiaux": ("bestiau",),
    "biafraises": ("biafrais",),
    "biafrais": ("biafrais",),
    "biais": ("biais",),
    "bibliobus": ("bibliobus",),
    "bibus": ("bibus",),
    "biceps": ("biceps",),
    "biches-de-mer": ("biche-de-mer",),
    "bic": ("bic",),
    "bidentaux": ("bidental",),
    "bidi": ("bidi",),
    "biens-fonds": ("bien-fonds",),
    "bienheureuses": ("bienheureux",),
    "bienheureux": ("bienheureux",),
    "bifidus": ("bifidus",),
    "bifrons": ("bifrons",),
    "bigarreaux": ("bigarreau",),
    "bigleuses": ("bigleux",),
    "bigleux": ("bigleux",),
    "bigorneaux": ("bigorneau",),
    "bihoreaux": ("bihoreau",),
    "bijoux": ("bijou",),
    "bilieuses": ("bilieux",),
    "bilieux": ("bilieux",),
    "bimétaux": ("bimétal",),
    "bintje": ("bintje",),
    "biogaz": ("biogaz",),
    "biomatériaux": ("biomatériau",),
    "biseaux": ("biseau",),
    "bis": ("bis",),
    "biterroises": ("biterrois",),
    "biterrois": ("biterrois",),
    "bitis": ("bitis",),
    "bitoniaux": ("bitoniau",),
    "bittacus": ("bittacus",),
    "biveaux": ("biveau",),
    "bizness": ("bizness",),
    "blablabla": ("blablabla",),
    "blabla": ("blabla",),
    "blaireaux": ("blaireau",),
    "blaisoises": ("blaisois",),
    "blaisois": ("blaisois",),
    "blancs-becs": ("blanc-bec",),
    "blancs-seings": ("blanc-seing",),
    "blaps": ("blaps",),
    "bledius": ("bledius",),
    "blepsias": ("blepsias",),
    "blésoises": ("blésois",),
    "blésois": ("blésois",),
    "blissus": ("blissus",),
    "blitz": ("blitz",),
    "blocs-correspondances": ("bloc-correspondance",),
    "blocs-diagrammes": ("bloc-diagramme",),
    "blocs-éviers": ("bloc-évier",),
    "blockhaus": ("blockhaus",),
    "blocs-moteurs": ("bloc-moteur",),
    "blocus": ("blocus",),
    "blongios": ("blongios",),
    "bluesmen": ("bluesman",),
    "blues": ("blues",),
    "b": ("b",),
    "bobineaux": ("bobineau",),
    "bocaux": ("bocal",),
    "bodhisattva": ("bodhisattva",),
    "bodies": ("body",),
    "bois": ("bois",),
    "boisseaux": ("boisseau",),
    "boiteuses": ("boiteux",),
    "boiteux": ("boiteux",),
    "bolonaises": ("bolonais",),
    "bolonais": ("bolonais",),
    "bolton": ("bolton",),
    "bombyx": ("bombyx",),
    "bons-becs": ("bon-bec",),
    "bonshommes": ("bonhomme",),
    "bonneteaux": ("bonneteau",),
    "bonnezeaux": ("bonnezeau",),
    "bons-primes": ("bon-prime",),
    "bonus": ("bonus",),
    "boqueteaux": ("boqueteau",),
    "borassus": ("borassus",),
    "borax": ("borax",),
    "borborus": ("borborus",),
    "bordeaux": ("bordeaux",),
    "bordelaises": ("bordelais",),
    "bordelais": ("bordelais",),
    "bordereaux": ("bordereau",),
    "borg": ("borg",),
    "bossas-novas": ("bossa-nova",),
    "bossemen": ("bosseman",),
    "bossis": ("bossis",),
    "boss": ("boss",),
    "bothriolepis": ("bothriolepis",),
    "bothrops": ("bothrops",),
    "botrytis": ("botrytis",),
    "boucaux": ("boucau",),
    "bouchons allumeurs": ("bouchon-allumeur",),
    "bouchons-allumeurs": ("bouchon-allumeur",),
    "bouées-culottes": ("bouée-culotte",),
    "boueuses": ("boueux",),
    "boueux": ("boueux",),
    "bouis-bouis": ("boui-boui",),
    "bouleaux": ("bouleau",),
    "boulê": ("boulê",),
    "bouleux": ("bouleux",),
    "boulonnaises": ("boulonnais",),
    "boulonnais": ("boulonnais",),
    "bourbonnaises": ("bourbonnais",),
    "bourbonnais": ("bourbonnais",),
    "bourgeoises": ("bourgeois",),
    "bourgeois": ("bourgeois",),
    "bourgueticrinus": ("bourgueticrinus",),
    "bourras": ("bourras",),
    "bourreaux": ("bourreau",),
    "bouseuses": ("bouseux",),
    "bouseux": ("bouseux",),
    "bouts-dehors": ("bout-dehors",),
    "boutefeux": ("boutefeu",),
    "bouts-filtres": ("bout-filtre",),
    "boxes": ("box",),
    "boyaux": ("boyau",),
    "bracelets-montres": ("bracelet-montre",),
    "brachyanticlinaux": ("brachyanticlinal",),
    "brachycerus": ("brachycerus",),
    "brachyderes": ("brachyderes",),
    "brachymyrmex": ("brachymyrmex",),
    "brachysynclinaux": ("brachysynclinal",),
    "brandebourgeoises": ("brandebourgeois",),
    "brandebourgeois": ("brandebourgeois",),
    "brandies": ("brandy",),
    "brangus": ("brangus",),
    "bras": ("bras",),
    "brassolis": ("brassolis",),
    "brebis": ("brebis",),
    "brechites": ("brechites",),
    "bredouillis": ("bredouillis",),
    "breitschwanz": ("breitschwanz",),
    "brêmoises": ("brêmois",),
    "brêmois": ("brêmois",),
    "brestoises": ("brestois",),
    "brestois": ("brestois",),
    "breu": ("breu",),
    "bréviceps": ("bréviceps",),
    "brise-tourteaux": ("brise-tourteau",),
    "brisis": ("brisis",),
    "bris": ("bris",),
    "brissus": ("brissus",),
    "broadway": ("broadway",),
    "bronchiteuses": ("bronchiteux",),
    "bronchiteux": ("bronchiteux",),
    "bronteus": ("bronteus",),
    "brooklyn": ("brooklyn",),
    "brouillis": ("brouillis",),
    "brugeoises": ("brugeois",),
    "brugeois": ("brugeois",),
    "brûlis": ("brûlis",),
    "brutales": ("brutal",),
    "brutaux": ("brutal",),
    "bruxelloises": ("bruxellois",),
    "bruxellois": ("bruxellois",),
    "bubalornis": ("bubalornis",),
    "bubas": ("bubas",),
    "buis": ("buis",),
    "buliminus": ("buliminus",),
    "bulimulus": ("bulimulus",),
    "bulimus": ("bulimus",),
    "buna": ("buna",),
    "bunraku": ("bunraku",),
    "bunsen": ("bunsen",),
    "bureaux": ("bureau",),
    "burgaux": ("burgau",),
    "burnous": ("burnous",),
    "burundaises": ("burundais",),
    "burundais": ("burundais",),
    "bushido": ("bushido",),
    "bushmen": ("bushman",),
    "bushes": ("bush",),
    "businessmen": ("businessman",),
    "business": ("business",),
    "businesswomen": ("businesswoman",),
    "bus": ("bus",),
    "butagaz": ("butagaz",),
    "buthus": ("buthus",),
    "byctiscus": ("byctiscus",),
    "byssus": ("byssus",),
    "cabas": ("cabas",),
    "câbleaux": ("câbleau",),
    "cabus": ("cabus",),
    "cacatoès": ("cacatoès",),
    "cacatois": ("cacatois",),
    "cacops": ("cacops",),
    "cactus": ("cactus",),
    "cadeaux": ("cadeau",),
    "cadenas": ("cadenas",),
    "caecilius": ("caecilius",),
    "caennaises": ("caennais",),
    "caennais": ("caennais",),
    "cafés-concerts": ("café-concert",),
    "cafés-hôtels": ("café-hôtel",),
    "cafés-restaurants": ("café-restaurant",),
    "cafougneuses": ("cafougneux",),
    "cafougneux": ("cafougneux",),
    "cafouilleuses": ("cafouilleux",),
    "cafouilleux": ("cafouilleux",),
    "cafouillis": ("cafouillis",),
    "cagneuses": ("cagneux",),
    "cagneux": ("cagneux",),
    "caïeux": ("caïeu",),
    "caillebotis": ("caillebotis",),
    "cailleteaux": ("cailleteau",),
    "cailloux": ("caillou",),
    "cailloutis": ("cailloutis",),
    "caissiers-comptables": ("caissier-comptable",),
    "calabraises": ("calabrais",),
    "calabrais": ("calabrais",),
    "calamobius": ("calamobius",),
    "calamoichthys": ("calamoichthys",),
    "calanus": ("calanus",),
    "calathus": ("calathus",),
    "calcanéus": ("calcanéus",),
    "calcaroni": ("calcarone",),
    "calendos": ("calendos",),
    "calicivirus": ("calicivirus",),
    "caligus": ("caligus",),
    "callicnémis": ("callicnémis",),
    "callinectes": ("callinectes",),
    "calliptamus": ("calliptamus",),
    "calocoris": ("calocoris",),
    "caloptenus": ("caloptenus",),
    "caloptéryx": ("caloptéryx",),
    "calotermes": ("calotermes",),
    "calvados": ("calvados",),
    "camaïeux": ("camaïeu",),
    "camarguaises": ("camarguais",),
    "camarguais": ("camarguais",),
    "cambarus": ("cambarus",),
    "cambouis": ("cambouis",),
    "cambridge": ("cambridge",),
    "cameramen": ("cameraman",),
    "caméramen": ("caméraman",),
    "caméras-stylos": ("caméra-stylo",),
    "camerounaises": ("camerounais",),
    "camerounais": ("camerounais",),
    "camions-citernes": ("camion-citerne",),
    "campo": ("campo",),
    "campos": ("campos",),
    "campus": ("campus",),
    "canada": ("canada",),
    "canaux": ("canal",),
    "canaux-tunnels": ("canal-tunnel",),
    "canapés-lits": ("canapé-lit",),
    "canardeaux": ("canardeau",),
    "cancéreuses": ("cancéreux",),
    "cancéreux": ("cancéreux",),
    "candida": ("candida",),
    "canevas": ("canevas",),
    "caniveaux": ("caniveau",),
    "cannabis": ("cannabis",),
    "cannes-parapluies": ("canne-parapluie",),
    "cantalès": ("cantalès",),
    "cantharis": ("cantharis",),
    "cantonaises": ("cantonais",),
    "cantonais": ("cantonais",),
    "capitaux": ("capital",),
    "capnodis": ("capnodis",),
    "caporaux-chefs": ("caporal-chef",),
    "caporali": ("caporale",),
    "caporales": ("caporal",),
    "caporaux": ("caporal",),
    "capricieuses": ("capricieux",),
    "capricieux": ("capricieux",),
    "capsules-congés": ("capsule-congé",),
    "capsus": ("capsus",),
    "capulus": ("capulus",),
    "carausius": ("carausius",),
    "carbonari": ("carbonaro",),
    "carcinus": ("carcinus",),
    "cardinaux": ("cardinal",),
    "cardiovirus": ("cardiovirus",),
    "carex": ("carex",),
    "car-ferries": ("car-ferry",),
    "carmen": ("carmen",),
    "carnaux": ("carnau",),
    "carneaux": ("carneau",),
    "carnets-blocs": ("carnet-bloc",),
    "carolus": ("carolus",),
    "carpeaux": ("carpeau",),
    "carpilius": ("carpilius",),
    "carpobrotus": ("carpobrotus",),
    "carpus": ("carpus",),
    "carquois": ("carquois",),
    "carreaux": ("carreau",),
    "cartes-crédit": ("carte-crédit",),
    "cartes-lettres": ("carte-lettre",),
    "carterus": ("carterus",),
    "carteux": ("carteux",),
    "cartes-vues": ("carte-vue",),
    "carthaginoises": ("carthaginois",),
    "carthaginois": ("carthaginois",),
    "cartons-cuirs": ("carton-cuir",),
    "cartons-pierres": ("carton-pierre",),
    "carus": ("carus",),
    "casablanca": ("casablanca",),
    "cas": ("cas",),
    "casseaux": ("casseau",),
    "casse-museaux": ("casse-museau",),
    "cassis": ("cassis",),
    "castagneux": ("castagneux",),
    "castorex": ("castorex",),
    "castorrex": ("castorrex",),
    "catarrheuses": ("catarrheux",),
    "catarrheux": ("catarrheux",),
    "catches": ("catch",),
    "catélectrotonus": ("catélectrotonus",),
    "catharsis": ("catharsis",),
    "catharsius": ("catharsius",),
    "cathartus": ("cathartus",),
    "cathélectrotonus": ("cathélectrotonus",),
    "catholicos": ("catholicos",),
    "catoblépas": ("catoblépas",),
    "catops": ("catops",),
    "cauchoises": ("cauchois",),
    "cauchois": ("cauchois",),
    "caucus": ("caucus",),
    "cauris": ("cauris",),
    "caveaux": ("caveau",),
    "cayeux": ("cayeu",),
    "cedex": ("cedex",),
    "céleris-navets": ("céleri-navet",),
    "celsius": ("celsius",),
    "cendaux": ("cendal",),
    "cens": ("cens",),
    "centesimi": ("centesimo",),
    "centraux": ("central",),
    "centres-tirs": ("centre-tir",),
    "centres-villes": ("centre-ville",),
    "cephalodiscus": ("cephalodiscus",),
    "céphalothorax": ("céphalothorax",),
    "cepheus": ("cepheus",),
    "ceps": ("ceps",),
    "cérambyx": ("cérambyx",),
    "cératias": ("cératias",),
    "cératodes": ("cératodes",),
    "cératophrys": ("cératophrys",),
    "ceratophyllus": ("ceratophyllus",),
    "cerceaux": ("cerceau",),
    "cercéris": ("cercéris",),
    "cercleuses": ("cercleux",),
    "cercleux": ("cercleux",),
    "cerfs-volants": ("cerf-volant",),
    "cerfs-volistes": ("cerf-voliste",),
    "cerneaux": ("cerneau",),
    "cers": ("cers",),
    "ceruchus": ("ceruchus",),
    "cerveaux": ("cerveau",),
    "cervelas": ("cervelas",),
    "céteaux": ("céteau",),
    "ceylanaises": ("ceylanais",),
    "ceylanais": ("ceylanais",),
    "chablis": ("chablis",),
    "chaboisseaux": ("chaboisseau",),
    "chaenichtys": ("chaenichtys",),
    "chairmen": ("chairman",),
    "chais": ("chais",),
    "chalcis": ("chalcis",),
    "chalets-refuges": ("chalet-refuge",),
    "chalumeaux": ("chalumeau",),
    "chamaerops": ("chamaerops",),
    "chameaux": ("chameau",),
    "chamelles": ("chameau",),
    "chamérops": ("chamérops",),
    "chamois": ("chamois",),
    "champs-contrechamps": ("champ-contrechamp",),
    "champenoises": ("champenois",),
    "champenois": ("champenois",),
    "champis": ("champis",),
    "champisses": ("champis",),
    "chanceuses": ("chanceux",),
    "chanceux": ("chanceux",),
    "chancreuses": ("chancreux",),
    "chancreux": ("chancreux",),
    "chanos": ("chanos",),
    "chanteaux": ("chanteau",),
    "chaos": ("chaos",),
    "chapeaux-claques": ("chapeau-claque",),
    "chapeaux": ("chapeau",),
    "chapiteaux": ("chapiteau",),
    "charaeas": ("charaeas",),
    "charaxes": ("charaxes",),
    "charax": ("charax",),
    "chardonay": ("chardonay",),
    "chardonnay": ("chardonnay",),
    "charentaises": ("charentais",),
    "charentais": ("charentais",),
    "chariots-grues": ("chariot-grue",),
    "charolaises": ("charolais",),
    "charolais": ("charolais",),
    "charollaises": ("charollais",),
    "charollais": ("charollais",),
    "chartreuses": ("chartreux",),
    "chartreux": ("chartreux",),
    "chas": ("chas",),
    "chassés-croisés": ("chassé-croisé",),
    "chasselas": ("chasselas",),
    "chasseurs-bombardiers": ("chasseur-bombardier",),
    "chasseurs-cueilleurs": ("chasseur-cueilleur",),
    "chassieuses": ("chassieux",),
    "chassieux": ("chassieux",),
    "châssis": ("châssis",),
    "châteaux": ("château",),
    "châteauneuf": ("châteauneuf",),
    "chats-huants": ("chat-huant",),
    "chatouillis": ("chatouillis",),
    "chaudeaux": ("chaudeau",),
    "chaudes-lances": ("chaude-lance",),
    "chaus": ("chaus",),
    "chauves-souris": ("chauve-souris",),
    "chaux": ("chaux",),
    "chefs-barres": ("chef-barre",),
    "chefs-d'oeuvre": ("chef-d'oeuvre",),
    "chefs-lieux": ("chef-lieu",),
    "cheilochalasis": ("cheilochalasis",),
    "cheiropompholyx": ("cheiropompholyx",),
    "chemineaux": ("chemineau",),
    "chémosis": ("chémosis",),
    "chenaux": ("chenal",),
    "chéneaux": ("chéneau",),
    "chêneaux": ("chêneau",),
    "chênes-lièges": ("chêne-liège",),
    "chènevis": ("chènevis",),
    "cherbourgeoises": ("cherbourgeois",),
    "cherbourgeois": ("cherbourgeois",),
    "cherfaix": ("cherfaix",),
    "chermes": ("chermes",),
    "chermès": ("chermès",),
    "chervis": ("chervis",),
    "chesterfield": ("chesterfield",),
    "chevaux-jupons": ("cheval-jupon",),
    "chevaux": ("chevau",),
    "chevaux-vapeur": ("cheval-vapeur",),
    "chevau": ("chevau",),
    "cheveux": ("cheveu",),
    "chevreaux": ("chevreau",),
    "chiches-kebabs": ("chiche-kebab",),
    "chichiteuses": ("chichiteux",),
    "chichiteux": ("chichiteux",),
    "chiens-lions": ("chien-lion",),
    "chiens-loups": ("chien-loup",),
    "chimonius": ("chimonius",),
    "chi": ("chi",),
    "chinoises": ("chinois",),
    "chinois": ("chinois",),
    "chintz": ("chintz",),
    "chionaspis": ("chionaspis",),
    "chionis": ("chionis",),
    "chipeaux": ("chipeau",),
    "chiroteuthis": ("chiroteuthis",),
    "chirurgiens-barbiers": ("chirurgien-barbier",),
    "chirurgiennes-majors": ("chirurgien-major",),
    "chlamydiae": ("chlamydia",),
    "chlamys": ("chlamys",),
    "choix": ("choix",),
    "choléthorax": ("choléthorax",),
    "chondracanthus": ("chondracanthus",),
    "chondromyces": ("chondromyces",),
    "chorionitis": ("chorionitis",),
    "chorioptes": ("chorioptes",),
    "choroiditis": ("choroiditis",),
    "chorthippus": ("chorthippus",),
    "chorus": ("chorus",),
    "choucas": ("choucas",),
    "choux-fleurs": ("chou-fleur",),
    "choux-navets": ("chou-navet",),
    "choux": ("chou",),
    "choux-turneps": ("chou-turneps",),
    "chrémeaux": ("chrémeau",),
    "chromes-tungstène": ("chrome-tungstène",),
    "chrysis": ("chrysis",),
    "chrysobothris": ("chrysobothris",),
    "chrysochus": ("chrysochus",),
    "chrysops": ("chrysops",),
    "chthonius": ("chthonius",),
    "chuchotis": ("chuchotis",),
    "churchmen": ("churchman",),
    "chydorus": ("chydorus",),
    "chylothorax": ("chylothorax",),
    "cigogneaux": ("cigogneau",),
    "cigonneaux": ("cigonneau",),
    "cimbex": ("cimbex",),
    "cingalaises": ("cingalais",),
    "cingalais": ("cingalais",),
    "cinghalaises": ("cinghalais",),
    "cinghalais": ("cinghalais",),
    "cinq": ("cinq",),
    "cinquante": ("cinquante",),
    "cionus": ("cionus",),
    "circoncis": ("circoncis",),
    "circulus": ("circulus",),
    "cirrocumulus": ("cirrocumulus",),
    "cirrostratus": ("cirrostratus",),
    "cirroteuthis": ("cirroteuthis",),
    "cirrus": ("cirrus",),
    "ciseaux": ("ciseau",),
    "citrus": ("citrus",),
    "cittosis": ("cittosis",),
    "cixius": ("cixius",),
    "cladothrix": ("cladothrix",),
    "clafoutis": ("clafoutis",),
    "clairs-obscurs": ("clair-obscur",),
    "clanculus": ("clanculus",),
    "clapotis": ("clapotis",),
    "clarias": ("clarias",),
    "clausocalanus": ("clausocalanus",),
    "claustra": ("claustrum",),
    "claveaux": ("claveau",),
    "clebs": ("clebs",),
    "clergymen": ("clergyman",),
    "cléricaux": ("clérical",),
    "climax": ("climax",),
    "cliquetis": ("cliquetis",),
    "clitoris": ("clitoris",),
    "clonus": ("clonus",),
    "closeaux": ("closeau",),
    "clos": ("clos",),
    "clubmen": ("clubman",),
    "c": ("c",),
    "ç": ("ç",),
    "coaches": ("coach",),
    "cocatris": ("cocatris",),
    "cocatrix": ("cocatrix",),
    "coccidotrophus": ("coccidotrophus",),
    "coccosteus": ("coccosteus",),
    "cocculus": ("cocculus",),
    "cocci": ("coccus",),
    "coccyx": ("coccyx",),
    "cochevis": ("cochevis",),
    "cochinchinoises": ("cochinchinois",),
    "cochinchinois": ("cochinchinois",),
    "cochylis": ("cochylis",),
    "cocodès": ("cocodès",),
    "codex": ("codex",),
    "codiopsis": ("codiopsis",),
    "coelioxys": ("coelioxys",),
    "cogneux": ("cogneux",),
    "coigneux": ("coigneux",),
    "coïtus": ("coïtus",),
    "coleman": ("coleman",),
    "coleps": ("coleps",),
    "coléreuses": ("coléreux",),
    "coléreux": ("coléreux",),
    "coléus": ("coléus",),
    "colias": ("colias",),
    "colineaux": ("colineau",),
    "colis": ("colis",),
    "collapsus": ("collapsus",),
    "collatérales": ("collatéral",),
    "collatéraux": ("collatéral",),
    "colliculus": ("colliculus",),
    "collyrites": ("collyrites",),
    "colobopsis": ("colobopsis",),
    "coloniales": ("colonial",),
    "coloniaux": ("colonial",),
    "colones": ("colón",),
    "coloris": ("coloris",),
    "colotyphus": ("colotyphus",),
    "colpocléisis": ("colpocléisis",),
    "columbus": ("columbus",),
    "comateuses": ("comateux",),
    "comateux": ("comateux",),
    "combien": ("combien",),
    "comitiales": ("comitial",),
    "comitiaux": ("comitial",),
    "commensales": ("commensal",),
    "commensaux": ("commensal",),
    "comment": ("comment",),
    "commerciales": ("commercial",),
    "commerciaux": ("commercial",),
    "commises": ("commis",),
    "commis": ("commis",),
    "commissaires-priseurs": ("commissaire-priseur",),
    "compas": ("compas",),
    "complexus": ("complexus",),
    "compound": ("compound",),
    "compradores": ("comprador",),
    "compromis": ("compromis",),
    "comtoises": ("comtois",),
    "comtois": ("comtois",),
    "cona": ("cona",),
    "conchylis": ("conchylis",),
    "concours": ("concours",),
    "confessionnaux": ("confessionnal",),
    "confiteor": ("confiteor",),
    "congolaises": ("congolais",),
    "congolais": ("congolais",),
    "congrès": ("congrès",),
    "congress": ("congress",),
    "coniatus": ("coniatus",),
    "conneaux": ("conneau",),
    "conoclypeus": ("conoclypeus",),
    "conodectes": ("conodectes",),
    "conops": ("conops",),
    "conquistadores": ("conquistador",),
    "consciencieuses": ("consciencieux",),
    "consciencieux": ("consciencieux",),
    "consensus": ("consensus",),
    "contagieuses": ("contagieux",),
    "contagieux": ("contagieux",),
    "contentieux": ("contentieux",),
    "continental": ("continental",),
    "continentales": ("continental",),
    "continentaux": ("continental",),
    "contravis": ("contravis",),
    "contrebas": ("contrebas",),
    "contrechâssis": ("contrechâssis",),
    "contrepoids": ("contrepoids",),
    "contresens": ("contresens",),
    "contretemps": ("contretemps",),
    "contumax": ("contumax",),
    "conus": ("conus",),
    "convolvulus": ("convolvulus",),
    "coopers": ("coopers",),
    "copeaux": ("copeau",),
    "copris": ("copris",),
    "cops": ("cops",),
    "coptotermes": ("coptotermes",),
    "coquaux": ("coquau",),
    "coqueleux": ("coqueleux",),
    "coquelucheuses": ("coquelucheux",),
    "coquelucheux": ("coquelucheux",),
    "coraux": ("corail",),
    "corbeaux": ("corbeau",),
    "corbières": ("corbières",),
    "corbis": ("corbis",),
    "cordeaux": ("cordeau",),
    "cordiaux": ("cordial",),
    "coréopsis": ("coréopsis",),
    "cornemuseuses": ("cornemuseux",),
    "cornemuseux": ("cornemuseux",),
    "cornouaillaises": ("cornouaillais",),
    "cornouaillais": ("cornouaillais",),
    "coroebus": ("coroebus",),
    "coronavirus": ("coronavirus",),
    "corporaux": ("corporal",),
    "corps": ("corps",),
    "corpora": ("corpus",),
    "corpus": ("corpus",),
    "corregidores": ("corregidor",),
    "corrégidores": ("corrégidor",),
    "cortex": ("cortex",),
    "corydalis": ("corydalis",),
    "corydoras": ("corydoras",),
    "coryllis": ("coryllis",),
    "corylopsis": ("corylopsis",),
    "corymbites": ("corymbites",),
    "corystes": ("corystes",),
    "cosignaux": ("cosignal",),
    "cosinus": ("cosinus",),
    "cosmos": ("cosmos",),
    "cossus": ("cossus",),
    "costeaux": ("costeau",),
    "coteaux": ("coteau",),
    "cotons-graines": ("coton-graine",),
    "couchages-couette": ("couchage-couette",),
    "couches-culottes": ("couche-culotte",),
    "couchis": ("couchis",),
    "cous-coupés": ("cou-coupé",),
    "couleuvreaux": ("couleuvreau",),
    "coulis": ("coulis",),
    "coulisseaux": ("coulisseau",),
    "coulommiers": ("coulommiers",),
    "coulonneuses": ("coulonneux",),
    "coulonneux": ("coulonneux",),
    "countries": ("country",),
    "coupons-réponses": ("coupon-réponse",),
    "courageuses": ("courageux",),
    "courageux": ("courageux",),
    "courlieux": ("courlieu",),
    "courlis": ("courlis",),
    "couros": ("couros",),
    "cous rouges": ("cou-rouge",),
    "courroux": ("courroux",),
    "courses-trames": ("course-trame",),
    "cours": ("cours",),
    "courts-bouillons": ("court-bouillon",),
    "courts métrages": ("court-métrage",),
    "courts-métrages": ("court-métrage",),
    "couscous": ("couscous",),
    "coustilleux": ("coustilleux",),
    "couteaux": ("couteau",),
    "couteaux-poignards": ("couteau-poignard",),
    "coutelas": ("coutelas",),
    "cous-tors": ("cou-tors",),
    "couvre-feux": ("couvre-feu",),
    "cowpox": ("cowpox",),
    "coxsackievirus": ("coxsackievirus",),
    "coyaux": ("coyau",),
    "crachouillis": ("crachouillis",),
    "cranioschisis": ("cranioschisis",),
    "craniotabès": ("craniotabès",),
    "credo": ("credo",),
    "cremastochilus": ("cremastochilus",),
    "créneaux": ("créneau",),
    "creseis": ("creseis",),
    "crésus": ("crésus",),
    "crêtes-de-coq": ("crête-de-coq",),
    "crétineux": ("crétineux",),
    "crétoises": ("crétois",),
    "crétois": ("crétois",),
    "creusoises": ("creusois",),
    "creusois": ("creusois",),
    "creux": ("creux",),
    "cricotopus": ("cricotopus",),
    "criss": ("criss",),
    "cristaux": ("cristal",),
    "crocallis": ("crocallis",),
    "crocus": ("crocus",),
    "croix": ("croix",),
    "croqueneaux": ("croqueneau",),
    "croquis": ("croquis",),
    "crossmen": ("crossman",),
    "cross": ("cross",),
    "croupeuses": ("croupeux",),
    "croupeux": ("croupeux",),
    "crucifix": ("crucifix",),
    "cryptanthus": ("cryptanthus",),
    "cryptocercus": ("cryptocercus",),
    "cryptococci": ("cryptococcus",),
    "cryptolaemus": ("cryptolaemus",),
    "cryptomonas": ("cryptomonas",),
    "cryptophagus": ("cryptophagus",),
    "cryptops": ("cryptops",),
    "cryptorhynchus": ("cryptorhynchus",),
    "cryptotops": ("cryptotops",),
    "cryptus": ("cryptus",),
    "crystallogobius": ("crystallogobius",),
    "csardas": ("csardas",),
    "cténus": ("cténus",),
    "cubitus": ("cubitus",),
    "cuisseaux": ("cuisseau",),
    "culs bénis": ("cul-béni",),
    "culs-bruns": ("cul-brun",),
    "culs de bouteille": ("cul-de-bouteille",),
    "culs-de-bouteille": ("cul-de-bouteille",),
    "culs de bus": ("cul-de-bus",),
    "culs-de-four": ("cul-de-four",),
    "culs-de-jatte": ("cul-de-jatte",),
    "culs-de-lampe": ("cul-de-lampe",),
    "culs-de-plomb": ("cul-de-plomb",),
    "culs-de-poulain": ("cul-de-poulain",),
    "culs-de-sac": ("cul-de-sac",),
    "culs-de-singe": ("cul-de-singe",),
    "culex": ("culex",),
    "culs-rouges": ("cul-rouge",),
    "cumulonimbus": ("cumulonimbus",),
    "cumulostratus": ("cumulostratus",),
    "cumulus": ("cumulus",),
    "cunnilinctus": ("cunnilinctus",),
    "cunnilingus": ("cunnilingus",),
    "curiaux": ("curial",),
    "curieuses": ("curieux",),
    "curieux": ("curieux",),
    "cursus": ("cursus",),
    "custom": ("custom",),
    "cuveaux": ("cuveau",),
    "cyamus": ("cyamus",),
    "cyatholaimus": ("cyatholaimus",),
    "cyberbus": ("cyberbus",),
    "cycas": ("cycas",),
    "cychrus": ("cychrus",),
    "cyclops": ("cyclops",),
    "cylas": ("cylas",),
    "cylindres-équerres": ("cylindre-équerre",),
    "cylindrophis": ("cylindrophis",),
    "cyllocoris": ("cyllocoris",),
    "cymindis": ("cymindis",),
    "cynips": ("cynips",),
    "cyprès": ("cyprès",),
    "cypris": ("cypris",),
    "cyrtauchenius": ("cyrtauchenius",),
    "cystinéphrosis": ("cystinéphrosis",),
    "cytomégalovirus": ("cytomégalovirus",),
    "czardas": ("czardas",),
    "dacquoises": ("dacquois",),
    "dacquois": ("dacquois",),
    "dacryoops": ("dacryoops",),
    "dactylopius": ("dactylopius",),
    "dacus": ("dacus",),
    "dadais": ("dadais",),
    "dadouchos": ("dadouchos",),
    "daijin": ("daijin",),
    "dais": ("dais",),
    "daleaux": ("daleau",),
    "dallas": ("dallas",),
    "damaeus": ("damaeus",),
    "damas": ("damas",),
    "dames-blanches": ("dame-blanche",),
    "dames-jeannes": ("dame-jeanne",),
    "dames-rondes": ("dame-ronde",),
    "damoiseaux": ("damoiseau",),
    "damoiselles": ("damoiseau",),
    "dan": ("dan",),
    "danoises": ("danois",),
    "danois": ("danois",),
    "danube": ("danube",),
    "daphnis": ("daphnis",),
    "darmous": ("darmous",),
    "dartois": ("dartois",),
    "dartos": ("dartos",),
    "dauphinoises": ("dauphinois",),
    "dauphinois": ("dauphinois",),
    "david": ("david",),
    "davidoff": ("davidoff",),
    "débarras": ("débarras",),
    "débours": ("débours",),
    "débris": ("débris",),
    "décès": ("décès",),
    "décours": ("décours",),
    "décrets-lois": ("décret-loi",),
    "décubitus": ("décubitus",),
    "décussis": ("décussis",),
    "dédaigneuses": ("dédaigneux",),
    "dédaigneux": ("dédaigneux",),
    "dedans": ("dedans",),
    "défauts-congés": ("défaut-congé",),
    "défends": ("défends",),
    "défens": ("défens",),
    "dégras": ("dégras",),
    "dégueulis": ("dégueulis",),
    "dehors": ("dehors",),
    "déixis": ("déixis",),
    "deleatur": ("deleatur",),
    "delphax": ("delphax",),
    "demi-dieux": ("demi-dieu",),
    "demidoff": ("demidoff",),
    "demi-métaux": ("demi-métal",),
    "demi-tonneaux": ("demi-tonneau",),
    "démocrates-chrétiennes": ("démocrate-chrétien",),
    "démocrates-chrétiens": ("démocrate-chrétien",),
    "demodex": ("demodex",),
    "dendraspis": ("dendraspis",),
    "dendrohyrax": ("dendrohyrax",),
    "dendrolimus": ("dendrolimus",),
    "dendronotus": ("dendronotus",),
    "dénéraux": ("dénéral",),
    "dentaux": ("dental",),
    "dents-de-loup": ("dent-de-loup",),
    "dentinogenesis": ("dentinogenesis",),
    "deporaus": ("deporaus",),
    "dépôts-ventes": ("dépôt-vente",),
    "dermanyssus": ("dermanyssus",),
    "dermatophilus": ("dermatophilus",),
    "dérocéras": ("dérocéras",),
    "derocheilocaris": ("derocheilocaris",),
    "derolomus": ("derolomus",),
    "désaveux": ("désaveu",),
    "desidiopsis": ("desidiopsis",),
    "désis": ("désis",),
    "deskmen": ("deskman",),
    "desmoceras": ("desmoceras",),
    "dessinateurs-cartographes": ("dessinateur-cartographe",),
    "dessous": ("dessous",),
    "dessus": ("dessus",),
    "détritus": ("détritus",),
    "deutschemark": ("deutschmark",),
    "deutschemarks": ("deutschmark",),
    "deux": ("deux",),
    "déverbaux": ("déverbal",),
    "dévers": ("dévers",),
    "devis": ("devis",),
    "diagonaux": ("diagonal",),
    "diamond": ("diamond",),
    "diana": ("diana",),
    "diaptomus": ("diaptomus",),
    "diaschisis": ("diaschisis",),
    "diaspis": ("diaspis",),
    "diastasis": ("diastasis",),
    "diastylis": ("diastylis",),
    "diceras": ("diceras",),
    "dichirotrichus": ("dichirotrichus",),
    "dieppoises": ("dieppois",),
    "dieppois": ("dieppois",),
    "diesels-hydrauliques": ("diesel-hydraulique",),
    "diestrus": ("diestrus",),
    "dieux": ("dieu",),
    "dijonnaises": ("dijonnais",),
    "dijonnais": ("dijonnais",),
    "dilophus": ("dilophus",),
    "dilus": ("dilus",),
    "dimitri": ("dimitri",),
    "dinarites": ("dinarites",),
    "dindonneaux": ("dindonneau",),
    "dîners-débats": ("dîner-débat",),
    "dineutes": ("dineutes",),
    "dinichthys": ("dinichthys",),
    "dinophilus": ("dinophilus",),
    "dinopis": ("dinopis",),
    "dinornis": ("dinornis",),
    "dioestrus": ("dioestrus",),
    "diogenes": ("diogenes",),
    "diopsis": ("diopsis",),
    "diphyès": ("diphyès",),
    "diplex": ("diplex",),
    "diplocidaris": ("diplocidaris",),
    "diplodocus": ("diplodocus",),
    "diplodus": ("diplodus",),
    "diplograptus": ("diplograptus",),
    "diplo": ("diplo",),
    "dipterus": ("dipterus",),
    "discours": ("discours",),
    "disetteuses": ("disetteux",),
    "disetteux": ("disetteux",),
    "disques-lotion": ("disque-lotion",),
    "distichiasis": ("distichiasis",),
    "distillers": ("distillers",),
    "districhiasis": ("districhiasis",),
    "ditomus": ("ditomus",),
    "diurnaux": ("diurnal",),
    "divis": ("divis",),
    "diwan": ("diwan",),
    "dix": ("dix",),
    "djaïna": ("djaïna",),
    "djamâa": ("djamâa",),
    "djemâa": ("djemâa",),
    "d": ("d",),
    "dociostaurus": ("dociostaurus",),
    "docophorus": ("docophorus",),
    "doigts-indicateurs": ("doigt-indicateur",),
    "dolci": ("dolce",),
    "doleaux": ("doleau",),
    "dolerus": ("dolerus",),
    "dolichoderus": ("dolichoderus",),
    "dolichopus": ("dolichopus",),
    "dolomedes": ("dolomedes",),
    "domovoï": ("domovoï",),
    "doña": ("doña",),
    "donax": ("donax",),
    "do": ("do",),
    "donne": ("donna",),
    "dopa": ("dopa",),
    "dorcas": ("dorcas",),
    "dorcus": ("dorcus",),
    "doris": ("doris",),
    "dorylaimus": ("dorylaimus",),
    "dos": ("dos",),
    "doubleaux": ("doubleau",),
    "doubles-blancs": ("double-blanc",),
    "doubles-corps": ("double-corps",),
    "doubles-deux": ("double-deux",),
    "doubles-faces": ("double-face",),
    "doubles fonds": ("double-fond",),
    "doubles-fonds": ("double-fond",),
    "doubles-plis": ("double-pli",),
    "doubles-sculls": ("double-scull",),
    "doubles-toits": ("double-toit",),
    "doubles-un": ("double-un",),
    "doublis": ("doublis",),
    "douces-amères": ("douce-amère",),
    "doucereuses": ("doucereux",),
    "doucereux": ("doucereux",),
    "douglas": ("douglas",),
    "douze": ("douze",),
    "dracula": ("dracula",),
    "dracunculus": ("dracunculus",),
    "dragonneaux": ("dragonneau",),
    "drapeaux": ("drapeau",),
    "drépanaspis": ("drépanaspis",),
    "drépanornis": ("drépanornis",),
    "dress": ("dress",),
    "drômoises": ("drômois",),
    "drômois": ("drômois",),
    "dromos": ("dromos",),
    "dromus": ("dromus",),
    "dryinus": ("dryinus",),
    "dryocoetes": ("dryocoetes",),
    "duchés-pairies": ("duché-pairie",),
    "dunkerquoises": ("dunkerquois",),
    "dunkerquois": ("dunkerquois",),
    "dunoises": ("dunois",),
    "dunois": ("dunois",),
    "duplex": ("duplex",),
    "duplicata": ("duplicata",),
    "dures-mères": ("dure-mère",),
    "duxelles": ("duxelles",),
    "duces": ("dux",),
    "dvorak": ("dvorak",),
    "dymasus": ("dymasus",),
    "dynamos-démarreur": ("dynamo-démarreur",),
    "dyschirius": ("dyschirius",),
    "dysdercus": ("dysdercus",),
    "dysostosis": ("dysostosis",),
    "dzêta": ("dzêta",),
    "earias": ("earias",),
    "eaux-de-vie": ("eau-de-vie",),
    "eaux-fortes": ("eau-forte",),
    "eaux-mères": ("eau-mère",),
    "eaux": ("eau",),
    "éboulis": ("éboulis",),
    "eccremocarpus": ("eccremocarpus",),
    "ecdysis": ("ecdysis",),
    "échalas": ("échalas",),
    "échantillons-types": ("échantillon-type",),
    "échaudis": ("échaudis",),
    "échaux": ("échau",),
    "écheveaux": ("écheveau",),
    "échinobrissus": ("échinobrissus",),
    "échinocactus": ("échinocactus",),
    "échinocéréus": ("échinocéréus",),
    "échinoconus": ("échinoconus",),
    "échinocorys": ("échinocorys",),
    "echinocyamus": ("echinocyamus",),
    "échinops": ("échinops",),
    "échinus": ("échinus",),
    "échitès": ("échitès",),
    "échoplanar": ("échoplanar",),
    "échoplex": ("échoplex",),
    "echovirus": ("echovirus",),
    "échovirus": ("échovirus",),
    "écossais": ("écossais",),
    "écotaxis": ("écotaxis",),
    "écriteaux": ("écriteau",),
    "eczémateuses": ("eczémateux",),
    "eczémateux": ("eczémateux",),
    "edelweiss": ("edelweiss",),
    "éditoriaux": ("éditorial",),
    "éfourceaux": ("éfourceau",),
    "égales": ("égal",),
    "égaux": ("égal",),
    "églises-halles": ("église-halle",),
    "ego": ("ego",),
    "elaeagnus": ("elaeagnus",),
    "elaeis": ("elaeis",),
    "élaeis": ("élaeis",),
    "élaphis": ("élaphis",),
    "élaps": ("élaps",),
    "élasmopus": ("élasmopus",),
    "élasmostéthus": ("élasmostéthus",),
    "élastorrhexis": ("élastorrhexis",),
    "elbeuf": ("elbeuf",),
    "électrostimulus": ("électrostimulus",),
    "électrotonus": ("électrotonus",),
    "eleis": ("eleis",),
    "éléis": ("éléis",),
    "éléments-bars": ("élément-bar",),
    "éléphanteaux": ("éléphanteau",),
    "éléphantiasis": ("éléphantiasis",),
    "élèves-brigadières": ("élève-brigadier",),
    "élèves-maîtres": ("élève-maître",),
    "élis": ("élis",),
    "ellampus": ("ellampus",),
    "ellipsocephalus": ("ellipsocephalus",),
    "elmis": ("elmis",),
    "élongis": ("élongis",),
    "éloptéryx": ("éloptéryx",),
    "émaux": ("émail",),
    "embarras": ("embarras",),
    "embolus": ("embolus",),
    "émetteurs-récepteurs": ("émetteur-récepteur",),
    "émilion": ("émilion",),
    "empéripolesis": ("empéripolesis",),
    "emphysémateuses": ("emphysémateux",),
    "emphysémateux": ("emphysémateux",),
    "emphytus": ("emphytus",),
    "empis": ("empis",),
    "empois": ("empois",),
    "emporos": ("emporos",),
    "emposieux": ("emposieu",),
    "emprosthotonos": ("emprosthotonos",),
    "encaisses-or": ("encaisse-or",),
    "en-cas": ("encas",),
    "encas": ("encas",),
    "encens": ("encens",),
    "enchaux": ("enchaux",),
    "enclos": ("enclos",),
    "en-cours": ("encours",),
    "encours": ("encours",),
    "encroix": ("encroix",),
    "encyrtus": ("encyrtus",),
    "endoceras": ("endoceras",),
    "endolimax": ("endolimax",),
    "endomychus": ("endomychus",),
    "endophtalmitis": ("endophtalmitis",),
    "endos": ("endos",),
    "endovirus": ("endovirus",),
    "endromis": ("endromis",),
    "e": ("e",),
    "enfaîteaux": ("enfaîteau",),
    "engrais": ("engrais",),
    "engrois": ("engrois",),
    "enjeux": ("enjeu",),
    "ennomos": ("ennomos",),
    "ensis": ("ensis",),
    "ensoupleaux": ("ensoupleau",),
    "entérovirus": ("entérovirus",),
    "entibois": ("entibois",),
    "entomoscelis": ("entomoscelis",),
    "entrejeux": ("entrejeu",),
    "entrelacs": ("entrelacs",),
    "entremets": ("entremets",),
    "entreprises-pilotes": ("entreprise-pilote",),
    "entrevous": ("entrevous",),
    "envers": ("envers",),
    "envieuses": ("envieux",),
    "envieux": ("envieux",),
    "eohippus": ("eohippus",),
    "ephialtes": ("ephialtes",),
    "épicanthis": ("épicanthis",),
    "épicanthus": ("épicanthus",),
    "épieux": ("épieu",),
    "épihippus": ("épihippus",),
    "épilissus": ("épilissus",),
    "épiornis": ("épiornis",),
    "épiscopaux": ("épiscopal",),
    "épiscopos": ("épiscopos",),
    "épispadias": ("épispadias",),
    "épistasis": ("épistasis",),
    "épistaxis": ("épistaxis",),
    "épistylis": ("épistylis",),
    "épithalamus": ("épithalamus",),
    "épouses": ("époux",),
    "époux": ("époux",),
    "epsilon": ("epsilon",),
    "épulis": ("épulis",),
    "epyornis": ("epyornis",),
    "épyornis": ("épyornis",),
    "équatoriaux": ("équatorial",),
    "éranthis": ("éranthis",),
    "érébus": ("érébus",),
    "érémostachys": ("érémostachys",),
    "érémurus": ("érémurus",),
    "érésipélateuses": ("érésipélateux",),
    "érésipélateux": ("érésipélateux",),
    "eretes": ("eretes",),
    "ériophyes": ("ériophyes",),
    "érirrhinus": ("érirrhinus",),
    "éros": ("éros",),
    "errata": ("erratum",),
    "ersatz": ("ersatz",),
    "erseaux": ("erseau",),
    "ers": ("ers",),
    "éryops": ("éryops",),
    "érysipélateuses": ("érysipélateux",),
    "érysipélateux": ("érysipélateux",),
    "érysipélothrix": ("érysipélothrix",),
    "érythrinus": ("érythrinus",),
    "erythrogenesis": ("erythrogenesis",),
    "érythrorrhexis": ("érythrorrhexis",),
    "éryx": ("éryx",),
    "escabeaux": ("escabeau",),
    "espaces-enfants": ("espace-enfant",),
    "espaces-temps": ("espace-temps",),
    "esquimaudes": ("esquimau",),
    "esquimaux": ("esquimau",),
    "esseaux": ("esseau",),
    "essieux": ("essieu",),
    "estèphe": ("estèphe",),
    "estibois": ("estibois",),
    "estriqueux": ("estriqueux",),
    "étampeux": ("étampeux",),
    "êta": ("êta",),
    "états-majors": ("état-major",),
    "états-membres": ("état-membre",),
    "étaux": ("étau",),
    "eteophilus": ("eteophilus",),
    "ethos": ("ethos",),
    "etmopterus": ("etmopterus",),
    "étoquiaux": ("étoquiau",),
    "étourneaux": ("étourneau",),
    "étrieux": ("étrieu",),
    "eucalyptocrinus": ("eucalyptocrinus",),
    "eucalyptus": ("eucalyptus",),
    "eucharis": ("eucharis",),
    "euchirus": ("euchirus",),
    "eudémis": ("eudémis",),
    "eugeniacrinus": ("eugeniacrinus",),
    "eumerus": ("eumerus",),
    "eunausibius": ("eunausibius",),
    "euomphalus": ("euomphalus",),
    "euplectus": ("euplectus",),
    "euplotes": ("euplotes",),
    "euporus": ("euporus",),
    "euproctis": ("euproctis",),
    "euptéryx": ("euptéryx",),
    "europa": ("europa",),
    "eurycercus": ("eurycercus",),
    "eurypharynx": ("eurypharynx",),
    "eurypterus": ("eurypterus",),
    "euscorpius": ("euscorpius",),
    "eustrongylus": ("eustrongylus",),
    "eutermes": ("eutermes",),
    "eutropius": ("eutropius",),
    "evax": ("evax",),
    "eve": ("eve",),
    "evolvulus": ("evolvulus",),
    "excès": ("excès",),
    "ex-championnes": ("ex-champion",),
    "exeat": ("exeat",),
    "exequatur": ("exequatur",),
    "exit": ("exit",),
    "ex": ("ex",),
    "exocentrus": ("exocentrus",),
    "exochomus": ("exochomus",),
    "exodos": ("exodos",),
    "exophtalmos": ("exophtalmos",),
    "exorbitis": ("exorbitis",),
    "exovirus": ("exovirus",),
    "experts-comptables": ("expert-comptable",),
    "exprès": ("exprès",),
    "express": ("express",),
    "exquis": ("exquis",),
    "extrados": ("extrados",),
    "extra": ("extra",),
    "fabliaux": ("fabliau",),
    "faces-à-main": ("face-à-main",),
    "facétieuses": ("facétieux",),
    "facétieux": ("facétieux",),
    "fâcheuses": ("fâcheux",),
    "fâcheux": ("fâcheux",),
    "faciaux": ("facial",),
    "facies": ("facies",),
    "faciès": ("faciès",),
    "factieuses": ("factieux",),
    "factieux": ("factieux",),
    "faisandeaux": ("faisandeau",),
    "faisanneaux": ("faisanneau",),
    "faisceaux": ("faisceau",),
    "faits divers": ("fait-divers",),
    "faits-divers": ("fait-divers",),
    "faîteaux": ("faîteau",),
    "faix": ("faix",),
    "falsetti": ("falsetto",),
    "fanaux": ("fanal",),
    "fa": ("fa",),
    "fardeaux": ("fardeau",),
    "farineux": ("farineux",),
    "fatras": ("fatras",),
    "faucheux": ("faucheux",),
    "fauconneaux": ("fauconneau",),
    "fauteuils-brouettes": ("fauteuil-brouette",),
    "fauveaux": ("fauveau",),
    "faux": ("faux",),
    "favus": ("favus",),
    "fax": ("fax",),
    "féales": ("féal",),
    "féaux": ("féal",),
    "féciaux": ("fécial",),
    "fédérales": ("fédéral",),
    "fédéraux": ("fédéral",),
    "feld maréchaux": ("feld-maréchal",),
    "femmes-enfants": ("femme-enfant",),
    "fendis": ("fendis",),
    "fen": ("fen",),
    "féodales": ("féodal",),
    "féodaux": ("féodal",),
    "fermaux": ("fermail",),
    "fermes-auberges": ("ferme-auberge",),
    "ferrandais": ("ferrandais",),
    "ferraraises": ("ferrarais",),
    "ferrarais": ("ferrarais",),
    "ferries": ("ferry",),
    "festoù": ("fest",),
    "fetches": ("fetch",),
    "fétiaux": ("fétial",),
    "feuilletis": ("feuilletis",),
    "feux": ("feu",),
    "fez": ("fez",),
    "fiadoni": ("fiadone",),
    "fiat": ("fiat",),
    "fibratus": ("fibratus",),
    "fibrin": ("fibrin",),
    "fibrothorax": ("fibrothorax",),
    "ficus": ("ficus",),
    "fidéicommis": ("fidéicommis",),
    "fieux": ("fieu",),
    "fiévreuses": ("fiévreux",),
    "fiévreux": ("fiévreux",),
    "fifties": ("fifty",),
    "filid": ("fili",),
    "filles-mères": ("fille-mère",),
    "fillér": ("fillér",),
    "films-packs": ("film-pack",),
    "filons-couches": ("filon-couche",),
    "fils": ("fils",),
    "fimbristylis": ("fimbristylis",),
    "finches": ("finch",),
    "finish": ("finish",),
    "finlandaises": ("finlandais",),
    "finlandais": ("finlandais",),
    "finnoises": ("finnois",),
    "finnois": ("finnois",),
    "fiscaux": ("fiscal",),
    "fischer": ("fischer",),
    "flambeaux": ("flambeau",),
    "flanquis": ("flanquis",),
    "flavivirus": ("flavivirus",),
    "fléaux": ("fléau",),
    "floculus": ("floculus",),
    "flushes": ("flush",),
    "flûteaux": ("flûteau",),
    "flûtiaux": ("flûtiau",),
    "flux": ("flux",),
    "f": ("f",),
    "focus": ("focus",),
    "foetus": ("foetus",),
    "foireuses": ("foireux",),
    "foireux": ("foireux",),
    "fois": ("fois",),
    "folliclis": ("folliclis",),
    "follis": ("follis",),
    "fonceaux": ("fonceau",),
    "fondis": ("fondis",),
    "fonds": ("fonds",),
    "fongus": ("fongus",),
    "fontainebleaux": ("fontainebleau",),
    "fontis": ("fontis",),
    "forceps": ("forceps",),
    "formicomus": ("formicomus",),
    "fornix": ("fornix",),
    "forte": ("forte",),
    "fossores": ("fossor",),
    "fouillis": ("fouillis",),
    "fourneaux": ("fourneau",),
    "fourreaux": ("fourreau",),
    "fouteaux": ("fouteau",),
    "fox": ("fox",),
    "fracas": ("fracas",),
    "fractocumulus": ("fractocumulus",),
    "fractonimbus": ("fractonimbus",),
    "fractostratus": ("fractostratus",),
    "fractus": ("fractus",),
    "frais": ("frais",),
    "françaises": ("français",),
    "français": ("français",),
    "francs-archers": ("franc-archer",),
    "franc-bourgeoises": ("franc-bourgeois",),
    "francs-bourgeois": ("franc-bourgeois",),
    "francs-cantons": ("franc-canton",),
    "francs-comtois": ("franc-comtois",),
    "franc-maçonnes": ("franc-maçon",),
    "francs-maçons": ("franc-maçon",),
    "francs-parlers": ("franc-parler",),
    "francs-saures": ("franc-saure",),
    "francs-tireurs": ("franc-tireur",),
    "fred": ("fred",),
    "frettes-tourillons": ("frette-tourillon",),
    "freux": ("freux",),
    "fricandeaux": ("fricandeau",),
    "frics-fracs": ("fric-frac",),
    "frileuses": ("frileux",),
    "frileux": ("frileux",),
    "frimas": ("frimas",),
    "friselis": ("friselis",),
    "frisottis": ("frisottis",),
    "fritz": ("fritz",),
    "fromentaux": ("fromental",),
    "froncis": ("froncis",),
    "frontaux": ("frontail",),
    "fronteaux": ("fronteau",),
    "frottis": ("frottis",),
    "frous-frous": ("frou-frou",),
    "frusquin": ("frusquin",),
    "fucus": ("fucus",),
    "fundus": ("fundus",),
    "furieuses": ("furieux",),
    "furieux": ("furieux",),
    "furonculeuses": ("furonculeux",),
    "furonculeux": ("furonculeux",),
    "fuseaux": ("fuseau",),
    "fusées-parachutes": ("fusée-parachute",),
    "fusils-mitrailleurs": ("fusil-mitrailleur",),
    "fusinus": ("fusinus",),
    "fusus": ("fusus",),
    "gabonaises": ("gabonais",),
    "gabonais": ("gabonais",),
    "gâchis": ("gâchis",),
    "gadzarts": ("gadzarts",),
    "gagaku": ("gagaku",),
    "gages-pleiges": ("gage-pleige",),
    "gagmen": ("gagman",),
    "gaines-combinaisons": ("gaine-combinaison",),
    "galanthus": ("galanthus",),
    "galerites": ("galerites",),
    "galetas": ("galetas",),
    "galeuses": ("galeux",),
    "galeux": ("galeux",),
    "galimatias": ("galimatias",),
    "galloises": ("gallois",),
    "gallois": ("gallois",),
    "gallornis": ("gallornis",),
    "galvanotonus": ("galvanotonus",),
    "galvaudeuses": ("galvaudeux",),
    "galvaudeux": ("galvaudeux",),
    "gamasus": ("gamasus",),
    "gamma": ("gamma",),
    "gantoises": ("gantois",),
    "gantois": ("gantois",),
    "gapançaises": ("gapançais",),
    "gapançais": ("gapançais",),
    "garas": ("garas",),
    "garcinia": ("garcinia",),
    "gardes-barrière": ("garde-barrière",),
    "gardes champêtres": ("garde-champêtre",),
    "gardes-champêtres": ("garde-champêtre",),
    "gardes-chasses": ("garde-chasse",),
    "gardes-chiourme": ("garde-chiourme",),
    "gardes-chiourmes": ("garde-chiourme",),
    "gardes-frein": ("garde-frein",),
    "gardes-frontières": ("garde-frontière",),
    "gardes-magasin": ("garde-magasin",),
    "gardes-malades": ("garde-malade",),
    "gardes-marine": ("garde-marine",),
    "gardes-môle": ("garde-môle",),
    "garden-parties": ("garden-party",),
    "gardes-pêche": ("garde-pêche",),
    "gardes-ports": ("garde-port",),
    "garde-robières": ("garde-robier",),
    "gardes-vente": ("garde-vente",),
    "gardes-voies": ("garde-voie",),
    "gardiens-chefs": ("gardien-chef",),
    "gardoises": ("gardois",),
    "gardois": ("gardois",),
    "gardonneaux": ("gardonneau",),
    "gargouillis": ("gargouillis",),
    "gars": ("gars",),
    "gasteropelecus": ("gasteropelecus",),
    "gastornis": ("gastornis",),
    "gastrolysis": ("gastrolysis",),
    "gâteaux": ("gâteau",),
    "gâteuses": ("gâteux",),
    "gâteux": ("gâteux",),
    "gaulis": ("gaulis",),
    "gauloises": ("gaulois",),
    "gaulois": ("gaulois",),
    "gauss": ("gauss",),
    "gaz": ("gaz",),
    "gazouillis": ("gazouillis",),
    "gémeaux": ("gémeau",),
    "gemmaux": ("gemmail",),
    "gem": ("gem",),
    "générales": ("général",),
    "généraux": ("général",),
    "généreuses": ("généreux",),
    "généreux": ("généreux",),
    "genevoises": ("genevois",),
    "genevois": ("genevois",),
    "génoises": ("génois",),
    "génois": ("génois",),
    "genoux": ("genou",),
    "gens": ("gens",),
    "gentes": ("gens",),
    "gentilshommes": ("gentilhomme",),
    "gentlemen farmers": ("gentleman-farmer",),
    "gentlemen": ("gentleman",),
    "gentries": ("gentry",),
    "georgi": ("georgi",),
    "géoryssus": ("géoryssus",),
    "géosargus": ("géosargus",),
    "géosynclinaux": ("géosynclinal",),
    "géraniums-lierres": ("géranium-lierre",),
    "gerris": ("gerris",),
    "gerseaux": ("gerseau",),
    "gersoises": ("gersois",),
    "gersois": ("gersois",),
    "gerzeaux": ("gerzeau",),
    "gibus": ("gibus",),
    "gigahertz": ("gigahertz",),
    "gigantorhynchus": ("gigantorhynchus",),
    "gilles": ("gilles",),
    "girafeaux": ("girafeau",),
    "glacis": ("glacis",),
    "glas": ("glas",),
    "glass": ("glass",),
    "glaucomateuses": ("glaucomateux",),
    "glaucomateux": ("glaucomateux",),
    "glaucopis": ("glaucopis",),
    "global": ("global",),
    "globiceps": ("globiceps",),
    "glochidium": ("glochidium",),
    "gloméris": ("gloméris",),
    "glomus": ("glomus",),
    "gloria": ("gloria",),
    "gluaux": ("gluau",),
    "glycyméris": ("glycyméris",),
    "gnathonemus": ("gnathonemus",),
    "gneiss": ("gneiss",),
    "g": ("g",),
    "gnophos": ("gnophos",),
    "gobetis": ("gobetis",),
    "godelureaux": ("godelureau",),
    "godiveaux": ("godiveau",),
    "goitreuses": ("goitreux",),
    "goitreux": ("goitreux",),
    "gold": ("gold",),
    "gommes-ammoniaques": ("gomme-ammoniaque",),
    "gommes-laques": ("gomme-laque",),
    "gommeuses": ("gommeux",),
    "gommeux": ("gommeux",),
    "gomphus": ("gomphus",),
    "go": ("go",),
    "goniodes": ("goniodes",),
    "gonocérus": ("gonocérus",),
    "gonoplax": ("gonoplax",),
    "gonyaulax": ("gonyaulax",),
    "gopura": ("gopura",),
    "gouttereaux": ("gouttereau",),
    "goutteuses": ("goutteux",),
    "goutteux": ("goutteux",),
    "goyim": ("goy",),
    "grabeaux": ("grabeau",),
    "gradus": ("gradus",),
    "grainières-fleuristes": ("grainier-fleuriste",),
    "grammateus": ("grammateus",),
    "grammes-poids": ("gramme-poids",),
    "gram": ("gram",),
    "grands-angulaires": ("grand-angulaire",),
    "grands-duchés": ("grand-duché",),
    "grandes-duchesses": ("grand-duc",),
    "grands-ducs": ("grand-duc",),
    "grands-livres": ("grand-livre",),
    "grandmaster": ("grandmaster",),
    "grands-papas": ("grand-papa",),
    "grands-pères": ("grand-père",),
    "grands-places": ("grand-place",),
    "grandes-routes": ("grand-route",),
    "grands-voiles": ("grand-voile",),
    "gras": ("gras",),
    "gratteuses": ("gratteux",),
    "gratteux": ("gratteux",),
    "grattouillis": ("grattouillis",),
    "graux": ("grau",),
    "graves": ("graves",),
    "grecques-melkites": ("grec-melkite",),
    "grecs melkites": ("grec-melkite",),
    "grecs-melkites": ("grec-melkite",),
    "grémiaux": ("grémial",),
    "grènetis": ("grènetis",),
    "grenobloises": ("grenoblois",),
    "grenoblois": ("grenoblois",),
    "grès": ("grès",),
    "gribouillis": ("gribouillis",),
    "grignotis": ("grignotis",),
    "gris-gris": ("gris-gris",),
    "grimpereaux": ("grimpereau",),
    "grincheuses": ("grincheux",),
    "grincheux": ("grincheux",),
    "gris": ("gris",),
    "groenlandaises": ("groenlandais",),
    "groenlandais": ("groenlandais",),
    "groszy": ("grosz",),
    "gruaux": ("gruau",),
    "grumeaux": ("grumeau",),
    "gruppetti": ("gruppetto",),
    "guenilleuses": ("guenilleux",),
    "guenilleux": ("guenilleux",),
    "guernesiaises": ("guernesiais",),
    "guernesiais": ("guernesiais",),
    "gueules-de-loup": ("gueule-de-loup",),
    "gueuses": ("gueux",),
    "gueux": ("gueux",),
    "gueuzes-lambics": ("gueuze-lambic",),
    "guideaux": ("guideau",),
    "guillochis": ("guillochis",),
    "guindeaux": ("guindeau",),
    "günz": ("günz",),
    "gus": ("gus",),
    "guss": ("guss",),
    "guttas-perchas": ("gutta-percha",),
    "guyanaises": ("guyanais",),
    "guyanais": ("guyanais",),
    "gymnopternus": ("gymnopternus",),
    "gyratrix": ("gyratrix",),
    "gyrocompas": ("gyrocompas",),
    "gyrus": ("gyrus",),
    "habitus": ("habitus",),
    "hachereaux": ("hachereau",),
    "hachis": ("hachis",),
    "haemanthus": ("haemanthus",),
    "haematococcus": ("haematococcus",),
    "haemophilus": ("haemophilus",),
    "haemopis": ("haemopis",),
    "haggis": ("haggis",),
    "hagis": ("hagis",),
    "haguaises": ("haguais",),
    "haguais": ("haguais",),
    "haha": ("haha",),
    "hahn": ("hahn",),
    "haikai": ("haikai",),
    "haiku": ("haiku",),
    "haïku": ("haïku",),
    "haineuses": ("haineux",),
    "haineux": ("haineux",),
    "halacarus": ("halacarus",),
    "halalas": ("halalas",),
    "hale-bas": ("halebas",),
    "halebas": ("halebas",),
    "halefis": ("halefis",),
    "haléri": ("halér",),
    "halictophagus": ("halictophagus",),
    "haliotis": ("haliotis",),
    "hallus": ("hallus",),
    "hallux": ("hallux",),
    "hamadryas": ("hamadryas",),
    "hamamélis": ("hamamélis",),
    "hambourgeoises": ("hambourgeois",),
    "hambourgeois": ("hambourgeois",),
    "hameaux": ("hameau",),
    "hammerless": ("hammerless",),
    "hammer": ("hammer",),
    "hanufa": ("hanif",),
    "han": ("han",),
    "hantavirus": ("hantavirus",),
    "hantei": ("hantei",),
    "hao": ("hao",),
    "hapax": ("hapax",),
    "haploceras": ("haploceras",),
    "happy": ("happy",),
    "haras": ("haras",),
    "harengueuses": ("harengueux",),
    "harengueux": ("harengueux",),
    "harmandia": ("harmandia",),
    "harnais": ("harnais",),
    "harnois": ("harnois",),
    "harpes": ("harpes",),
    "harpoceras": ("harpoceras",),
    "hassidim": ("hassid",),
    "hâtereaux": ("hâtereau",),
    "hathaway": ("hathaway",),
    "hâtiveaux": ("hâtiveau",),
    "hauts-bars": ("haut-bar",),
    "hautbois": ("hautbois",),
    "hauts-commissariats": ("haut-commissariat",),
    "hauts-de-côtelettes": ("haut-de-côtelettes",),
    "hauts-de-forme": ("haut-de-forme",),
    "hautes-pièces": ("haute-pièce",),
    "hauts-fonds": ("haut-fond",),
    "hauts fourneaux": ("haut-fourneau",),
    "hauts-fourneaux": ("haut-fourneau",),
    "hauts-fournistes": ("haut-fourniste",),
    "hauts-reliefs": ("haut-relief",),
    "havanaises": ("havanais",),
    "havanais": ("havanais",),
    "haveneaux": ("haveneau",),
    "havraises": ("havrais",),
    "havrais": ("havrais",),
    "héliocopris": ("héliocopris",),
    "héliothis": ("héliothis",),
    "hélix": ("hélix",),
    "hélopeltis": ("hélopeltis",),
    "hélops": ("hélops",),
    "hemaris": ("hemaris",),
    "hématocolpos": ("hématocolpos",),
    "hématopelvis": ("hématopelvis",),
    "hematopinus": ("hematopinus",),
    "hématorrachis": ("hématorrachis",),
    "hématosalpinx": ("hématosalpinx",),
    "hémicerveaux": ("hémicerveau",),
    "hemichromis": ("hemichromis",),
    "hémicidaris": ("hémicidaris",),
    "hémicorps": ("hémicorps",),
    "hémigrammus": ("hémigrammus",),
    "hémithorax": ("hémithorax",),
    "hémitruncus": ("hémitruncus",),
    "hemophilus": ("hemophilus",),
    "hémopneumothorax": ("hémopneumothorax",),
    "hémothorax": ("hémothorax",),
    "hendiadys": ("hendiadys",),
    "hépatopancréas": ("hépatopancréas",),
    "hérédosyphilis": ("hérédosyphilis",),
    "hereford": ("hereford",),
    "hermès": ("hermès",),
    "hernieuses": ("hernieux",),
    "hernieux": ("hernieux",),
    "héronneaux": ("héronneau",),
    "héroïnes": ("héros",),
    "héros": ("héros",),
    "herpès": ("herpès",),
    "herpèsvirus": ("herpèsvirus",),
    "herpétovirus": ("herpétovirus",),
    "hertz": ("hertz",),
    "hesperornis": ("hesperornis",),
    "hessoises": ("hessois",),
    "hessois": ("hessois",),
    "hétérakis": ("hétérakis",),
    "heterocerus": ("heterocerus",),
    "hétérops": ("hétérops",),
    "hétérosis": ("hétérosis",),
    "heux": ("heu",),
    "heures-lampes": ("heure-lampe",),
    "heureuses": ("heureux",),
    "heureux": ("heureux",),
    "hexacoralliaires-madréporaires": ("hexacoralliaire-madréporaire",),
    "hexacrinus": ("hexacrinus",),
    "hiatus": ("hiatus",),
    "hibiscus": ("hibiscus",),
    "hiboux": ("hibou",),
    "hic": ("hic",),
    "hiéroglyphus": ("hiéroglyphus",),
    "hiérolisthésis": ("hiérolisthésis",),
    "hifi": ("hifi",),
    "hildoceras": ("hildoceras",),
    "hippelates": ("hippelates",),
    "hippeus": ("hippeus",),
    "hippus": ("hippus",),
    "hircus": ("hircus",),
    "hirondeaux": ("hirondeau",),
    "histioteuthis": ("histioteuthis",),
    "h": ("h",),
    "hobbies": ("hobby",),
    "hobereaux": ("hobereau",),
    "holà": ("holà",),
    "holectypus": ("holectypus",),
    "holiday": ("holiday",),
    "hollandaises": ("hollandais",),
    "hollandais": ("hollandais",),
    "hollywood": ("hollywood",),
    "homalonotus": ("homalonotus",),
    "hommes-grenouilles": ("homme-grenouille",),
    "hommes-oiseaux": ("homme-oiseau",),
    "hommes-orchestres": ("homme-orchestre",),
    "hommes-sandwichs": ("homme-sandwich",),
    "homonculus": ("homonculus",),
    "hongkongaises": ("hongkongais",),
    "hongkongais": ("hongkongais",),
    "hongroises": ("hongrois",),
    "hongrois": ("hongrois",),
    "hôpitaux": ("hôpital",),
    "hoplites": ("hoplites",),
    "hoplopsyllus": ("hoplopsyllus",),
    "hôtels-restaurants": ("hôtel-restaurant",),
    "hotinus": ("hotinus",),
    "hottereaux": ("hottereau",),
    "hourdis": ("hourdis",),
    "houseaux": ("houseau",),
    "houx": ("houx",),
    "hoyaux": ("hoyau",),
    "hubert": ("hubert",),
    "huis": ("huis",),
    "huit": ("huit",),
    "humérus": ("humérus",),
    "humus": ("humus",),
    "huskies": ("husky",),
    "hus": ("hus",),
    "hutteaux": ("hutteau",),
    "hyalitis": ("hyalitis",),
    "hyalopterus": ("hyalopterus",),
    "hyas": ("hyas",),
    "hybos": ("hybos",),
    "hydaticus": ("hydaticus",),
    "hydatidothorax": ("hydatidothorax",),
    "hydramnios": ("hydramnios",),
    "hydraphaenops": ("hydraphaenops",),
    "hydrastis": ("hydrastis",),
    "hydrocolpos": ("hydrocolpos",),
    "hydropneumothorax": ("hydropneumothorax",),
    "hydrops": ("hydrops",),
    "hydrorachis": ("hydrorachis",),
    "hydrosalpinx": ("hydrosalpinx",),
    "hydrothorax": ("hydrothorax",),
    "hydryphantes": ("hydryphantes",),
    "hygrotus": ("hygrotus",),
    "hylambates": ("hylambates",),
    "hylobius": ("hylobius",),
    "hyperboréaux": ("hyperboréal",),
    "hypernerveuses": ("hypernerveux",),
    "hypernerveux": ("hypernerveux",),
    "hypernoyaux": ("hypernoyau",),
    "hyperolius": ("hyperolius",),
    "hypocras": ("hypocras",),
    "hypohippus": ("hypohippus",),
    "hypolaïs": ("hypolaïs",),
    "hypolimnas": ("hypolimnas",),
    "hypopharynx": ("hypopharynx",),
    "hypospadias": ("hypospadias",),
    "hypothalamus": ("hypothalamus",),
    "hyracothérium": ("hyracothérium",),
    "hystérésis": ("hystérésis",),
    "hystérocleisis": ("hystérocleisis",),
    "hystérostomatocleisis": ("hystérostomatocleisis",),
    "ibacus": ("ibacus",),
    "ibéris": ("ibéris",),
    "iberus": ("iberus",),
    "ibérus": ("ibérus",),
    "ibex": ("ibex",),
    "ibijaux": ("ibijau",),
    "ibiscus": ("ibiscus",),
    "ibis": ("ibis",),
    "ichthus": ("ichthus",),
    "ichthys": ("ichthys",),
    "ichtyophis": ("ichtyophis",),
    "ichtyornis": ("ichtyornis",),
    "ichtyotomus": ("ichtyotomus",),
    "ictus": ("ictus",),
    "idées-forces": ("idée-force",),
    "idiocerus": ("idiocerus",),
    "ilangs-ilangs": ("ilang-ilang",),
    "iléus": ("iléus",),
    "illaenus": ("illaenus",),
    "ilybius": ("ilybius",),
    "impatiens": ("impatiens",),
    "imperatores": ("imperator",),
    "imperial": ("imperial",),
    "imperia": ("imperium",),
    "imprimatur": ("imprimatur",),
    "inachus": ("inachus",),
    "incestueuses": ("incestueux",),
    "incestueux": ("incestueux",),
    "inches": ("inch",),
    "incipit": ("incipit",),
    "incirconcis": ("incirconcis",),
    "incomprises": ("incompris",),
    "incompris": ("incompris",),
    "incus": ("incus",),
    "indécises": ("indécis",),
    "indécis": ("indécis",),
    "index": ("index",),
    "indochinoises": ("indochinois",),
    "indochinois": ("indochinois",),
    "industries-clefs": ("industrie-clef",),
    "infarctus": ("infarctus",),
    "influx": ("influx",),
    "ingreux": ("ingreux",),
    "i": ("i",),
    "inlandsis": ("inlandsis",),
    "inox": ("inox",),
    "insomnieuses": ("insomnieux",),
    "insomnieux": ("insomnieux",),
    "insoumises": ("insoumis",),
    "insoumis": ("insoumis",),
    "instructions-machine": ("instruction-machine",),
    "instrumentaux": ("instrumental",),
    "insuccès": ("insuccès",),
    "intercours": ("intercours",),
    "interestrus": ("interestrus",),
    "internationales": ("international",),
    "internationaux": ("international",),
    "interoestrus": ("interoestrus",),
    "intersex": ("intersex",),
    "intox": ("intox",),
    "intrados": ("intrados",),
    "intramuraux": ("intramural",),
    "introït": ("introït",),
    "intruses": ("intrus",),
    "intrus": ("intrus",),
    "iota": ("iota",),
    "iphis": ("iphis",),
    "ips": ("ips",),
    "irbis": ("irbis",),
    "iridodonésis": ("iridodonésis",),
    "iridomyrmex": ("iridomyrmex",),
    "iridorrhexis": ("iridorrhexis",),
    "iridoschisis": ("iridoschisis",),
    "iris": ("iris",),
    "iritis": ("iritis",),
    "irlandaises": ("irlandais",),
    "irlandais": ("irlandais",),
    "iroquoises": ("iroquois",),
    "iroquois": ("iroquois",),
    "isatis": ("isatis",),
    "iséroises": ("isérois",),
    "isérois": ("isérois",),
    "isistius": ("isistius",),
    "islandaises": ("islandais",),
    "islandais": ("islandais",),
    "isoanticorps": ("isoanticorps",),
    "issus": ("issus",),
    "iveteaux": ("iveteau",),
    "ixodiphagus": ("ixodiphagus",),
    "jacobus": ("jacobus",),
    "jaconas": ("jaconas",),
    "jacques": ("jacques",),
    "jaïna": ("jaïna",),
    "jais": ("jais",),
    "jalouses": ("jaloux",),
    "jaloux": ("jaloux",),
    "jambonneaux": ("jambonneau",),
    "jamoytius": ("jamoytius",),
    "janiceps": ("janiceps",),
    "janus": ("janus",),
    "japonaises": ("japonais",),
    "japonais": ("japonais",),
    "japyx": ("japyx",),
    "jars": ("jars",),
    "jas": ("jas",),
    "jass": ("jass",),
    "jassus": ("jassus",),
    "jasus": ("jasus",),
    "jauneux": ("jauneux",),
    "javanaises": ("javanais",),
    "javanais": ("javanais",),
    "javeaux": ("javeau",),
    "jazzmen": ("jazzman",),
    "jazz": ("jazz",),
    "jeans": ("jeans",),
    "jerez": ("jerez",),
    "jérôme": ("jérôme",),
    "jersiaises": ("jersiais",),
    "jersiais": ("jersiais",),
    "jésus": ("jésus",),
    "jeux-concours": ("jeu-concours",),
    "jeux": ("jeu",),
    "jiao": ("jiao",),
    "jingoes": ("jingo",),
    "j": ("j",),
    "john": ("john",),
    "joseph": ("joseph",),
    "jottereaux": ("jottereau",),
    "jougris": ("jougris",),
    "joujoux": ("joujou",),
    "joules-seconde": ("joule-seconde",),
    "journaleuses": ("journaleux",),
    "journaleux": ("journaleux",),
    "journaux": ("journal",),
    "jouvenceaux": ("jouvenceau",),
    "jouvencelles": ("jouvenceau",),
    "joyaux": ("joyau",),
    "joyeux": ("joyeux",),
    "judas": ("judas",),
    "judéo-françaises": ("judéo-français",),
    "juke-boxes": ("juke-box",),
    "jules": ("jules",),
    "julodis": ("julodis",),
    "jumeaux": ("jumeaux",),
    "jumelles": ("jumeau",),
    "jurées-venderesses": ("juré-vendeur",),
    "jus": ("jus",),
    "justaucorps": ("justaucorps",),
    "juteux": ("juteux",),
    "kakatoès": ("kakatoès",),
    "kana": ("kana",),
    "kappa": ("kappa",),
    "karbaux": ("karbau",),
    "karma": ("karma",),
    "karman": ("karman",),
    "kazakhstan": ("kazakhstan",),
    "keo": ("keo",),
    "kérabaux": ("kérabau",),
    "kératomileusis": ("kératomileusis",),
    "kératonyxis": ("kératonyxis",),
    "kératosis": ("kératosis",),
    "kermès": ("kermès",),
    "ketchup": ("ketchup",),
    "khâgneuses": ("khâgneux",),
    "khâgneux": ("khâgneux",),
    "khi": ("khi",),
    "kibboutzim": ("kibboutz",),
    "kibboutz": ("kibboutz",),
    "kiev": ("kiev",),
    "kilogauss": ("kilogauss",),
    "kilohertz": ("kilohertz",),
    "kilomètres-heure": ("kilomètre-heure",),
    "kirghizes": ("kirghiz",),
    "kirghiz": ("kirghiz",),
    "kirsch": ("kirsch",),
    "kitsch": ("kitsch",),
    "klebs": ("klebs",),
    "kleenex": ("kleenex",),
    "k": ("k",),
    "kobez": ("kobez",),
    "kolkhoz": ("kolkhoz",),
    "ko": ("ko",),
    "koramius": ("koramius",),
    "korthals": ("korthals",),
    "kouros": ("kouros",),
    "kriss": ("kriss",),
    "kron": ("kron",),
    "kronprinz": ("kronprinz",),
    "kryptopterus": ("kryptopterus",),
    "ksour": ("ksar",),
    "ksi": ("ksi",),
    "kurus": ("kurus",),
    "kuvasz": ("kuvasz",),
    "kvas": ("kvas",),
    "kwas": ("kwas",),
    "kyrie": ("kyrie",),
    "kyudo": ("kyudo",),
    "labadens": ("labadens",),
    "laccobius": ("laccobius",),
    "lachesis": ("lachesis",),
    "lachnus": ("lachnus",),
    "lacis": ("lacis",),
    "lacs": ("lacs",),
    "lactobacillus": ("lactobacillus",),
    "ladies": ("lady",),
    "laemophloeus": ("laemophloeus",),
    "laemosthenus": ("laemosthenus",),
    "lagothrix": ("lagothrix",),
    "laguis": ("laguis",),
    "laïus": ("laïus",),
    "lambda": ("lambda",),
    "lambeaux": ("lambeau",),
    "lambis": ("lambis",),
    "lambris": ("lambris",),
    "lampas": ("lampas",),
    "lampes-projecteurs": ("lampe-projecteur",),
    "lampes-tempête": ("lampe-tempête",),
    "lampes-torches": ("lampe-torche",),
    "lampropeltis": ("lampropeltis",),
    "lancis": ("lancis",),
    "landaises": ("landais",),
    "landais": ("landais",),
    "langres": ("langres",),
    "langues-d'agneau": ("langue-d'agneau",),
    "lanistes": ("lanistes",),
    "la": ("la",),
    "läner": ("län",),
    "lanterneaux": ("lanterneau",),
    "laparoschisis": ("laparoschisis",),
    "lapereaux": ("lapereau",),
    "lapiaz": ("lapiaz",),
    "lapis": ("lapis",),
    "lapouge": ("lapouge",),
    "laps": ("laps",),
    "lapsus": ("lapsus",),
    "laquais": ("laquais",),
    "larinus": ("larinus",),
    "larmes-de-job": ("larme-de-job",),
    "larynx": ("larynx",),
    "lasiognathus": ("lasiognathus",),
    "lasius": ("lasius",),
    "las": ("las",),
    "lassis": ("lassis",),
    "lastex": ("lastex",),
    "latérocolis": ("latérocolis",),
    "latès": ("latès",),
    "latex": ("latex",),
    "latifundia": ("latifundium",),
    "latirus": ("latirus",),
    "lattis": ("lattis",),
    "laurent": ("laurent",),
    "lauriers camphriers": ("laurier-camphrier",),
    "lauriers-camphriers": ("laurier-camphrier",),
    "lauriers-roses": ("laurier-rose",),
    "lauriers-tins": ("laurier-tin",),
    "lauriers tulipiers": ("laurier-tulipier",),
    "lauriers-tulipiers": ("laurier-tulipier",),
    "lausannoises": ("lausannois",),
    "lausannois": ("lausannois",),
    "lavatories": ("lavatory",),
    "lave-tonneaux": ("lave-tonneau",),
    "lavis": ("lavis",),
    "lawrence": ("lawrence",),
    "lecythocrinus": ("lecythocrinus",),
    "leeds": ("leeds",),
    "legs": ("legs",),
    "leistus": ("leistus",),
    "lemniscus": ("lemniscus",),
    "lentigineuses": ("lentigineux",),
    "lentigineux": ("lentigineux",),
    "lentivirus": ("lentivirus",),
    "léonaises": ("léonais",),
    "léonais": ("léonais",),
    "léontiasis": ("léontiasis",),
    "leonurus": ("leonurus",),
    "lépidocyrtus": ("lépidocyrtus",),
    "lepidonotus": ("lepidonotus",),
    "lepidosaphes": ("lepidosaphes",),
    "lepidurus": ("lepidurus",),
    "lépothrix": ("lépothrix",),
    "lépreuses": ("lépreux",),
    "lépreux": ("lépreux",),
    "leptanillophilus": ("leptanillophilus",),
    "leptinus": ("leptinus",),
    "leptis": ("leptis",),
    "leptocheirus": ("leptocheirus",),
    "leptoconops": ("leptoconops",),
    "leptodirus": ("leptodirus",),
    "leptolepis": ("leptolepis",),
    "leptomonas": ("leptomonas",),
    "leptospirae": ("leptospira",),
    "leptothorax": ("leptothorax",),
    "leptothrix": ("leptothrix",),
    "lestes": ("lestes",),
    "lethocerus": ("lethocerus",),
    "lethrus": ("lethrus",),
    "leucopis": ("leucopis",),
    "leucospis": ("leucospis",),
    "leucovirus": ("leucovirus",),
    "lei": ("leu",),
    "levinea": ("levinea",),
    "leva": ("lev",),
    "lewis": ("lewis",),
    "lexis": ("lexis",),
    "liais": ("liais",),
    "lias": ("lias",),
    "libanaises": ("libanais",),
    "libanais": ("libanais",),
    "libérales": ("libéral",),
    "libéraux": ("libéral",),
    "libera": ("libera",),
    "libidineuses": ("libidineux",),
    "libidineux": ("libidineux",),
    "libido": ("libido",),
    "libres échangistes": ("libre-échangiste",),
    "libres-services": ("libre-service",),
    "libris": ("libris",),
    "licinus": ("licinus",),
    "lider": ("lider",),
    "liégeoises": ("liégeois",),
    "liégeois": ("liégeois",),
    "lieutenants-colonels": ("lieutenant-colonel",),
    "liguus": ("liguus",),
    "lilas": ("lilas",),
    "lille": ("lille",),
    "lilloises": ("lillois",),
    "lillois": ("lillois",),
    "limenitis": ("limenitis",),
    "limes": ("limes",),
    "limnephilus": ("limnephilus",),
    "limnobates": ("limnobates",),
    "limnophilus": ("limnophilus",),
    "limonius": ("limonius",),
    "limopsis": ("limopsis",),
    "limothrips": ("limothrips",),
    "lindorus": ("lindorus",),
    "lineus": ("lineus",),
    "linteaux": ("linteau",),
    "liocoris": ("liocoris",),
    "lionceaux": ("lionceau",),
    "lionotus": ("lionotus",),
    "liparis": ("liparis",),
    "liparocéras": ("liparocéras",),
    "liparus": ("liparus",),
    "liphistius": ("liphistius",),
    "liposcelis": ("liposcelis",),
    "lis": ("lis",),
    "lisseaux": ("lisseau",),
    "lissorhoptrus": ("lissorhoptrus",),
    "listeaux": ("listeau",),
    "lits-bateaux": ("lit-bateau",),
    "liteaux": ("liteau",),
    "lithocolletis": ("lithocolletis",),
    "lithomantis": ("lithomantis",),
    "lithops": ("lithops",),
    "litomastix": ("litomastix",),
    "littéraux": ("littéral",),
    "littoraux": ("littoral",),
    "lituus": ("lituus",),
    "livres-albums": ("livre-album",),
    "livrets-portefeuilles": ("livret-portefeuille",),
    "lixus": ("lixus",),
    "l": ("l",),
    "loasis": ("loasis",),
    "lobbies": ("lobby",),
    "lobites": ("lobites",),
    "lobomyces": ("lobomyces",),
    "lobosa": ("lobosa",),
    "locaux": ("local",),
    "loculi": ("loculus",),
    "loci": ("locus",),
    "loess": ("loess",),
    "logis": ("logis",),
    "logos": ("logos",),
    "lois-cadres": ("loi-cadre",),
    "lombricaux": ("lombrical",),
    "londrès": ("londrès",),
    "longs-bois": ("long-bois",),
    "longs métrages": ("long-métrage",),
    "longs-métrages": ("long-métrage",),
    "longues-vues": ("longue-vue",),
    "lophoptéryx": ("lophoptéryx",),
    "lop": ("lop",),
    "loqueteaux": ("loqueteau",),
    "lords-lieutenants": ("lord-lieutenant",),
    "lorientaises": ("lorientais",),
    "lorientais": ("lorientais",),
    "loris": ("loris",),
    "lorries": ("lorry",),
    "lotus": ("lotus",),
    "louises-bonnes": ("louise-bonne",),
    "louisianaises": ("louisianais",),
    "louisianais": ("louisianais",),
    "louisiannaises": ("louisiannais",),
    "louisiannais": ("louisiannais",),
    "louis": ("louis",),
    "loups-cerviers": ("loup-cervier",),
    "loups-garous": ("loup-garou",),
    "louveteaux": ("louveteau",),
    "lucernoises": ("lucernois",),
    "lucernois": ("lucernois",),
    "lumbriconereis": ("lumbriconereis",),
    "lupus": ("lupus",),
    "lurex": ("lurex",),
    "lutz": ("lutz",),
    "luxembourgeoises": ("luxembourgeois",),
    "luxembourgeois": ("luxembourgeois",),
    "lux": ("lux",),
    "lychnis": ("lychnis",),
    "lychnus": ("lychnus",),
    "lycus": ("lycus",),
    "lygaeus": ("lygaeus",),
    "lygus": ("lygus",),
    "lynx": ("lynx",),
    "lyonnaises": ("lyonnais",),
    "lyonnais": ("lyonnais",),
    "lysis": ("lysis",),
    "lys": ("lys",),
    "lyssavirus": ("lyssavirus",),
    "lytoceras": ("lytoceras",),
    "macareux": ("macareux",),
    "mâchicoulis": ("mâchicoulis",),
    "machimus": ("machimus",),
    "machines-outils": ("machine-outil",),
    "macis": ("macis",),
    "mâconnaises": ("mâconnais",),
    "mâconnais": ("mâconnais",),
    "macrocentrus": ("macrocentrus",),
    "macrocéphalites": ("macrocéphalites",),
    "macrocystis": ("macrocystis",),
    "macrolabis": ("macrolabis",),
    "macromeris": ("macromeris",),
    "macronuclei": ("macronucleus",),
    "macronucléus": ("macronucléus",),
    "macropocopris": ("macropocopris",),
    "macroscaphites": ("macroscaphites",),
    "macrotermes": ("macrotermes",),
    "mesdames": ("madame",),
    "madarosis": ("madarosis",),
    "madeleineaux": ("madeleineau",),
    "mesdemoiselles": ("mademoiselle",),
    "madras": ("madras",),
    "madrigaux": ("madrigal",),
    "maffieuses": ("maffieux",),
    "maffieux": ("maffieux",),
    "maffiosi": ("maffioso",),
    "mafieuses": ("mafieux",),
    "mafieux": ("mafieux",),
    "mafiosi": ("mafioso",),
    "magasins-souvenirs": ("magasin-souvenir",),
    "magdalinus": ("magdalinus",),
    "magilus": ("magilus",),
    "magnificat": ("magnificat",),
    "mail-coaches": ("mail-coach",),
    "mains-éponges": ("main-éponge",),
    "maïs": ("maïs",),
    "maîtres-queux": ("maître-queux",),
    "majoraux": ("majoral",),
    "makuta": ("makuta",),
    "malacosteus": ("malacosteus",),
    "malaises": ("malais",),
    "malais": ("malais",),
    "malapprises": ("malappris",),
    "malappris": ("malappris",),
    "malchanceuses": ("malchanceux",),
    "malchanceux": ("malchanceux",),
    "malheureuses": ("malheureux",),
    "malheureux": ("malheureux",),
    "malicieuses": ("malicieux",),
    "malicieux": ("malicieux",),
    "malines": ("malines",),
    "malinois": ("malinois",),
    "malles-cabines": ("malle-cabine",),
    "maux": ("mal",),
    "maltaises": ("maltais",),
    "maltais": ("maltais",),
    "malthinus": ("malthinus",),
    "malthodes": ("malthodes",),
    "malurus": ("malurus",),
    "malus": ("malus",),
    "mammies": ("mammy",),
    "mamies": ("mamy",),
    "manceaux": ("manceau",),
    "mancelles": ("manceau",),
    "manceps": ("manceps",),
    "mandats-cartes": ("mandat-carte",),
    "mandats-poste": ("mandat-poste",),
    "mangonneaux": ("mangonneau",),
    "maniaco-dépressives": ("maniaco-dépressif",),
    "manteaux": ("manteau",),
    "mantra": ("mantra",),
    "manxoises": ("manxois",),
    "manxois": ("manxois",),
    "maquereaux": ("maquereau",),
    "maquerelles": ("maquereau",),
    "maquis": ("maquis",),
    "marais": ("marais",),
    "maravédis": ("maravédis",),
    "marchands-diplomates": ("marchand-diplomate",),
    "marchandes-lunetières": ("marchand-lunetier",),
    "marcheuses": ("marcheux",),
    "marcheux": ("marcheux",),
    "maréchales": ("maréchal",),
    "maréchaux": ("maréchal",),
    "marennes": ("marennes",),
    "margaritana": ("margaritana",),
    "margarites": ("margarites",),
    "margaritifera": ("margaritifera",),
    "margarodes": ("margarodes",),
    "marginales": ("marginal",),
    "marginaux": ("marginal",),
    "margis": ("margis",),
    "margouillis": ("margouillis",),
    "maries-salopes": ("marie-salope",),
    "marins-pêcheurs": ("marin-pêcheur",),
    "markkaa": ("markka",),
    "marmenteaux": ("marmenteau",),
    "maroilles": ("maroilles",),
    "marquises": ("marquis",),
    "marquis": ("marquis",),
    "marseaux": ("marseau",),
    "marseillaises": ("marseillais",),
    "marseillais": ("marseillais",),
    "mars": ("mars",),
    "marsupiaux": ("marsupial",),
    "marsupiocrinus": ("marsupiocrinus",),
    "marsupites": ("marsupites",),
    "marteaux": ("marteau",),
    "marteaux-pilons": ("marteau-pilon",),
    "marteaux-piqueurs": ("marteau-piqueur",),
    "martini": ("martini",),
    "martiniquaises": ("martiniquais",),
    "martiniquais": ("martiniquais",),
    "martins-pêcheurs": ("martin-pêcheur",),
    "marxistes-léninistes": ("marxiste-léniniste",),
    "masaris": ("masaris",),
    "mas": ("mas",),
    "mastix": ("mastix",),
    "mastotermes": ("mastotermes",),
    "matelas": ("matelas",),
    "mâtereaux": ("mâtereau",),
    "matériaux": ("matériau",),
    "mâts-grue": ("mât-grue",),
    "matheuses": ("matheux",),
    "matheux": ("matheux",),
    "matoises": ("matois",),
    "matois": ("matois",),
    "matos": ("matos",),
    "matras": ("matras",),
    "matsucoccus": ("matsucoccus",),
    "mauvaises": ("mauvais",),
    "mauvais": ("mauvais",),
    "mauvis": ("mauvis",),
    "max": ("max",),
    "mécaniciennes-dentistes": ("mécanicien-dentiste",),
    "mecinus": ("mecinus",),
    "mecklembourgeoises": ("mecklembourgeois",),
    "mecklembourgeois": ("mecklembourgeois",),
    "médecins-capitaines": ("médecin-capitaine",),
    "médecins-chefs": ("médecin-chef",),
    "médecins-colonels": ("médecin-colonel",),
    "médecins-conseils": ("médecin-conseil",),
    "médiolittoraux": ("médiolittoral",),
    "médius": ("médius",),
    "mégacéros": ("mégacéros",),
    "mégacristaux": ("mégacristal",),
    "mégagauss": ("mégagauss",),
    "mégahertz": ("mégahertz",),
    "mégalopolis": ("mégalopolis",),
    "mégalothymus": ("mégalothymus",),
    "mégalovirus": ("mégalovirus",),
    "mégis": ("mégis",),
    "mélanitis": ("mélanitis",),
    "meldoises": ("meldois",),
    "meldois": ("meldois",),
    "melianthus": ("melianthus",),
    "meliboeus": ("meliboeus",),
    "mélicéris": ("mélicéris",),
    "melitta": ("melitta",),
    "mélocactus": ("mélocactus",),
    "melocrinus": ("melocrinus",),
    "melonechinus": ("melonechinus",),
    "melonites": ("melonites",),
    "mélops": ("mélops",),
    "mémoriaux": ("mémorial",),
    "meneaux": ("meneau",),
    "menehould": ("menehould",),
    "menneus": ("menneus",),
    "menus-vairs": ("menu-vair",),
    "mépris": ("mépris",),
    "mercurey": ("mercurey",),
    "merdeuses": ("merdeux",),
    "merdeux": ("merdeux",),
    "mères-grand": ("mère-grand",),
    "mérens": ("mérens",),
    "mères-poules": ("mère-poule",),
    "meretrix": ("meretrix",),
    "merguez": ("merguez",),
    "méridionales": ("méridional",),
    "méridionaux": ("méridional",),
    "mérinos": ("mérinos",),
    "merleaux": ("merleau",),
    "merlus": ("merlus",),
    "mermis": ("mermis",),
    "merveilleuses": ("merveilleux",),
    "merveilleux": ("merveilleux",),
    "merychippus": ("merychippus",),
    "mésocortex": ("mésocortex",),
    "mésohippus": ("mésohippus",),
    "mésonéphros": ("mésonéphros",),
    "mésosalpinx": ("mésosalpinx",),
    "mésothorax": ("mésothorax",),
    "mess": ("mess",),
    "métacrinus": ("métacrinus",),
    "métadiscours": ("métadiscours",),
    "métaux": ("métal",),
    "métamyxovirus": ("métamyxovirus",),
    "métanéphros": ("métanéphros",),
    "métaphycus": ("métaphycus",),
    "métathorax": ("métathorax",),
    "métestrus": ("métestrus",),
    "méticuleuses": ("méticuleux",),
    "méticuleux": ("méticuleux",),
    "métis": ("métis",),
    "métisses": ("métis",),
    "métoestrus": ("métoestrus",),
    "metopus": ("metopus",),
    "mètres-newton": ("mètre-newton",),
    "métreuses-vérificatrices": ("métreur-vérificateur",),
    "mets": ("mets",),
    "meursault": ("meursault",),
    "mex": ("mex",),
    "mezzotinto": ("mezzotinto",),
    "microbus": ("microbus",),
    "micrococci": ("micrococcus",),
    "microcristaux": ("microcristal",),
    "microdeutopus": ("microdeutopus",),
    "micromalthus": ("micromalthus",),
    "micronuclei": ("micronucleus",),
    "micronucléus": ("micronucléus",),
    "microphallus": ("microphallus",),
    "micropteryx": ("micropteryx",),
    "micropuits": ("micropuits",),
    "micrurus": ("micrurus",),
    "mictis": ("mictis",),
    "midshipmen": ("midshipman",),
    "mieux": ("mieux",),
    "migraineuses": ("migraineux",),
    "migraineux": ("migraineux",),
    "mihrab": ("mihrab",),
    "milanaises": ("milanais",),
    "milanais": ("milanais",),
    "milaneaux": ("milaneau",),
    "milieux": ("milieu",),
    "millas": ("millas",),
    "millepertuis": ("millepertuis",),
    "milleraies": ("milleraies",),
    "millericrinus": ("millericrinus",),
    "mimetus": ("mimetus",),
    "mimulus": ("mimulus",),
    "mindarus": ("mindarus",),
    "minéraliers-pétroliers": ("minéralier-pétrolier",),
    "minéraux": ("minéral",),
    "minervois": ("minervois",),
    "minibus": ("minibus",),
    "mi": ("mi",),
    "minnesänger": ("minnesänger",),
    "min": ("min",),
    "minois": ("minois",),
    "minus": ("minus",),
    "minutieuses": ("minutieux",),
    "minutieux": ("minutieux",),
    "miogéosynclinaux": ("miogéosynclinal",),
    "miohippus": ("miohippus",),
    "miosis": ("miosis",),
    "mirabilis": ("mirabilis",),
    "mirepoix": ("mirepoix",),
    "miridius": ("miridius",),
    "miris": ("miris",),
    "mischmétaux": ("mischmétal",),
    "miserere": ("miserere",),
    "miséréré": ("miséréré",),
    "miséreuses": ("miséreux",),
    "miséreux": ("miséreux",),
    "miss": ("miss",),
    "miteuses": ("miteux",),
    "miteux": ("miteux",),
    "m": ("m",),
    "modaux": ("modal",),
    "moineaux": ("moineau",),
    "moins": ("moins",),
    "mois": ("mois",),
    "molophilus": ("molophilus",),
    "monceaux": ("monceau",),
    "möngö": ("möngö",),
    "mongoz": ("mongoz",),
    "monias": ("monias",),
    "monilethrix": ("monilethrix",),
    "moniléthrix": ("moniléthrix",),
    "monocélis": ("monocélis",),
    "monocercomonas": ("monocercomonas",),
    "monoclinaux": ("monoclinal",),
    "monocristaux": ("monocristal",),
    "monognathus": ("monognathus",),
    "monograptus": ("monograptus",),
    "monohammus": ("monohammus",),
    "monophlebus": ("monophlebus",),
    "monoprix": ("monoprix",),
    "monotis": ("monotis",),
    "monox": ("monox",),
    "messeigneurs": ("monseigneur",),
    "messieurs": ("monsieur",),
    "monsignori": ("monsignore",),
    "monsignores": ("monsignor",),
    "montagnaises": ("montagnais",),
    "montagnais": ("montagnais",),
    "montalbanaises": ("montalbanais",),
    "montalbanais": ("montalbanais",),
    "monteuses-ajusteuses": ("monteur-ajusteur",),
    "montmartroises": ("montmartrois",),
    "montmartrois": ("montmartrois",),
    "montmorency": ("montmorency",),
    "montréalaises": ("montréalais",),
    "montréalais": ("montréalais",),
    "morbillivirus": ("morbillivirus",),
    "morbus": ("morbus",),
    "morceaux": ("morceau",),
    "mor": ("mor",),
    "mors": ("mors",),
    "mortiers-éprouvettes": ("mortier-éprouvette",),
    "morvandeaux": ("morvandeau",),
    "morvandelles": ("morvandeau",),
    "morveuses": ("morveux",),
    "morveux": ("morveux",),
    "moskova": ("moskova",),
    "moskva": ("moskva",),
    "mots-centres": ("mot-centre",),
    "mots-clés": ("mot-clé",),
    "moto-cross": ("motocross",),
    "motocross": ("motocross",),
    "mots-témoins": ("mot-témoin",),
    "motteux": ("motteux",),
    "moucharabieh": ("moucharabieh",),
    "mouchetis": ("mouchetis",),
    "moudjahidin": ("moudjahid",),
    "moukhabarat": ("moukhabarat",),
    "mouleaux": ("mouleau",),
    "mousseux": ("mousseux",),
    "moyeux": ("moyeu",),
    "mucus": ("mucus",),
    "mudéjar": ("mudéjar",),
    "mudpuppies": ("mudpuppy",),
    "multicanaux": ("multicanal",),
    "multiplex": ("multiplex",),
    "multisalles": ("multisalles",),
    "munichoises": ("munichois",),
    "munichois": ("munichois",),
    "munidopsis": ("munidopsis",),
    "mu": ("mu",),
    "murs-écrans": ("mur-écran",),
    "murex": ("murex",),
    "museaux": ("museau",),
    "myas": ("myas",),
    "mycosis": ("mycosis",),
    "mydas": ("mydas",),
    "myélophilus": ("myélophilus",),
    "myélorachischisis": ("myélorachischisis",),
    "myitis": ("myitis",),
    "myosciurus": ("myosciurus",),
    "myosis": ("myosis",),
    "myosotis": ("myosotis",),
    "myotis": ("myotis",),
    "mysis": ("mysis",),
    "mytilaspis": ("mytilaspis",),
    "myxoedémateuses": ("myxoedémateux",),
    "myxoedémateux": ("myxoedémateux",),
    "myxovirus": ("myxovirus",),
    "myzus": ("myzus",),
    "nabis": ("nabis",),
    "naevi": ("naevus",),
    "nairovirus": ("nairovirus",),
    "naïs": ("naïs",),
    "nanoréseaux": ("nanoréseau",),
    "nantaises": ("nantais",),
    "nantais": ("nantais",),
    "naos": ("naos",),
    "napeocles": ("napeocles",),
    "narodniki": ("narodnik",),
    "narodovoltsy": ("narodovolets",),
    "narthex": ("narthex",),
    "naseaux": ("naseau",),
    "nasopharynx": ("nasopharynx",),
    "nassarius": ("nassarius",),
    "nassellaria": ("nassellaria",),
    "nasutitermes": ("nasutitermes",),
    "naticopsis": ("naticopsis",),
    "nauplius": ("nauplius",),
    "navarraises": ("navarrais",),
    "navarrais": ("navarrais",),
    "navicert": ("navicert",),
    "navires-bases": ("navire-base",),
    "navires-écoles": ("navire-école",),
    "navires-majors": ("navire-major",),
    "nécessiteuses": ("nécessiteux",),
    "nécessiteux": ("nécessiteux",),
    "néerlandaises": ("néerlandais",),
    "néerlandais": ("néerlandais",),
    "négus": ("négus",),
    "nemeritis": ("nemeritis",),
    "némichthys": ("némichthys",),
    "nemoscolus": ("nemoscolus",),
    "némotélus": ("némotélus",),
    "neoceratodus": ("neoceratodus",),
    "néocortex": ("néocortex",),
    "néo-libérales": ("néolibéral",),
    "néo-libéraux": ("néolibéral",),
    "néolibérales": ("néolibéral",),
    "néolibéraux": ("néolibéral",),
    "néorurales": ("néorural",),
    "néoruraux": ("néorural",),
    "néovaisseaux": ("néovaisseau",),
    "népalaises": ("népalais",),
    "népalais": ("népalais",),
    "népenthès": ("népenthès",),
    "nephthys": ("nephthys",),
    "néréis": ("néréis",),
    "néritopsis": ("néritopsis",),
    "nérophis": ("nérophis",),
    "nerveuses": ("nerveux",),
    "nerveux": ("nerveux",),
    "nervotabès": ("nervotabès",),
    "nesticus": ("nesticus",),
    "netsuke": ("netsuke",),
    "netsuké": ("netsuké",),
    "neuf": ("neuf",),
    "neurosyphilis": ("neurosyphilis",),
    "neurotabès": ("neurotabès",),
    "neuroterus": ("neuroterus",),
    "neurotmésis": ("neurotmésis",),
    "neveux": ("neveu",),
    "newport": ("newport",),
    "new-yorkaises": ("new-yorkais",),
    "nez": ("nez",),
    "niaises": ("niais",),
    "niais": ("niais",),
    "nicaraguaises": ("nicaraguais",),
    "nicaraguais": ("nicaraguais",),
    "nicheux": ("nicheux",),
    "nicholas": ("nicholas",),
    "nicobaraises": ("nicobarais",),
    "nicobarais": ("nicobarais",),
    "niçoises": ("niçois",),
    "niçois": ("niçois",),
    "nikita": ("nikita",),
    "nimbostratus": ("nimbostratus",),
    "nimbus": ("nimbus",),
    "nîmoises": ("nîmois",),
    "nîmois": ("nîmois",),
    "ninas": ("ninas",),
    "niphargus": ("niphargus",),
    "nisoniades": ("nisoniades",),
    "nitrates-fuels": ("nitrate-fuel",),
    "nitrosomonas": ("nitrosomonas",),
    "niveaux": ("niveau",),
    "nivernaises": ("nivernais",),
    "nivernais": ("nivernais",),
    "n": ("n",),
    "nobliaux": ("nobliau",),
    "nodus": ("nodus",),
    "noix": ("noix",),
    "nolis": ("nolis",),
    "nomadacris": ("nomadacris",),
    "nominaux": ("nominal",),
    "nomophylax": ("nomophylax",),
    "non-belligérantes": ("non-belligérant",),
    "non comparants": ("non-comparant",),
    "non-émotives": ("non-émotif",),
    "non-lieux": ("non-lieu",),
    "non-métaux": ("non-métal",),
    "non": ("non",),
    "no": ("no",),
    "nô": ("nô",),
    "nops": ("nops",),
    "normes-planchers": ("norme-plancher",),
    "norois": ("norois",),
    "norrois": ("norrois",),
    "nota": ("nota",),
    "notaspis": ("notaspis",),
    "noterus": ("noterus",),
    "nothofagus": ("nothofagus",),
    "nothrus": ("nothrus",),
    "notiophilus": ("notiophilus",),
    "notomastus": ("notomastus",),
    "notornis": ("notornis",),
    "nounours": ("nounours",),
    "nouveaux-nés": ("nouveau-né",),
    "nouveaux": ("nouveau",),
    "nouvelles": ("nouveau",),
    "nova": ("nova",),
    "novae": ("nova",),
    "novius": ("novius",),
    "noyaux": ("noyau",),
    "nucléocrinus": ("nucléocrinus",),
    "nuclei": ("nucleus",),
    "nucléus": ("nucléus",),
    "nues-propriétés": ("nue-propriété",),
    "numéraux": ("numéral",),
    "numeri": ("numerus",),
    "nuraghi": ("nuraghe",),
    "nurseries": ("nursery",),
    "nyctinomus": ("nyctinomus",),
    "nysius": ("nysius",),
    "nystagmus": ("nystagmus",),
    "oaristys": ("oaristys",),
    "oasis": ("oasis",),
    "obstétriciennes-accoucheuses": ("obstétricien-accoucheur",),
    "obus": ("obus",),
    "obvers": ("obvers",),
    "occidentales": ("occidental",),
    "occidentaux": ("occidental",),
    "occipitaux": ("occipital",),
    "ochrops": ("ochrops",),
    "ochrosis": ("ochrosis",),
    "ocnus": ("ocnus",),
    "octaux": ("octal",),
    "oculi": ("oculus",),
    "odiellus": ("odiellus",),
    "odonestis": ("odonestis",),
    "odontolabis": ("odontolabis",),
    "odontoscélis": ("odontoscélis",),
    "oeils-de-chat": ("oeil-de-chat",),
    "oeils-de-pie": ("oeil-de-pie",),
    "oeils-de-serpent": ("oeil-de-serpent",),
    "oeneis": ("oeneis",),
    "oestrus": ("oestrus",),
    "officiaux": ("official",),
    "officiers-conseils": ("officier-conseil",),
    "officiers-mariniers": ("officier-marinier",),
    "offset": ("offset",),
    "oiseaux-bouchers": ("oiseau-boucher",),
    "oiseaux": ("oiseau",),
    "oiseaux-satin": ("oiseau-satin",),
    "oiseaux-souris": ("oiseau-souris",),
    "oléagineux": ("oléagineux",),
    "olenellus": ("olenellus",),
    "olenus": ("olenus",),
    "oléoprotéagineux": ("oléoprotéagineux",),
    "oléorésineux": ("oléorésineux",),
    "olethreutes": ("olethreutes",),
    "olibrius": ("olibrius",),
    "olibrus": ("olibrus",),
    "oligohydramnios": ("oligohydramnios",),
    "oligolophus": ("oligolophus",),
    "oligotrophus": ("oligotrophus",),
    "olim": ("olim",),
    "olios": ("olios",),
    "olynthus": ("olynthus",),
    "omanaises": ("omanais",),
    "omanais": ("omanais",),
    "oméga": ("oméga",),
    "omicron": ("omicron",),
    "omis": ("omis",),
    "omnibus": ("omnibus",),
    "oncocephalus": ("oncocephalus",),
    "oncoceras": ("oncoceras",),
    "oncornavirus": ("oncornavirus",),
    "oncovirus": ("oncovirus",),
    "oneirophantites": ("oneirophantites",),
    "oniscus": ("oniscus",),
    "onitis": ("onitis",),
    "o": ("o",),
    "onychauxis": ("onychauxis",),
    "onychorrhexis": ("onychorrhexis",),
    "onychoteuthis": ("onychoteuthis",),
    "onyxis": ("onyxis",),
    "onyx": ("onyx",),
    "onze": ("onze",),
    "oodes": ("oodes",),
    "ooencyrtus": ("ooencyrtus",),
    "oonops": ("oonops",),
    "oophoritis": ("oophoritis",),
    "opéras-ballets": ("opéra-ballet",),
    "opéras-oratorios": ("opéra-oratorio",),
    "ophiasis": ("ophiasis",),
    "ophiopluteus": ("ophiopluteus",),
    "ophrys": ("ophrys",),
    "ophtalmitis": ("ophtalmitis",),
    "ophtalmotonus": ("ophtalmotonus",),
    "ophthalmicus": ("ophthalmicus",),
    "opis": ("opis",),
    "opisthograptis": ("opisthograptis",),
    "opisthotonos": ("opisthotonos",),
    "opius": ("opius",),
    "opodeldoch": ("opodeldoch",),
    "opopanax": ("opopanax",),
    "opus": ("opus",),
    "oraux": ("oral",),
    "oranaises": ("oranais",),
    "oranais": ("oranais",),
    "orangemerix": ("orangemerix",),
    "orbivirus": ("orbivirus",),
    "orchis": ("orchis",),
    "ordo": ("ordo",),
    "oréas": ("oréas",),
    "oreilles d'âne": ("oreille-d'âne",),
    "oreilles de judas": ("oreille-de-judas",),
    "oreilles-d'éléphant": ("oreille-d'éléphant",),
    "oreilles de loup": ("oreille-de-loup",),
    "oreilles-d'homme": ("oreille-d'homme",),
    "orémus": ("orémus",),
    "öre": ("öre",),
    "organeaux": ("organeau",),
    "organoarsenicaux": ("organoarsenical",),
    "organocuivreux": ("organocuivreux",),
    "orgueilleuses": ("orgueilleux",),
    "orgueilleux": ("orgueilleux",),
    "oribus": ("oribus",),
    "orientales": ("oriental",),
    "orientaux": ("oriental",),
    "originales": ("original",),
    "originaux": ("original",),
    "orignaux": ("orignal",),
    "oripeaux": ("oripeau",),
    "orizaephilus": ("orizaephilus",),
    "orléanaises": ("orléanais",),
    "orléanais": ("orléanais",),
    "ormeaux": ("ormeau",),
    "ornithodorus": ("ornithodorus",),
    "ornix": ("ornix",),
    "orobitis": ("orobitis",),
    "orohippus": ("orohippus",),
    "oropharynx": ("oropharynx",),
    "orthalicus": ("orthalicus",),
    "orthoceras": ("orthoceras",),
    "orthomyxovirus": ("orthomyxovirus",),
    "orthopoxvirus": ("orthopoxvirus",),
    "orthotonos": ("orthotonos",),
    "orthotylus": ("orthotylus",),
    "oryx": ("oryx",),
    "oryzomys": ("oryzomys",),
    "os": ("os",),
    "osteogenesis": ("osteogenesis",),
    "osteolepis": ("osteolepis",),
    "osteopsathyrosis": ("osteopsathyrosis",),
    "ostraca": ("ostracon",),
    "othius": ("othius",),
    "otochalasis": ("otochalasis",),
    "ouas": ("ouas",),
    "oublieuses": ("oublieux",),
    "oublieux": ("oublieux",),
    "ouest-allemandes": ("ouest-allemand",),
    "ougandaises": ("ougandais",),
    "ougandais": ("ougandais",),
    "oui": ("oui",),
    "ourses": ("ours",),
    "ours": ("ours",),
    "outardeaux": ("outardeau",),
    "outcross": ("outcross",),
    "ouvreaux": ("ouvreau",),
    "ouvrières-façonnières": ("ouvrier-façonnier",),
    "ouvriers-façonniers": ("ouvrier-façonnier",),
    "ovibos": ("ovibos",),
    "ovotestis": ("ovotestis",),
    "oxalis": ("oxalis",),
    "oxymirus": ("oxymirus",),
    "oxynoticeras": ("oxynoticeras",),
    "oxyrachis": ("oxyrachis",),
    "oxyuriasis": ("oxyuriasis",),
    "ozéneuses": ("ozéneux",),
    "ozéneux": ("ozéneux",),
    "pacaschas": ("pacaschas",),
    "pachydiscus": ("pachydiscus",),
    "pachyonyxis": ("pachyonyxis",),
    "pachyrhizus": ("pachyrhizus",),
    "pachyuromys": ("pachyuromys",),
    "pacific": ("pacific",),
    "pacs": ("pacs",),
    "paddies": ("paddy",),
    "pageaux": ("pageau",),
    "pagus": ("pagus",),
    "paillis": ("paillis",),
    "paintbox": ("paintbox",),
    "paisseaux": ("paisseau",),
    "paix": ("paix",),
    "pakistanaises": ("pakistanais",),
    "pakistanais": ("pakistanais",),
    "palaeechinus": ("palaeechinus",),
    "palaeophonus": ("palaeophonus",),
    "palais": ("palais",),
    "paléocortex": ("paléocortex",),
    "paléomilieux": ("paléomilieu",),
    "paleoniscus": ("paleoniscus",),
    "paléoniscus": ("paléoniscus",),
    "paléophis": ("paléophis",),
    "paléornis": ("paléornis",),
    "paléothalamus": ("paléothalamus",),
    "palinurus": ("palinurus",),
    "palis": ("palis",),
    "palmarès": ("palmarès",),
    "palmatopteris": ("palmatopteris",),
    "palmiers-dattiers": ("palmier-dattier",),
    "palmipes": ("palmipes",),
    "paloises": ("palois",),
    "palois": ("palois",),
    "palonneaux": ("palonneau",),
    "paludomus": ("paludomus",),
    "palus": ("palus",),
    "panais": ("panais",),
    "pananticorps": ("pananticorps",),
    "panaris": ("panaris",),
    "panax": ("panax",),
    "panchax": ("panchax",),
    "pancréas": ("pancréas",),
    "pandanus": ("pandanus",),
    "pandinus": ("pandinus",),
    "panneaux": ("panneau",),
    "pannus": ("pannus",),
    "panonceaux": ("panonceau",),
    "panops": ("panops",),
    "paonneaux": ("paonneau",),
    "paparazzi": ("paparazzo",),
    "papas": ("papas",),
    "papillomavirus": ("papillomavirus",),
    "papovavirus": ("papovavirus",),
    "papies": ("papy",),
    "papyrus": ("papyrus",),
    "paquis": ("paquis",),
    "parabasaux": ("parabasal",),
    "paradis": ("paradis",),
    "parados": ("parados",),
    "paradoxides": ("paradoxides",),
    "paragneiss": ("paragneiss",),
    "paragonimiasis": ("paragonimiasis",),
    "paragonimus": ("paragonimus",),
    "parakeratosis": ("parakeratosis",),
    "paramount": ("paramount",),
    "paramyoclonus": ("paramyoclonus",),
    "paramyxovirus": ("paramyxovirus",),
    "paranucléus": ("paranucléus",),
    "paraphimosis": ("paraphimosis",),
    "paraphrénitis": ("paraphrénitis",),
    "paraponyx": ("paraponyx",),
    "parapoxvirus": ("parapoxvirus",),
    "parapsoriasis": ("parapsoriasis",),
    "paratyphus": ("paratyphus",),
    "parcorps": ("parcorps",),
    "parcours": ("parcours",),
    "pardanthus": ("pardanthus",),
    "pardessus": ("pardessus",),
    "paresseuses": ("paresseux",),
    "paresseux": ("paresseux",),
    "pariétaux": ("pariétal",),
    "park": ("park",),
    "parodontis": ("parodontis",),
    "paros": ("paros",),
    "partageuses": ("partageux",),
    "partageux": ("partageux",),
    "party": ("party",),
    "parties": ("party",),
    "parvis": ("parvis",),
    "parvovirus": ("parvovirus",),
    "pascals-seconde": ("pascal-seconde",),
    "pasdaran": ("pasdar",),
    "pas": ("pas",),
    "passereaux": ("passereau",),
    "pastis": ("pastis",),
    "pastoureaux": ("pastoureau",),
    "pastourelles": ("pastoureau",),
    "pataquès": ("pataquès",),
    "pataras": ("pataras",),
    "patas": ("patas",),
    "pater-familias": ("paterfamilias",),
    "paterfamilias": ("paterfamilias",),
    "pater": ("pater",),
    "pathos": ("pathos",),
    "pâtiras": ("pâtiras",),
    "pâtis": ("pâtis",),
    "pât": ("pât",),
    "patouillis": ("patouillis",),
    "pattes-de-chat": ("patte-de-chat",),
    "pattes-de-loup": ("patte-de-loup",),
    "pattes-nageoires": ("patte-nageoire",),
    "pauses-café": ("pause-café",),
    "paussus": ("paussus",),
    "pavois": ("pavois",),
    "payses": ("pays",),
    "pays": ("pays",),
    "pearl": ("pearl",),
    "peaux": ("peau",),
    "peaux-rouges": ("peau-rouge",),
    "pécoptéris": ("pécoptéris",),
    "pectoraux": ("pectoral",),
    "pectus": ("pectus",),
    "pédinus": ("pédinus",),
    "pediopsis": ("pediopsis",),
    "pédocaux": ("pédocal",),
    "peintres graveurs": ("peintre-graveur",),
    "peintres-graveurs": ("peintre-graveur",),
    "peintres pistoleurs": ("peintre-pistoleur",),
    "peintres-verriers": ("peintre-verrier",),
    "pékinoises": ("pékinois",),
    "pékinois": ("pékinois",),
    "pelagos": ("pelagos",),
    "pellagreuses": ("pellagreux",),
    "pellagreux": ("pellagreux",),
    "peloscolex": ("peloscolex",),
    "peltoceras": ("peltoceras",),
    "pelvis": ("pelvis",),
    "pemphigus": ("pemphigus",),
    "pemphix": ("pemphix",),
    "penaeus": ("penaeus",),
    "penicillus": ("penicillus",),
    "pénis": ("pénis",),
    "pénitis": ("pénitis",),
    "pennia": ("penni",),
    "pence": ("penny",),
    "pennies": ("penny",),
    "pentremites": ("pentremites",),
    "people": ("people",),
    "péplos": ("péplos",),
    "pepsis": ("pepsis",),
    "peptococcus": ("peptococcus",),
    "peptostreptococcus": ("peptostreptococcus",),
    "péray": ("péray",),
    "perchis": ("perchis",),
    "perchmen": ("perchman",),
    "perdreaux": ("perdreau",),
    "perdrix": ("perdrix",),
    "perfect": ("perfect",),
    "perfringens": ("perfringens",),
    "periadenitis": ("periadenitis",),
    "périgueux": ("périgueux",),
    "périnéréis": ("périnéréis",),
    "périonyxis": ("périonyxis",),
    "péripolésis": ("péripolésis",),
    "périsphinctes": ("périsphinctes",),
    "peritelus": ("peritelus",),
    "permanentistes-coloristes": ("permanentiste-coloriste",),
    "permis": ("permis",),
    "pernod": ("pernod",),
    "pertuis": ("pertuis",),
    "perverses": ("pervers",),
    "pervers": ("pervers",),
    "pestivirus": ("pestivirus",),
    "pétasites": ("pétasites",),
    "pétersbourgeoises": ("pétersbourgeois",),
    "pétersbourgeois": ("pétersbourgeois",),
    "pètesec": ("pètesec",),
    "péteuses": ("péteux",),
    "péteux": ("péteux",),
    "petits-beurres": ("petit-beurre",),
    "petites-bourgeoises": ("petit-bourgeois",),
    "petites-filles": ("petite-fille",),
    "petites-nièces": ("petite-nièce",),
    "petits-fers": ("petit-fer",),
    "petits-fils": ("petit-fils",),
    "petits fours": ("petit-four",),
    "petits-fours": ("petit-four",),
    "petits-grains": ("petit-grain",),
    "petits-gris": ("petit-gris",),
    "petits-maîtres": ("petit-maître",),
    "petits-suisses": ("petit-suisse",),
    "peureuses": ("peureux",),
    "peureux": ("peureux",),
    "phacoérisis": ("phacoérisis",),
    "phacops": ("phacops",),
    "phacus": ("phacus",),
    "phaeogenes": ("phaeogenes",),
    "phaius": ("phaius",),
    "phajus": ("phajus",),
    "phalaenopsis": ("phalaenopsis",),
    "phallus": ("phallus",),
    "pharmacophagus": ("pharmacophagus",),
    "pharynx": ("pharynx",),
    "phénacodus": ("phénacodus",),
    "phenax": ("phenax",),
    "phénix": ("phénix",),
    "phénocristaux": ("phénocristal",),
    "philhydrus": ("philhydrus",),
    "phillips": ("phillips",),
    "philodromus": ("philodromus",),
    "philonicus": ("philonicus",),
    "phimosis": ("phimosis",),
    "phi": ("phi",),
    "phlebovirus": ("phlebovirus",),
    "phlébovirus": ("phlébovirus",),
    "phléothrips": ("phléothrips",),
    "phlox": ("phlox",),
    "ph": ("ph",),
    "phoenix": ("phoenix",),
    "phororhachos": ("phororhachos",),
    "photinus": ("photinus",),
    "photos-robots": ("photo-robot",),
    "phractolaemus": ("phractolaemus",),
    "phragmoceras": ("phragmoceras",),
    "phtiriasis": ("phtiriasis",),
    "phtirius": ("phtirius",),
    "phylloceras": ("phylloceras",),
    "phylloptéryx": ("phylloptéryx",),
    "physalis": ("physalis",),
    "physopsis": ("physopsis",),
    "phytéléphas": ("phytéléphas",),
    "phytobius": ("phytobius",),
    "phytocoris": ("phytocoris",),
    "picornavirus": ("picornavirus",),
    "picoteuses": ("picoteux",),
    "picoteux": ("picoteux",),
    "picris": ("picris",),
    "picromerus": ("picromerus",),
    "pics-verts": ("pic-vert",),
    "pieds-bleus": ("pied-bleu",),
    "pieds-bots": ("pied-bot",),
    "pieds-d'alouette": ("pied-d'alouette",),
    "pieds-de-cheval": ("pied-de-cheval",),
    "pieds-de-corbeau": ("pied-de-corbeau",),
    "pieds-de-cuve": ("pied-de-cuve",),
    "pieds-d'éléphant": ("pied-d'éléphant",),
    "pieds-de-lion": ("pied-de-lion",),
    "pieds de nez": ("pied-de-nez",),
    "pieds-de-nez": ("pied-de-nez",),
    "pieds-de-veau": ("pied-de-veau",),
    "piédestaux": ("piédestal",),
    "pieds-noirs": ("pied-noir",),
    "pies-mères": ("pie-mère",),
    "piémontaises": ("piémontais",),
    "piémontais": ("piémontais",),
    "pieris": ("pieris",),
    "pieta": ("pieta",),
    "pieux": ("pieu",),
    "pigeonneaux": ("pigeonneau",),
    "pileopsis": ("pileopsis",),
    "pileus": ("pileus",),
    "pilotes-majors": ("pilote-major",),
    "pilotis": ("pilotis",),
    "pilumnus": ("pilumnus",),
    "pilus": ("pilus",),
    "pimperneaux": ("pimperneau",),
    "pinacoceras": ("pinacoceras",),
    "pinax": ("pinax",),
    "pinceaux": ("pinceau",),
    "pineaux": ("pineau",),
    "pi": ("pi",),
    "pintadeaux": ("pintadeau",),
    "pionosyllis": ("pionosyllis",),
    "pipeaux": ("pipeau",),
    "piqueux": ("piqueux",),
    "pironeaux": ("pironeau",),
    "pironneaux": ("pironneau",),
    "pis": ("pis",),
    "pistolets-mitrailleurs": ("pistolet-mitrailleur",),
    "pithiviers": ("pithiviers",),
    "pituiteuses": ("pituiteux",),
    "pituiteux": ("pituiteux",),
    "pitymys": ("pitymys",),
    "pityriasis": ("pityriasis",),
    "placeaux": ("placeau",),
    "placenticeras": ("placenticeras",),
    "plagianthus": ("plagianthus",),
    "plaquis": ("plaquis",),
    "plasmarrhexis": ("plasmarrhexis",),
    "plateaux": ("plateau",),
    "plateaux-repas": ("plateau-repas",),
    "plates-bandes": ("plate-bande",),
    "plates-cuves": ("plate-cuve",),
    "plates-formes": ("plate-forme",),
    "platinum": ("platinum",),
    "plats-joints": ("plat-joint",),
    "platophrys": ("platophrys",),
    "plâtras": ("plâtras",),
    "platyceras": ("platyceras",),
    "platycnémis": ("platycnémis",),
    "platycrinus": ("platycrinus",),
    "platymerus": ("platymerus",),
    "platynéréis": ("platynéréis",),
    "platypus": ("platypus",),
    "plectranthus": ("plectranthus",),
    "plectus": ("plectus",),
    "pleins-vents": ("plein-vent",),
    "plésiadapis": ("plésiadapis",),
    "plesiomonas": ("plesiomonas",),
    "plésioteuthis": ("plésioteuthis",),
    "pleurothotonos": ("pleurothotonos",),
    "pleurotropis": ("pleurotropis",),
    "plexiglas": ("plexiglas",),
    "plexus": ("plexus",),
    "pliohippus": ("pliohippus",),
    "plombières": ("plombières",),
    "plombiers-zingueurs": ("plombier-zingueur",),
    "plotosus": ("plotosus",),
    "plumeaux": ("plumeau",),
    "plumetis": ("plumetis",),
    "plus": ("plus",),
    "pluteus": ("pluteus",),
    "pneumocystis": ("pneumocystis",),
    "pneumorachis": ("pneumorachis",),
    "pneumothorax": ("pneumothorax",),
    "pneumovirus": ("pneumovirus",),
    "p": ("p",),
    "pocheteaux": ("pocheteau",),
    "pochettes-disco": ("pochette-disco",),
    "podoceropsis": ("podoceropsis",),
    "podocnemis": ("podocnemis",),
    "poecilobothrus": ("poecilobothrus",),
    "poeciloscytus": ("poeciloscytus",),
    "poecilus": ("poecilus",),
    "poétereaux": ("poétereau",),
    "pogonochoerus": ("pogonochoerus",),
    "poids": ("poids",),
    "pointaux": ("pointal",),
    "pointeaux": ("pointeau",),
    "pointilleuses": ("pointilleux",),
    "pointilleux": ("pointilleux",),
    "poireaux": ("poireau",),
    "pois": ("pois",),
    "poissons-anges": ("poisson-ange",),
    "poissons-chats": ("poisson-chat",),
    "poissons-crapauds": ("poisson-crapaud",),
    "poissons-épées": ("poisson-épée",),
    "poissons-feuilles": ("poisson-feuille",),
    "poissons-lézards": ("poisson-lézard",),
    "poissons-perroquets": ("poisson-perroquet",),
    "poissons-scies": ("poisson-scie",),
    "poissons-soldats": ("poisson-soldat",),
    "poix": ("poix",),
    "policemen": ("policeman",),
    "poliovirus": ("poliovirus",),
    "pollicipes": ("pollicipes",),
    "pollinosis": ("pollinosis",),
    "polonaises": ("polonais",),
    "polonais": ("polonais",),
    "polska": ("polska",),
    "polybothris": ("polybothris",),
    "polycelis": ("polycelis",),
    "polycristaux": ("polycristal",),
    "polydrosus": ("polydrosus",),
    "polygordius": ("polygordius",),
    "polykrikos": ("polykrikos",),
    "polymitarcys": ("polymitarcys",),
    "polyneuritis": ("polyneuritis",),
    "polyomavirus": ("polyomavirus",),
    "polyophthalmus": ("polyophthalmus",),
    "polypointes-ondes": ("polypointe-onde",),
    "polyposis": ("polyposis",),
    "polyscias": ("polyscias",),
    "pomatias": ("pomatias",),
    "pomatoceros": ("pomatoceros",),
    "pomerol": ("pomerol",),
    "pommeaux": ("pommeau",),
    "pompholyx": ("pompholyx",),
    "ponantaises": ("ponantais",),
    "ponantais": ("ponantais",),
    "ponceaux": ("ponceau",),
    "pondéreux": ("pondéreux",),
    "ponts-aqueducs": ("pont-aqueduc",),
    "ponts-canaux": ("pont-canal",),
    "ponteaux": ("ponteau",),
    "ponts-levis": ("pont-levis",),
    "ponts-neufs": ("pont-neuf",),
    "ponts-routes": ("pont-route",),
    "pontuseaux": ("pontuseau",),
    "popov": ("popov",),
    "poraspis": ("poraspis",),
    "porcs-épics": ("porc-épic",),
    "porichthys": ("porichthys",),
    "porphyrops": ("porphyrops",),
    "porreaux": ("porreau",),
    "portechoux": ("portechoux",),
    "porte-drapeaux": ("porte-drapeau",),
    "portefaix": ("portefaix",),
    "porte-feux": ("porte-feu",),
    "portemanteaux": ("portemanteau",),
    "porte-oiseaux": ("porte-oiseau",),
    "portugaises": ("portugais",),
    "portugais": ("portugais",),
    "postoestrus": ("postoestrus",),
    "pots-à-feu": ("pot-à-feu",),
    "potamacanthus": ("potamacanthus",),
    "potamides": ("potamides",),
    "pots-de-vin": ("pot-de-vin",),
    "poteaux": ("poteau",),
    "pots-pourris": ("pot-pourri",),
    "pouilleuses": ("pouilleux",),
    "pouilleux": ("pouilleux",),
    "pouilly": ("pouilly",),
    "pouls": ("pouls",),
    "poux": ("pou",),
    "pourceaux": ("pourceau",),
    "pourquoi": ("pourquoi",),
    "power": ("power",),
    "pox": ("pox",),
    "poxvirus": ("poxvirus",),
    "praesides": ("praeses",),
    "pragoises": ("pragois",),
    "pragois": ("pragois",),
    "praguoises": ("praguois",),
    "praguois": ("praguois",),
    "prasocuris": ("prasocuris",),
    "praxis": ("praxis",),
    "prays": ("prays",),
    "préaux": ("préau",),
    "préavis": ("préavis",),
    "précieuses": ("précieux",),
    "précieux": ("précieux",),
    "précis": ("précis",),
    "prédécès": ("prédécès",),
    "préfaisceaux": ("préfaisceau",),
    "pregadi": ("pregado",),
    "prélegs": ("prélegs",),
    "premiers-nés": ("premier-né",),
    "premix": ("premix",),
    "prémycosis": ("prémycosis",),
    "préoestrus": ("préoestrus",),
    "prérequis": ("prérequis",),
    "prés-salés": ("pré-salé",),
    "présapiens": ("présapiens",),
    "présemis": ("présemis",),
    "présidiaux": ("présidial",),
    "présomptueuses": ("présomptueux",),
    "présomptueux": ("présomptueux",),
    "presqu îles": ("presqu'île",),
    "prétentieuses": ("prétentieux",),
    "prétentieux": ("prétentieux",),
    "preux": ("preux",),
    "principales": ("principal",),
    "principaux": ("principal",),
    "printemps": ("printemps",),
    "priocnemis": ("priocnemis",),
    "prionomys": ("prionomys",),
    "prismastolaimus": ("prismastolaimus",),
    "prix": ("prix",),
    "proamnios": ("proamnios",),
    "procès": ("procès",),
    "processionnaux": ("processionnal",),
    "processus": ("processus",),
    "procès-verbaux": ("procès-verbal",),
    "prochinoises": ("prochinois",),
    "prochinois": ("prochinois",),
    "procris": ("procris",),
    "procubitus": ("procubitus",),
    "prodigiosus": ("prodigiosus",),
    "productus": ("productus",),
    "produits-maison": ("produit-maison",),
    "proetus": ("proetus",),
    "profès": ("profès",),
    "professes": ("profès",),
    "proglottis": ("proglottis",),
    "progrès": ("progrès",),
    "prolapsus": ("prolapsus",),
    "promises": ("promis",),
    "promis": ("promis",),
    "pronaos": ("pronaos",),
    "pronéphros": ("pronéphros",),
    "pronominaux": ("pronominal",),
    "pronucleus": ("pronucleus",),
    "pronucléus": ("pronucléus",),
    "propolis": ("propolis",),
    "propositus": ("propositus",),
    "propos": ("propos",),
    "prorata": ("prorata",),
    "prorhynchus": ("prorhynchus",),
    "pros": ("pros",),
    "prosopis": ("prosopis",),
    "prospecteurs-placiers": ("prospecteur-placier",),
    "prospectrices-placières": ("prospecteur-placier",),
    "prospectus": ("prospectus",),
    "protéagineux": ("protéagineux",),
    "protéroctopus": ("protéroctopus",),
    "proteus": ("proteus",),
    "prothorax": ("prothorax",),
    "protobatrachus": ("protobatrachus",),
    "protocératops": ("protocératops",),
    "protococcus": ("protococcus",),
    "protovirus": ("protovirus",),
    "provençales": ("provençal",),
    "provençaux": ("provençal",),
    "provinciales": ("provincial",),
    "provinciaux": ("provincial",),
    "provirus": ("provirus",),
    "prud homies": ("prud'homie",),
    "pruneaux": ("pruneau",),
    "prunus": ("prunus",),
    "psammophis": ("psammophis",),
    "pseudaxis": ("pseudaxis",),
    "pseudococcus": ("pseudococcus",),
    "pseudocowpox": ("pseudocowpox",),
    "pseudomonas": ("pseudomonas",),
    "pseudopanaris": ("pseudopanaris",),
    "pseudotabès": ("pseudotabès",),
    "pseudotruncus": ("pseudotruncus",),
    "pseudovirus": ("pseudovirus",),
    "psiloceras": ("psiloceras",),
    "psilosis": ("psilosis",),
    "psi": ("psi",),
    "psoas": ("psoas",),
    "psoïtis": ("psoïtis",),
    "psolus": ("psolus",),
    "psoriasis": ("psoriasis",),
    "psoroptes": ("psoroptes",),
    "pteleobius": ("pteleobius",),
    "pteraspis": ("pteraspis",),
    "ptéroïs": ("ptéroïs",),
    "pterolepis": ("pterolepis",),
    "ptérostichus": ("ptérostichus",),
    "pterygotus": ("pterygotus",),
    "ptérygotus": ("ptérygotus",),
    "ptilinus": ("ptilinus",),
    "ptosis": ("ptosis",),
    "ptôsis": ("ptôsis",),
    "ptychites": ("ptychites",),
    "pubis": ("pubis",),
    "puceaux": ("puceau",),
    "pucelles": ("puceau",),
    "pucheux": ("pucheux",),
    "puits": ("puits",),
    "pulex": ("pulex",),
    "pulsus": ("pulsus",),
    "pupazzi": ("pupazzo",),
    "pureaux": ("pureau",),
    "pus": ("pus",),
    "putois": ("putois",),
    "putti": ("putto",),
    "pygaulus": ("pygaulus",),
    "pyocolpos": ("pyocolpos",),
    "pyopneumothorax": ("pyopneumothorax",),
    "pyosalpinx": ("pyosalpinx",),
    "pyothorax": ("pyothorax",),
    "pyrex": ("pyrex",),
    "pyrocoris": ("pyrocoris",),
    "pyroligneux": ("pyroligneux",),
    "pyrosis": ("pyrosis",),
    "pyrrhocoris": ("pyrrhocoris",),
    "qcm": ("qcm",),
    "q": ("q",),
    "quadratojugaux": ("quadratojugal",),
    "quadriceps": ("quadriceps",),
    "quadrijumeaux": ("quadrijumeau",),
    "quadrijumelles": ("quadrijumeau",),
    "quadruplex": ("quadruplex",),
    "quanta": ("quantum",),
    "quarante": ("quarante",),
    "quarts-de-brie": ("quart-de-brie",),
    "quartiers-maîtres": ("quartier-maître",),
    "quartz": ("quartz",),
    "quatorze": ("quatorze",),
    "quatre-feuilles": ("quatrefeuilles",),
    "quatrefeuilles": ("quatrefeuilles",),
    "quatre": ("quatre",),
    "québécoises": ("québécois",),
    "québécois": ("québécois",),
    "queen": ("queen",),
    "quercinoises": ("quercinois",),
    "quercinois": ("quercinois",),
    "queues de cheval": ("queue-de-cheval",),
    "queues-de-cochon": ("queue-de-cochon",),
    "queues de pie": ("queue-de-pie",),
    "queues de poisson": ("queue-de-poisson",),
    "queues-de-poisson": ("queue-de-poisson",),
    "queues-de-rat": ("queue-de-rat",),
    "queues-de-souris": ("queue-de-souris",),
    "queues-fourchues": ("queue-fourchue",),
    "queux": ("queux",),
    "quintaux": ("quintal",),
    "quintus": ("quintus",),
    "quinze": ("quinze",),
    "quitus": ("quitus",),
    "quizz": ("quizz",),
    "quotes-parts": ("quote-part",),
    "qwerty": ("qwerty",),
    "rabais": ("rabais",),
    "raboteuses-dégauchisseuses": ("raboteuse-dégauchisseuse",),
    "racers-racers": ("racer-racer",),
    "rachischisis": ("rachischisis",),
    "rachis": ("rachis",),
    "racinaux": ("racinal",),
    "radeaux": ("radeau",),
    "radicales": ("radical",),
    "radicaux": ("radical",),
    "radicaux-socialistes": ("radical-socialiste",),
    "radiocanaux": ("radiocanal",),
    "radiocompas": ("radiocompas",),
    "radiojournaux": ("radiojournal",),
    "radiolites": ("radiolites",),
    "radis": ("radis",),
    "radius": ("radius",),
    "radix": ("radix",),
    "rafiaux": ("rafiau",),
    "raga": ("raga",),
    "ragazzi": ("ragazzo",),
    "rais": ("rais",),
    "raïs": ("raïs",),
    "rajoutis": ("rajoutis",),
    "raku": ("raku",),
    "ramas": ("ramas",),
    "ramasseuses-dépanouilleuses": ("ramasseuse-dépanouilleuse",),
    "ramassis": ("ramassis",),
    "rameaux": ("rameau",),
    "ramereaux": ("ramereau",),
    "ram": ("ram",),
    "rampeaux": ("rampeau",),
    "ramponeaux": ("ramponeau",),
    "ramponneaux": ("ramponneau",),
    "rams": ("rams",),
    "rancio": ("rancio",),
    "rancuneuses": ("rancuneux",),
    "rancuneux": ("rancuneux",),
    "ra": ("ra",),
    "ranz": ("ranz",),
    "rappointis": ("rappointis",),
    "raptus": ("raptus",),
    "raskolniki": ("raskolnik",),
    "ras": ("ras",),
    "râteaux": ("râteau",),
    "rationaux": ("rational",),
    "raz": ("raz",),
    "réaux": ("réal",),
    "rebours": ("rebours",),
    "rebouteuses": ("rebouteux",),
    "rebouteux": ("rebouteux",),
    "rebras": ("rebras",),
    "rébus": ("rébus",),
    "recès": ("recès",),
    "récessus": ("récessus",),
    "recez": ("recez",),
    "réchampis": ("réchampis",),
    "recluses": ("reclus",),
    "reclus": ("reclus",),
    "recordwomen": ("recordwoman",),
    "recors": ("recors",),
    "recours": ("recours",),
    "redoux": ("redoux",),
    "réductions-couple": ("réduction-couple",),
    "reflex": ("reflex",),
    "reflux": ("reflux",),
    "refus": ("refus",),
    "régionaux": ("régional",),
    "régisseurs-comptables": ("régisseur-comptable",),
    "régisseuses-comptables": ("régisseur-comptable",),
    "regros": ("regros",),
    "reines-marguerites": ("reine-marguerite",),
    "reis": ("reis",),
    "rejoneadores": ("rejoneador",),
    "relais": ("relais",),
    "relancis": ("relancis",),
    "relapses": ("relaps",),
    "relaps": ("relaps",),
    "religieuses": ("religieux",),
    "religieux": ("religieux",),
    "remiz": ("remiz",),
    "rémiz": ("rémiz",),
    "rémoises": ("rémois",),
    "rémois": ("rémois",),
    "remords": ("remords",),
    "remous": ("remous",),
    "renardeaux": ("renardeau",),
    "renformis": ("renformis",),
    "rennaises": ("rennais",),
    "rennais": ("rennais",),
    "renouveaux": ("renouveau",),
    "ré": ("ré",),
    "réovirus": ("réovirus",),
    "repas": ("repas",),
    "répons": ("répons",),
    "repos": ("repos",),
    "repris": ("repris",),
    "reps": ("reps",),
    "requiem": ("requiem",),
    "requises": ("requis",),
    "requis": ("requis",),
    "réseaux": ("réseau",),
    "résineux": ("résineux",),
    "responsoriaux": ("responsorial",),
    "reticulitermes": ("reticulitermes",),
    "rétinoschisis": ("rétinoschisis",),
    "retorses": ("retors",),
    "retors": ("retors",),
    "rétrocolis": ("rétrocolis",),
    "retrolentivirus": ("retrolentivirus",),
    "rétrolisthésis": ("rétrolisthésis",),
    "retroussis": ("retroussis",),
    "rétrovirus": ("rétrovirus",),
    "rets": ("rets",),
    "réunionaises": ("réunionais",),
    "réunionais": ("réunionais",),
    "réunionnaises": ("réunionnais",),
    "réunionnais": ("réunionnais",),
    "reversis": ("reversis",),
    "revers": ("revers",),
    "rez": ("rez",),
    "rhabditis": ("rhabditis",),
    "rhabdovirus": ("rhabdovirus",),
    "rhagoletis": ("rhagoletis",),
    "rhamphus": ("rhamphus",),
    "rhésus": ("rhésus",),
    "rhinocéros": ("rhinocéros",),
    "rhinococcyx": ("rhinococcyx",),
    "rhinoglanis": ("rhinoglanis",),
    "rhinoncus": ("rhinoncus",),
    "rhinopharynx": ("rhinopharynx",),
    "rhinophrynus": ("rhinophrynus",),
    "rhinovirus": ("rhinovirus",),
    "rhipsalis": ("rhipsalis",),
    "rhizobius": ("rhizobius",),
    "rhizocrinus": ("rhizocrinus",),
    "rhizopus": ("rhizopus",),
    "rhodnius": ("rhodnius",),
    "rhogas": ("rhogas",),
    "rhonchus": ("rhonchus",),
    "rhô": ("rhô",),
    "rhopalotomus": ("rhopalotomus",),
    "rhyparochromus": ("rhyparochromus",),
    "rhytidores": ("rhytidores",),
    "rhytidosis": ("rhytidosis",),
    "ribouis": ("ribouis",),
    "ricardeaux": ("ricardeau",),
    "ricard": ("ricard",),
    "ricercari": ("ricercare",),
    "richelieux": ("richelieu",),
    "rictus": ("rictus",),
    "rideaux": ("rideau",),
    "rinceaux": ("rinceau",),
    "ripoux": ("ripou",),
    "rishi": ("rishi",),
    "risi": ("risi",),
    "ris": ("ris",),
    "risorius": ("risorius",),
    "riss": ("riss",),
    "rivales": ("rival",),
    "rivaux": ("rival",),
    "riva": ("riva",),
    "rivesaltes": ("rivesaltes",),
    "riz": ("riz",),
    "r": ("r",),
    "roches-réservoirs": ("roche-réservoir",),
    "rôles-titres": ("rôle-titre",),
    "rollmops": ("rollmops",),
    "romanée": ("romanée",),
    "romans-photo": ("roman-photo",),
    "policiers": ("romanpolicier",),
    "romans policiers": ("romanpolicier",),
    "rom": ("rom",),
    "rompis": ("rompis",),
    "ronchonneaux": ("ronchonneau",),
    "ronchus": ("ronchus",),
    "ronds-de-cuir": ("rond-de-cuir",),
    "rondeaux": ("rondeau",),
    "ronds-points": ("rond-point",),
    "rönin": ("rönin",),
    "roseaux-massues": ("roseau-massue",),
    "roseaux": ("roseau",),
    "roses-crans": ("rose-cran",),
    "rosés-des-prés": ("rosé-des-prés",),
    "rossolis": ("rossolis",),
    "rotavirus": ("rotavirus",),
    "rouennaises": ("rouennais",),
    "rouennais": ("rouennais",),
    "rougeoleuses": ("rougeoleux",),
    "rougeoleux": ("rougeoleux",),
    "rouleaux": ("rouleau",),
    "roulis": ("roulis",),
    "rousseaux": ("rousseau",),
    "roussillonnaises": ("roussillonnais",),
    "roussillonnais": ("roussillonnais",),
    "rouvieux": ("rouvieux",),
    "rousses": ("roux",),
    "roux": ("roux",),
    "royaux": ("royal",),
    "royalties": ("royalty",),
    "ruandaises": ("ruandais",),
    "ruandais": ("ruandais",),
    "rubéoleuses": ("rubéoleux",),
    "rubéoleux": ("rubéoleux",),
    "rubis": ("rubis",),
    "rubivirus": ("rubivirus",),
    "rugbymen": ("rugbyman",),
    "rugueux": ("rugueux",),
    "ruisseaux": ("ruisseau",),
    "rumex": ("rumex",),
    "ruolz": ("ruolz",),
    "ruraux": ("rural",),
    "rushes": ("rush",),
    "ruz": ("ruz",),
    "rwandaises": ("rwandais",),
    "rwandais": ("rwandais",),
    "sabbath": ("sabbath",),
    "sabres-baïonnettes": ("sabre-baïonnette",),
    "saccharomyces": ("saccharomyces",),
    "sacramentaux": ("sacramental",),
    "sacrolisthésis": ("sacrolisthésis",),
    "sadhu": ("sadhu",),
    "sages-femmes": ("sage-femme",),
    "sainbois": ("sainbois",),
    "saindoux": ("saindoux",),
    "saintes-barbes": ("sainte-barbe",),
    "saints-germains": ("saint-germain",),
    "saints-paulins": ("saint-paulin",),
    "saisies-brandons": ("saisie-brandon",),
    "salarias": ("salarias",),
    "salers": ("salers",),
    "salicionaux": ("salicional",),
    "salmigondis": ("salmigondis",),
    "salmis": ("salmis",),
    "salmonella": ("salmonella",),
    "salomon": ("salomon",),
    "salons-bibliothèques": ("salon-bibliothèque",),
    "salopiaux": ("salopiau",),
    "salsifis": ("salsifis",),
    "salzbourgeoises": ("salzbourgeois",),
    "salzbourgeois": ("salzbourgeois",),
    "sammies": ("sammy",),
    "sanctus": ("sanctus",),
    "sandhi": ("sandhi",),
    "sandix": ("sandix",),
    "sandyx": ("sandyx",),
    "sapeurs-aérostiers": ("sapeur-aérostier",),
    "sapeurs-pompiers": ("sapeur-pompier",),
    "sapientiaux": ("sapiential",),
    "sarcocystis": ("sarcocystis",),
    "sardinaux": ("sardinal",),
    "sardineaux": ("sardineau",),
    "sardonyx": ("sardonyx",),
    "saros": ("saros",),
    "sarroises": ("sarrois",),
    "sarrois": ("sarrois",),
    "sarthoises": ("sarthois",),
    "sarthois": ("sarthois",),
    "sas": ("sas",),
    "sassafras": ("sassafras",),
    "satang": ("satang",),
    "satî": ("satî",),
    "satisfecit": ("satisfecit",),
    "satyriasis": ("satyriasis",),
    "saumoneaux": ("saumoneau",),
    "sauriasis": ("sauriasis",),
    "sauris": ("sauris",),
    "sauts-de-lit": ("saut-de-lit",),
    "sauts-de-ski": ("saut-de-ski",),
    "sautereaux": ("sautereau",),
    "sauternes": ("sauternes",),
    "sax": ("sax",),
    "saz": ("saz",),
    "sbrinz": ("sbrinz",),
    "scabies": ("scabies",),
    "scandix": ("scandix",),
    "scapholisthésis": ("scapholisthésis",),
    "scapulae": ("scapula",),
    "scarlatineuses": ("scarlatineux",),
    "scarlatineux": ("scarlatineux",),
    "sceaux-matrices": ("sceau-matrice",),
    "sceaux": ("sceau",),
    "scénopinus": ("scénopinus",),
    "scévophylax": ("scévophylax",),
    "schedius": ("schedius",),
    "schizodus": ("schizodus",),
    "schizothorax": ("schizothorax",),
    "schlass": ("schlass",),
    "schnaps": ("schnaps",),
    "schuss": ("schuss",),
    "sciapus": ("sciapus",),
    "sciocoris": ("sciocoris",),
    "scolecolepis": ("scolecolepis",),
    "scolex": ("scolex",),
    "scolioptéryx": ("scolioptéryx",),
    "scoloplos": ("scoloplos",),
    "scolopostethus": ("scolopostethus",),
    "scopaeus": ("scopaeus",),
    "scratches": ("scratch",),
    "scrofuleuses": ("scrofuleux",),
    "scrofuleux": ("scrofuleux",),
    "scrupuleuses": ("scrupuleux",),
    "scrupuleux": ("scrupuleux",),
    "scymnus": ("scymnus",),
    "seaux": ("seau",),
    "secours": ("secours",),
    "secrétaires-greffiers": ("secrétaire-greffier",),
    "secrétariats-greffes": ("secrétariat-greffe",),
    "secrets-défense": ("secret-défense",),
    "secteurs-clés": ("secteur-clé",),
    "séditieuses": ("séditieux",),
    "séditieux": ("séditieux",),
    "sefaraddim": ("sefaraddi",),
    "sefardim": ("sefardi",),
    "ségrais": ("ségrais",),
    "seize": ("seize",),
    "selleries-maroquineries": ("sellerie-maroquinerie",),
    "selliers-maroquiniers": ("sellier-maroquinier",),
    "semenceaux": ("semenceau",),
    "semis": ("semis",),
    "sempervivum": ("sempervivum",),
    "senaux": ("senau",),
    "sénéchaux": ("sénéchal",),
    "sénégalaises": ("sénégalais",),
    "sénégalais": ("sénégalais",),
    "sen": ("sen",),
    "sénonaises": ("sénonais",),
    "sénonais": ("sénonais",),
    "sens": ("sens",),
    "sentimentales": ("sentimental",),
    "sentimentaux": ("sentimental",),
    "seps": ("seps",),
    "septmoncel": ("septmoncel",),
    "sept": ("sept",),
    "serbocaux": ("serbocal",),
    "serdeaux": ("serdeau",),
    "serpenteaux": ("serpenteau",),
    "sertões": ("sertão",),
    "serventois": ("serventois",),
    "sétoises": ("sétois",),
    "sétois": ("sétois",),
    "sévereaux": ("sévereau",),
    "sèvres": ("sèvres",),
    "seychelloises": ("seychellois",),
    "seychellois": ("seychellois",),
    "sfumati": ("sfumato",),
    "shakespeare": ("shakespeare",),
    "shalom": ("shalom",),
    "sherries": ("sherry",),
    "shigella": ("shigella",),
    "shikken": ("shikken",),
    "shonagon": ("shonagon",),
    "showbiz": ("showbiz",),
    "showmen": ("showman",),
    "sialis": ("sialis",),
    "siamoises": ("siamois",),
    "siamois": ("siamois",),
    "sicus": ("sicus",),
    "sièges-autos": ("siège-auto",),
    "siemens": ("siemens",),
    "siennoises": ("siennois",),
    "siennois": ("siennois",),
    "siffleux": ("siffleux",),
    "sigaretus": ("sigaretus",),
    "sigma": ("sigma",),
    "signaux": ("signal",),
    "silencieuses": ("silencieux",),
    "silencieux": ("silencieux",),
    "silex": ("silex",),
    "silvanus": ("silvanus",),
    "silver": ("silver",),
    "simbleaux": ("simbleau",),
    "simias": ("simias",),
    "simplex": ("simplex",),
    "sinnfeiner": ("sinnfeiner",),
    "si": ("si",),
    "sinus": ("sinus",),
    "sioux": ("sioux",),
    "sirex": ("sirex",),
    "sirventès": ("sirventès",),
    "sistrurus": ("sistrurus",),
    "sitaris": ("sitaris",),
    "sitophilus": ("sitophilus",),
    "sitophylax": ("sitophylax",),
    "situs": ("situs",),
    "six": ("six",),
    "sketches": ("sketch",),
    "skons": ("skons",),
    "skoptsy": ("skopets",),
    "skunks": ("skunks",),
    "skuns": ("skuns",),
    "smashes": ("smash",),
    "smilax": ("smilax",),
    "s": ("s",),
    "sociales-démocrates": ("social-démocrate",),
    "sociaux-démocrates": ("social-démocrate",),
    "socius": ("socius",),
    "soixante": ("soixante",),
    "soleae": ("solea",),
    "solecurtus": ("solecurtus",),
    "solenocurtus": ("solenocurtus",),
    "solenopsis": ("solenopsis",),
    "solex": ("solex",),
    "soliveaux": ("soliveau",),
    "solmaris": ("solmaris",),
    "solmissus": ("solmissus",),
    "somatoschisis": ("somatoschisis",),
    "sommeilleuses": ("sommeilleux",),
    "sommeilleux": ("sommeilleux",),
    "sors": ("sors",),
    "soudanaises": ("soudanais",),
    "soudanais": ("soudanais",),
    "souffreteuses": ("souffreteux",),
    "souffreteux": ("souffreteux",),
    "soundanais": ("soundanais",),
    "soupiraux": ("soupirail",),
    "sourdes-muettes": ("sourd-muet",),
    "sourds-muets": ("sourd-muet",),
    "souriceaux": ("souriceau",),
    "souris": ("souris",),
    "sournoises": ("sournois",),
    "sournois": ("sournois",),
    "sous-bailleresses": ("sous-bailleur",),
    "sous-brigadières": ("sous-brigadier",),
    "sous-entrepreneuses": ("sous-entrepreneur",),
    "sous-inspectrices": ("sous-inspecteur",),
    "soutiens-gorge": ("soutien-gorge",),
    "soyeuses": ("soyeux",),
    "soyeux": ("soyeux",),
    "spalax": ("spalax",),
    "spasmus": ("spasmus",),
    "speiss": ("speiss",),
    "spélerpès": ("spélerpès",),
    "spéos": ("spéos",),
    "sphaerechinus": ("sphaerechinus",),
    "sphaeroceras": ("sphaeroceras",),
    "sphaeronis": ("sphaeronis",),
    "sphaerophorus": ("sphaerophorus",),
    "sphaerulites": ("sphaerulites",),
    "spherophorus": ("spherophorus",),
    "sphex": ("sphex",),
    "sphinx": ("sphinx",),
    "spiophanes": ("spiophanes",),
    "spiraux": ("spiral",),
    "spiritueux": ("spiritueux",),
    "spiromonas": ("spiromonas",),
    "spitz": ("spitz",),
    "spléniaux": ("splénial",),
    "splénius": ("splénius",),
    "spondias": ("spondias",),
    "spondylocléisis": ("spondylocléisis",),
    "spondyloklisis": ("spondyloklisis",),
    "spondylolisthésis": ("spondylolisthésis",),
    "spondylolysis": ("spondylolysis",),
    "spondyloptosis": ("spondyloptosis",),
    "spondyloschisis": ("spondyloschisis",),
    "spongieuses": ("spongieux",),
    "spongieux": ("spongieux",),
    "sportsmen": ("sportsman",),
    "sportswomen": ("sportswoman",),
    "spumarétrovirus": ("spumarétrovirus",),
    "spumavirus": ("spumavirus",),
    "ss": ("ss",),
    "stafford": ("stafford",),
    "stapes": ("stapes",),
    "staphylococcus": ("staphylococcus",),
    "starets": ("starets",),
    "stariets": ("stariets",),
    "stations-service": ("station-service",),
    "stations-wagons": ("station-wagon",),
    "statues-menhirs": ("statue-menhir",),
    "status": ("status",),
    "stelis": ("stelis",),
    "stenebothrus": ("stenebothrus",),
    "sténéptéryx": ("sténéptéryx",),
    "stenopsocus": ("stenopsocus",),
    "stenorynchus": ("stenorynchus",),
    "stenosis": ("stenosis",),
    "stephanitis": ("stephanitis",),
    "stephanoceras": ("stephanoceras",),
    "stéphanoises": ("stéphanois",),
    "stéphanois": ("stéphanois",),
    "sterling": ("sterling",),
    "sthenelaïs": ("sthenelaïs",),
    "stilicus": ("stilicus",),
    "stimuli": ("stimulus",),
    "stimulus": ("stimulus",),
    "stokes": ("stokes",),
    "stomaphis": ("stomaphis",),
    "stomechinus": ("stomechinus",),
    "stomias": ("stomias",),
    "storax": ("storax",),
    "stories": ("story",),
    "stotinki": ("stotinka",),
    "stoupa": ("stoupa",),
    "stradivarius": ("stradivarius",),
    "strasbourgeoises": ("strasbourgeois",),
    "strasbourgeois": ("strasbourgeois",),
    "stras": ("stras",),
    "strass": ("strass",),
    "stratiomys": ("stratiomys",),
    "strato-cumulus": ("stratocumulus",),
    "stratocumulus": ("stratocumulus",),
    "stratonimbus": ("stratonimbus",),
    "stratus": ("stratus",),
    "streltsy": ("strelets",),
    "streptobacillus": ("streptobacillus",),
    "streptococcus": ("streptococcus",),
    "streptomyces": ("streptomyces",),
    "streptopus": ("streptopus",),
    "streptothrix": ("streptothrix",),
    "stress": ("stress",),
    "strix": ("strix",),
    "strongyloïdes": ("strongyloïdes",),
    "strongylus": ("strongylus",),
    "strophantus": ("strophantus",),
    "strophosomus": ("strophosomus",),
    "strophulus": ("strophulus",),
    "strychnos": ("strychnos",),
    "stupa": ("stupa",),
    "stylos-bille": ("stylo-bille",),
    "stylochus": ("stylochus",),
    "stylonurus": ("stylonurus",),
    "stylops": ("stylops",),
    "styrax": ("styrax",),
    "succès": ("succès",),
    "success": ("success",),
    "suédoises": ("suédois",),
    "suédois": ("suédois",),
    "suiboku": ("suiboku",),
    "summum": ("summum",),
    "sumo": ("sumo",),
    "sumotori": ("sumotori",),
    "super-héroïnes": ("super-héros",),
    "supermen": ("superman",),
    "supernovae": ("supernova",),
    "superstitieuses": ("superstitieux",),
    "superstitieux": ("superstitieux",),
    "superwomen": ("superwoman",),
    "surchoix": ("surchoix",),
    "surcostaux": ("surcostal",),
    "surdos": ("surdos",),
    "sureaux": ("sureau",),
    "surfaix": ("surfaix",),
    "surmatelas": ("surmatelas",),
    "suros": ("suros",),
    "surplis": ("surplis",),
    "surplus": ("surplus",),
    "surpoids": ("surpoids",),
    "sursis": ("sursis",),
    "surtaux": ("surtaux",),
    "surtors": ("surtors",),
    "surtravaux": ("surtravail",),
    "suspens": ("suspens",),
    "sutra": ("sutra",),
    "swingmen": ("swingman",),
    "sycosis": ("sycosis",),
    "syllabus": ("syllabus",),
    "syllis": ("syllis",),
    "sylvaner": ("sylvaner",),
    "synchisis": ("synchisis",),
    "synchysis": ("synchysis",),
    "synclinaux": ("synclinal",),
    "synêgoros": ("synêgoros",),
    "synophrys": ("synophrys",),
    "synopsis": ("synopsis",),
    "syntomis": ("syntomis",),
    "syphilis": ("syphilis",),
    "syrinx": ("syrinx",),
    "syromastes": ("syromastes",),
    "systèmes experts": ("système-expert",),
    "systèmes-experts": ("système-expert",),
    "tabes": ("tabes",),
    "tabès": ("tabès",),
    "tableaux": ("tableau",),
    "tables-valises": ("table-valise",),
    "tachinus": ("tachinus",),
    "tachyporus": ("tachyporus",),
    "tachytes": ("tachytes",),
    "taeniasis": ("taeniasis",),
    "taffetas": ("taffetas",),
    "tagetes": ("tagetes",),
    "tagos": ("tagos",),
    "taïchi": ("taïchi",),
    "taiko": ("taiko",),
    "tailleurs-couturiers": ("tailleur-couturier",),
    "taillis": ("taillis",),
    "tairo": ("tairo",),
    "taiseuses": ("taiseux",),
    "taiseux": ("taiseux",),
    "taisho": ("taisho",),
    "taïwanaises": ("taïwanais",),
    "taïwanais": ("taïwanais",),
    "talkies-walkies": ("talkie-walkie",),
    "talus": ("talus",),
    "tamara": ("tamara",),
    "tamaraux": ("tamarau",),
    "tamaris": ("tamaris",),
    "tamarix": ("tamarix",),
    "tamis": ("tamis",),
    "tampons-dateurs": ("tampon-dateur",),
    "tanaïs": ("tanaïs",),
    "tanapox": ("tanapox",),
    "tandai": ("tandai",),
    "tangaras-hirondelles": ("tangara-hirondelle",),
    "tania": ("tania",),
    "tanka": ("tanka",),
    "tanypus": ("tanypus",),
    "tanytarsus": ("tanytarsus",),
    "tape-marteaux": ("tape-marteau",),
    "tapes": ("tapes",),
    "tapinois": ("tapinois",),
    "tapis": ("tapis",),
    "tarantass": ("tarantass",),
    "touareg": ("targui",),
    "touarègue": ("targui",),
    "tartes-maison": ("tarte-maison",),
    "tas": ("tas",),
    "tasseaux": ("tasseau",),
    "tatsu": ("tatsu",),
    "taudis": ("taudis",),
    "tau": ("tau",),
    "taureaux": ("taureau",),
    "taux": ("taux",),
    "taxibus": ("taxibus",),
    "taxis": ("taxis",),
    "tax": ("tax",),
    "taxocrinus": ("taxocrinus",),
    "tchervonetz": ("tchervonetz",),
    "technico-commerciaux": ("technico-commercial",),
    "teigneuses": ("teigneux",),
    "teigneux": ("teigneux",),
    "téléas": ("téléas",),
    "télécanthus": ("télécanthus",),
    "téléjournaux": ("téléjournal",),
    "télétex": ("télétex",),
    "télétravaux": ("télétravail",),
    "télex": ("télex",),
    "tell": ("tell",),
    "temenos": ("temenos",),
    "temporaux": ("temporal",),
    "temps": ("temps",),
    "ténébreuses": ("ténébreux",),
    "ténébreux": ("ténébreux",),
    "tennismen": ("tennisman",),
    "tennis": ("tennis",),
    "tentaculites": ("tentaculites",),
    "tentes-abris": ("tente-abri",),
    "terfès": ("terfès",),
    "tergipes": ("tergipes",),
    "terminaux": ("terminal",),
    "terminus": ("terminus",),
    "terreaux": ("terreau",),
    "terrenoix": ("terrenoix",),
    "territoriaux": ("territorial",),
    "tests-minute": ("test-minute",),
    "tétanos": ("tétanos",),
    "têteaux": ("têteau",),
    "têtes-de-loup": ("tête-de-loup",),
    "têtes-de-mort": ("tête-de-mort",),
    "tetracidaris": ("tetracidaris",),
    "tétras": ("tétras",),
    "tetrastichus": ("tetrastichus",),
    "tétrix": ("tétrix",),
    "tex": ("tex",),
    "thaïlandaises": ("thaïlandais",),
    "thaïlandais": ("thaïlandais",),
    "thaïs": ("thaïs",),
    "thalamus": ("thalamus",),
    "thalestris": ("thalestris",),
    "thamnophis": ("thamnophis",),
    "thamnotettix": ("thamnotettix",),
    "thanaos": ("thanaos",),
    "thaumastus": ("thaumastus",),
    "théâtreuses": ("théâtreux",),
    "théâtreux": ("théâtreux",),
    "theodoxus": ("theodoxus",),
    "théologaux": ("théologal",),
    "therioplectes": ("therioplectes",),
    "thermos": ("thermos",),
    "thesaurus": ("thesaurus",),
    "thêta": ("thêta",),
    "tholos": ("tholos",),
    "thomas": ("thomas",),
    "thorax": ("thorax",),
    "thous": ("thous",),
    "thrips": ("thrips",),
    "thrombus": ("thrombus",),
    "thymus": ("thymus",),
    "tiarechinus": ("tiarechinus",),
    "tiers": ("tiers",),
    "timbres-poste": ("timbre-poste",),
    "tingis": ("tingis",),
    "tinto": ("tinto",),
    "tiroirs-caisses": ("tiroir-caisse",),
    "tiroirs-lits": ("tiroir-lit",),
    "tirolites": ("tirolites",),
    "tissus-éponges": ("tissu-éponge",),
    "titres-lignes": ("titre-ligne",),
    "t": ("t",),
    "toea": ("toea",),
    "togavirus": ("togavirus",),
    "togolaises": ("togolais",),
    "togolais": ("togolais",),
    "toits-terrasses": ("toit-terrasse",),
    "toitures-terrasses": ("toiture-terrasse",),
    "tokai": ("tokai",),
    "tokaï": ("tokaï",),
    "tokaj": ("tokaj",),
    "tokay": ("tokay",),
    "tolas": ("tolas",),
    "tomaspis": ("tomaspis",),
    "tombeaux": ("tombeau",),
    "tombereaux": ("tombereau",),
    "tommies": ("tommy",),
    "tomocerus": ("tomocerus",),
    "tonkinoises": ("tonkinois",),
    "tonkinois": ("tonkinois",),
    "tonlieux": ("tonlieu",),
    "tonneaux": ("tonneau",),
    "tonus": ("tonus",),
    "tophus": ("tophus",),
    "torchis": ("torchis",),
    "torii": ("torii",),
    "tori": ("tori",),
    "torontoises": ("torontois",),
    "torontois": ("torontois",),
    "tors": ("tors",),
    "torticolis": ("torticolis",),
    "tortis": ("tortis",),
    "torus": ("torus",),
    "tories": ("tory",),
    "totaux": ("total",),
    "totanus": ("totanus",),
    "touchaux": ("touchau",),
    "toucheaux": ("toucheau",),
    "toulonnaises": ("toulonnais",),
    "toulonnais": ("toulonnais",),
    "tourangeaux": ("tourangeau",),
    "tourangelles": ("tourangeau",),
    "tourelles-balises": ("tourelle-balise",),
    "tours-minute": ("tour-minute",),
    "tournedos": ("tournedos",),
    "tournevis": ("tournevis",),
    "tournis": ("tournis",),
    "tourteaux": ("tourteau",),
    "tourtereaux": ("tourtereau",),
    "toutes-bonnes": ("toute-bonne",),
    "toux": ("toux",),
    "toxopneustes": ("toxopneustes",),
    "tracas": ("tracas",),
    "trachomateuses": ("trachomateux",),
    "trachomateux": ("trachomateux",),
    "trachyceras": ("trachyceras",),
    "trachyscelis": ("trachyscelis",),
    "trachys": ("trachys",),
    "tractus": ("tractus",),
    "tragus": ("tragus",),
    "traîneaux": ("traîneau",),
    "trains-ferries": ("train-ferry",),
    "tranchis": ("tranchis",),
    "trapezonotus": ("trapezonotus",),
    "travers": ("travers",),
    "travois": ("travois",),
    "tréaz": ("tréaz",),
    "tréchus": ("tréchus",),
    "tréfonds": ("tréfonds",),
    "trégoroises": ("trégorois",),
    "trégorois": ("trégorois",),
    "trégorroises": ("trégorrois",),
    "trégorrois": ("trégorrois",),
    "treillis": ("treillis",),
    "treize": ("treize",),
    "tremataspis": ("tremataspis",),
    "trematops": ("trematops",),
    "tremex": ("tremex",),
    "trempis": ("trempis",),
    "trente": ("trente",),
    "trépas": ("trépas",),
    "trésorières-payeuses": ("trésorier-payeur",),
    "trésoriers-payeurs": ("trésorier-payeur",),
    "tréteaux": ("tréteau",),
    "trez": ("trez",),
    "trias": ("trias",),
    "tribordais": ("tribordais",),
    "tribunaux": ("tribunal",),
    "triceps": ("triceps",),
    "tricératops": ("tricératops",),
    "trichauxis": ("trichauxis",),
    "trichiasis": ("trichiasis",),
    "trichodes": ("trichodes",),
    "trichokinésis": ("trichokinésis",),
    "trichomonas": ("trichomonas",),
    "trichomycosis": ("trichomycosis",),
    "trichoniscus": ("trichoniscus",),
    "trichonodosis": ("trichonodosis",),
    "trichoptilus": ("trichoptilus",),
    "trichorrhexis": ("trichorrhexis",),
    "trichosis": ("trichosis",),
    "trichotortosis": ("trichotortosis",),
    "trijumeaux": ("trijumeau",),
    "trijumelles": ("trijumeau",),
    "trimétaux": ("trimétal",),
    "trimitus": ("trimitus",),
    "trinucleus": ("trinucleus",),
    "trionix": ("trionix",),
    "trionyx": ("trionyx",),
    "triplées": ("triplés",),
    "triplés": ("triplés",),
    "triplex": ("triplex",),
    "triplicata": ("triplicata",),
    "triradius": ("triradius",),
    "trismus": ("trismus",),
    "triumph": ("triumph",),
    "trobriandaises": ("trobriandais",),
    "trobriandais": ("trobriandais",),
    "trochocystes": ("trochocystes",),
    "trochocystites": ("trochocystites",),
    "trogophloeus": ("trogophloeus",),
    "troilus": ("troilus",),
    "trois": ("trois",),
    "trolleybus": ("trolleybus",),
    "tropicoris": ("tropicoris",),
    "tropites": ("tropites",),
    "troubleaux": ("troubleau",),
    "troupeaux": ("troupeau",),
    "trousseaux": ("trousseau",),
    "trox": ("trox",),
    "trulli": ("trullo",),
    "trumeaux": ("trumeau",),
    "truncus": ("truncus",),
    "trustis": ("trustis",),
    "tuberculeuses": ("tuberculeux",),
    "tuberculeux": ("tuberculeux",),
    "tubifex": ("tubifex",),
    "tubulorhexis": ("tubulorhexis",),
    "tubulorrhexis": ("tubulorrhexis",),
    "tufeaux": ("tufeau",),
    "tuffeaux": ("tuffeau",),
    "tuileaux": ("tuileau",),
    "tumulus": ("tumulus",),
    "tunisoises": ("tunisois",),
    "tunisois": ("tunisois",),
    "tuphos": ("tuphos",),
    "tupinambis": ("tupinambis",),
    "turco-mongoles": ("turco-mongol",),
    "turinoises": ("turinois",),
    "turinois": ("turinois",),
    "turneps": ("turneps",),
    "turris": ("turris",),
    "tursiops": ("tursiops",),
    "tutti": ("tutti",),
    "tuyaux": ("tuyau",),
    "tychius": ("tychius",),
    "tylenchus": ("tylenchus",),
    "tylosis": ("tylosis",),
    "tympanaux": ("tympanal",),
    "tympanotonos": ("tympanotonos",),
    "typhlogobius": ("typhlogobius",),
    "typhlops": ("typhlops",),
    "typhus": ("typhus",),
    "typus": ("typus",),
    "tyranneaux": ("tyranneau",),
    "uegitglanis": ("uegitglanis",),
    "uintacrinus": ("uintacrinus",),
    "ulcus": ("ulcus",),
    "ultralibérales": ("ultralibéral",),
    "ultralibéraux": ("ultralibéral",),
    "ultravirus": ("ultravirus",),
    "unaspis": ("unaspis",),
    "unaux": ("unau",),
    "uncus": ("uncus",),
    "underground": ("underground",),
    "unguis": ("unguis",),
    "universaux": ("universal",),
    "univers": ("univers",),
    "un": ("un",),
    "u": ("u",),
    "upas": ("upas",),
    "upsilon": ("upsilon",),
    "uraeus": ("uraeus",),
    "uraptéryx": ("uraptéryx",),
    "urinaux": ("urinal",),
    "urus": ("urus",),
    "usus": ("usus",),
    "uterus": ("uterus",),
    "utérus": ("utérus",),
    "ut": ("ut",),
    "uva": ("uva",),
    "vaisseaux": ("vaisseau",),
    "valences-grammes": ("valence-gramme",),
    "valenciennes": ("valenciennes",),
    "valenciennoises": ("valenciennois",),
    "valenciennois": ("valenciennois",),
    "valentinoises": ("valentinois",),
    "valentinois": ("valentinois",),
    "valgus": ("valgus",),
    "vaniteuses": ("vaniteux",),
    "vaniteux": ("vaniteux",),
    "vanneaux": ("vanneau",),
    "vantaux": ("vantail",),
    "varioleuses": ("varioleux",),
    "varioleux": ("varioleux",),
    "variqueuses": ("variqueux",),
    "variqueux": ("variqueux",),
    "varoises": ("varois",),
    "varois": ("varois",),
    "varus": ("varus",),
    "vaseux": ("vaseux",),
    "vasistas": ("vasistas",),
    "vassales": ("vassal",),
    "vassaux": ("vassal",),
    "vassiveaux": ("vassiveau",),
    "vaudoises": ("vaudois",),
    "vaudois": ("vaudois",),
    "vaux": ("vau",),
    "vavassaux": ("vavassal",),
    "veaux": ("veau",),
    "vedika": ("vedika",),
    "vegas": ("vegas",),
    "végétaux": ("végétal",),
    "vélo-cross": ("vélocross",),
    "vélocross": ("vélocross",),
    "velours": ("velours",),
    "vénérupis": ("vénérupis",),
    "veniat": ("veniat",),
    "ventaux": ("ventail",),
    "venteaux": ("venteau",),
    "ventis": ("ventis",),
    "vénus": ("vénus",),
    "véreaux": ("véreau",),
    "verglas": ("verglas",),
    "verjus": ("verjus",),
    "vermis": ("vermis",),
    "vermisseaux": ("vermisseau",),
    "vernis": ("vernis",),
    "vernix": ("vernix",),
    "véroleuses": ("véroleux",),
    "véroleux": ("véroleux",),
    "véronaises": ("véronais",),
    "véronais": ("véronais",),
    "versaillaises": ("versaillais",),
    "versaillais": ("versaillais",),
    "versailleuses": ("versailleux",),
    "versailleux": ("versailleux",),
    "verseaux": ("verseau",),
    "vers": ("vers",),
    "vertex": ("vertex",),
    "verticaux": ("vertical",),
    "verveux": ("verveux",),
    "vésiculovirus": ("vésiculovirus",),
    "vespéraux": ("vespéral",),
    "vesperus": ("vesperus",),
    "vesses-de-loup": ("vesse-de-loup",),
    "vestes-fantaisie": ("veste-fantaisie",),
    "vetche": ("vetche",),
    "vichy": ("vichy",),
    "vichyssoises": ("vichyssois",),
    "vichyssois": ("vichyssois",),
    "vicieuses": ("vicieux",),
    "vicieux": ("vicieux",),
    "vidéotex": ("vidéotex",),
    "vidimus": ("vidimus",),
    "vielleuses": ("vielleux",),
    "vielleux": ("vielleux",),
    "viennoises": ("viennois",),
    "viennois": ("viennois",),
    "viêt": ("viêt",),
    "vieilles": ("vieux",),
    "vieux": ("vieux",),
    "vigneaux": ("vigneau",),
    "vihara": ("vihara",),
    "villageoises": ("villageois",),
    "villageois": ("villageois",),
    "villicus": ("villicus",),
    "vincent": ("vincent",),
    "vindas": ("vindas",),
    "vindaux": ("vindau",),
    "vingt": ("vingt",),
    "violoneuses": ("violoneux",),
    "violoneux": ("violoneux",),
    "vipereaux": ("vipereau",),
    "vipéreaux": ("vipéreau",),
    "vipériaux": ("vipériau",),
    "virgin": ("virgin",),
    "virus": ("virus",),
    "vis": ("vis",),
    "vitellus": ("vitellus",),
    "vitraux": ("vitrail",),
    "viverravus": ("viverravus",),
    "viviparus": ("viviparus",),
    "vladimir": ("vladimir",),
    "v": ("v",),
    "voceri": ("vocero",),
    "voeux": ("voeu",),
    "voitures-bars": ("voiture-bar",),
    "voitures-cuisines": ("voiture-cuisine",),
    "voitures-lits": ("voiture-lit",),
    "voitures-restaurants": ("voiture-restaurant",),
    "voiturières-transporteuses": ("voiturier-transporteur",),
    "voix": ("voix",),
    "volis": ("volis",),
    "volubilis": ("volubilis",),
    "voluptueuses": ("voluptueux",),
    "voluptueux": ("voluptueux",),
    "volvox": ("volvox",),
    "volvulus": ("volvulus",),
    "vomis-purgatifs": ("vomi-purgatif",),
    "vortex": ("vortex",),
    "vousseaux": ("vousseau",),
    "vouvray": ("vouvray",),
    "vox": ("vox",),
    "vraquiers-pétroliers": ("vraquier-pétrolier",),
    "wagons-citernes": ("wagon-citerne",),
    "wagons-foudres": ("wagon-foudre",),
    "wagons-lits": ("wagon-lit",),
    "wagons-réservoirs": ("wagon-réservoir",),
    "wagons-restaurants": ("wagon-restaurant",),
    "wagons-salons": ("wagon-salon",),
    "wagons-trémies": ("wagon-trémie",),
    "waldorf": ("waldorf",),
    "wallabies": ("wallaby",),
    "watergate": ("watergate",),
    "watts-heures": ("watt-heure",),
    "wattmen": ("wattman",),
    "wc": ("wc",),
    "wells": ("wells",),
    "williams": ("williams",),
    "w": ("w",),
    "won": ("won",),
    "wurtembergeoises": ("wurtembergeois",),
    "wurtembergeois": ("wurtembergeois",),
    "xancus": ("xancus",),
    "xantholinus": ("xantholinus",),
    "xanthosis": ("xanthosis",),
    "xénocristaux": ("xénocristal",),
    "xenos": ("xenos",),
    "xérès": ("xérès",),
    "xérosis": ("xérosis",),
    "xérus": ("xérus",),
    "xi": ("xi",),
    "x": ("x",),
    "xyleborus": ("xyleborus",),
    "xysticus": ("xysticus",),
    "yachtmen": ("yachtman",),
    "yachtsmen": ("yachtsman",),
    "yachtswomen": ("yachtswoman",),
    "yachtwomen": ("yachtwoman",),
    "yaksa": ("yaksa",),
    "yaws": ("yaws",),
    "yeomen": ("yeoman",),
    "yéyé": ("yéyé",),
    "ylangs-ylangs": ("ylang-ylang",),
    "y": ("y",),
    "yo": ("yo",),
    "yo-yo": ("yoyo",),
    "yoyo": ("yoyo",),
    "ypréaux": ("ypréau",),
    "yuppies": ("yuppy",),
    "zabrus": ("zabrus",),
    "zaglossus": ("zaglossus",),
    "zaibatsu": ("zaibatsu",),
    "zaïbatsu": ("zaïbatsu",),
    "zaïroises": ("zaïrois",),
    "zaïrois": ("zaïrois",),
    "zamenis": ("zamenis",),
    "zani": ("zani",),
    "zanni": ("zanni",),
    "zaouia": ("zaouia",),
    "zaouïa": ("zaouïa",),
    "zarkov": ("zarkov",),
    "zawiya": ("zawiya",),
    "zélandaises": ("zélandais",),
    "zélandais": ("zélandais",),
    "zélotes": ("zélotes",),
    "zen": ("zen",),
    "zêta": ("zêta",),
    "zethus": ("zethus",),
    "zigoteaux": ("zigoteau",),
    "zindiq": ("zindiq",),
    "zindîq": ("zindîq",),
    "zingari": ("zingaro",),
    "z": ("z",),
    "zodiac": ("zodiac",),
    "zonabris": ("zonabris",),
    "zonites": ("zonites",),
    "zonitis": ("zonitis",),
    "zoophagus": ("zoophagus",),
    "zostérops": ("zostérops",),
    "zupa": ("zupa",),
    "zuppa": ("zuppa",),
    "zurichoises": ("zurichois",),
    "zurichois": ("zurichois",),
    "zyras": ("zyras",),
    "zyzomys": ("zyzomys",),
    "porte-musc": ("porte-musc",),
    "soul": ("soul",),
    "sociale": ("sociale",),
    "porte-plaque": ("porte-plaque",),
    "sous-estimation": ("sous-estimation",),
    "ouvre-boîte": ("ouvre-boîte",),
    "hégire": ("hégire",),
    "couchitique": ("couchitique",),
    "étouffée": ("étouffée",),
    "méthyl-mercure": ("méthyl-mercure",),
    "grand-chantre": ("grand-chantre",),
    "arrière-cabinet": ("arrière-cabinet",),
    "pisse-copie": ("pisse-copie",),
    "sans-emploi": ("sans-emploi",),
    "couvre-lumière": ("couvre-lumière",),
    "sous-industrialisation": ("sous-industrialisation",),
    "protège-dents": ("protège-dents",),
    "viagra": ("viagra",),
    "sauvette": ("sauvette",),
    "agent-voyer": ("agent-voyer",),
    "nouvelle-ecosse": ("nouvelle-ecosse",),
    "ju-jitsu": ("ju-jitsu",),
    "homme-caoutchouc": ("homme-caoutchouc",),
    "tue-mouche": ("tue-mouche",),
    "saint-benoît": ("saint-benoît",),
    "double-étoffe": ("double-étoffe",),
    "svane": ("svane",),
    "poisson-serpent": ("poisson-serpent",),
    "tussau": ("tussau",),
    "aconit-napel": ("aconit-napel",),
    "thrill": ("thrill",),
    "landerneau": ("landerneau",),
    "semi-nomadisme": ("semi-nomadisme",),
    "polyribosylribitol": ("polyribosylribitol",),
    "natron": ("natron",),
    "coupe-asperges": ("coupe-asperges",),
    "danton": ("danton",),
    "bel-homme": ("bel-homme",),
    "semen-contra": ("semen-contra",),
    "contre-performance": ("contre-performance",),
    "petit-cousin": ("petit-cousin",),
    "épée-baïonnette": ("épée-baïonnette",),
    "banal": ("banal",),
    "aristophane": ("aristophane",),
    "gan": ("gan",),
    "talleyrand": ("talleyrand",),
    "orfèvre-bijoutier": ("orfèvre-bijoutier",),
    "porte-canon": ("porte-canon",),
    "cro-magnon": ("cro-magnon",),
    "abat-jour": ("abat-jour",),
    "tsé-tsé": ("tsé-tsé",),
    "cut-back": ("cut-back",),
    "marivaux": ("marivaux",),
    "chasse-pointe": ("chasse-pointe",),
    "home-studio": ("home-studio",),
    "bar-buffet": ("bar-buffet",),
    "glamour": ("glamour",),
    "groupe-cible": ("groupe-cible",),
    "new-york": ("new-york",),
    "saint-père": ("saint-père",),
    "moi": ("moi",),
    "mégléno-roumain": ("mégléno-roumain",),
    "saint-synode": ("saint-synode",),
    "sri-lankais": ("sri-lankais",),
    "flandrien": ("flandrien",),
    "langue-de-serpent": ("langue-de-serpent",),
    "tête-à-tête": ("tête-à-tête",),
    "halzoun": ("halzoun",),
    "porte-jupe": ("porte-jupe",),
    "colombium": ("colombium",),
    "imperfectivité": ("imperfectivité",),
    "protège-tibia": ("protège-tibia",),
    "gratte-menton": ("gratte-menton",),
    "chasse-peau": ("chasse-peau",),
    "actinium": ("actinium",),
    "avant-midi": ("avant-midi",),
    "perfectum": ("perfectum",),
    "joual": ("joual",),
    "allume-cigare": ("allume-cigare",),
    "largue": ("largue",),
    "kermel": ("kermel",),
    "rummy": ("rummy",),
    "spina-bifida": ("spina-bifida",),
    "bécasseau-maubèche": ("bécasseau-maubèche",),
    "sans-façons": ("sans-façons",),
    "semi-autonomie": ("semi-autonomie",),
    "coupe-douilles": ("coupe-douilles",),
    "hache-légumes": ("hache-légumes",),
    "mao-spontex": ("mao-spontex",),
    "ido": ("ido",),
    "terre-plein": ("terre-plein",),
    "raskol": ("raskol",),
    "hors-bilan": ("hors-bilan",),
    "demi-sommeil": ("demi-sommeil",),
    "fifty-fifty": ("fifty-fifty",),
    "avant-pays": ("avant-pays",),
    "cité-jardin": ("cité-jardin",),
    "petite-venise": ("petite-venise",),
    "tripette": ("tripette",),
    "non-accompli": ("non-accompli",),
    "contre-emploi": ("contre-emploi",),
    "wagon-plateforme": ("wagon-plateforme",),
    "bouche-à-bouche": ("bouche-à-bouche",),
    "sergent-major": ("sergent-major",),
    "non-linéarité": ("non-linéarité",),
    "quatre-quarts": ("quatre-quarts",),
    "pop": ("pop",),
    "ramasse-couverts": ("ramasse-couverts",),
    "monte-courroie": ("monte-courroie",),
    "marat": ("marat",),
    "halobios": ("halobios",),
    "dessus-de-porte": ("dessus-de-porte",),
    "saute-ruisseau": ("saute-ruisseau",),
    "stellionat": ("stellionat",),
    "définitive": ("définitive",),
    "dame-pipi": ("dame-pipi",),
    "yttrium": ("yttrium",),
    "porte-fleurs": ("porte-fleurs",),
    "thermidor": ("thermidor",),
    "sous-gorge": ("sous-gorge",),
    "hors-ligne": ("hors-ligne",),
    "trois-mâts": ("trois-mâts",),
    "copernic": ("copernic",),
    "casse-poitrine": ("casse-poitrine",),
    "macro-instruction": ("macro-instruction",),
    "sous-adresse": ("sous-adresse",),
    "hold-up": ("hold-up",),
    "pince-pantalon": ("pince-pantalon",),
    "porte-chandelle": ("porte-chandelle",),
    "discussion-marathon": ("discussion-marathon",),
    "tire-clou": ("tire-clou",),
    "grille-pain": ("grille-pain",),
    "sensationnel": ("sensationnel",),
    "poissard": ("poissard",),
    "pisse-vinaigre": ("pisse-vinaigre",),
    "nord-est": ("nord-est",),
    "bloc-cylindre": ("bloc-cylindre",),
    "working": ("working",),
    "pin-up": ("pin-up",),
    "provisoire": ("provisoire",),
    "bateau-pilote": ("bateau-pilote",),
    "blanc-manger": ("blanc-manger",),
    "cérium": ("cérium",),
    "tête-à-queue": ("tête-à-queue",),
    "chez-soi": ("chez-soi",),
    "pèse-alcool": ("pèse-alcool",),
    "port-salut": ("port-salut",),
    "ever": ("ever",),
    "boute-selle": ("boute-selle",),
    "méningo-myélite": ("méningo-myélite",),
    "chemise-culotte": ("chemise-culotte",),
    "plus-que-parfait": ("plus-que-parfait",),
    "halte-garderie": ("halte-garderie",),
    "rouge-queue": ("rouge-queue",),
    "haute-loire": ("haute-loire",),
    "appuie-bras": ("appuie-bras",),
    "jeunisme": ("jeunisme",),
    "talaing": ("talaing",),
    "mètre-kilogramme": ("mètre-kilogramme",),
    "duce": ("duce",),
    "demi-jour": ("demi-jour",),
    "arrière-pays": ("arrière-pays",),
    "check-up": ("check-up",),
    "eurocode": ("eurocode",),
    "vesou": ("vesou",),
    "non-représentation": ("non-représentation",),
    "presse-bouton": ("presse-bouton",),
    "terre-neuve": ("terre-neuve",),
    "sous-amendement": ("sous-amendement",),
    "poisson-pilote": ("poisson-pilote",),
    "bachi-bouzouk": ("bachi-bouzouk",),
    "porte-amarre": ("porte-amarre",),
    "débat-fleuve": ("débat-fleuve",),
    "porte-jarretelles": ("porte-jarretelles",),
    "vert-de-gris": ("vert-de-gris",),
    "micro-injection": ("micro-injection",),
    "dame-honteuse": ("dame-honteuse",),
    "sous-anneau": ("sous-anneau",),
    "dichlorodiéthyl": ("dichlorodiéthyl",),
    "convenu": ("convenu",),
    "songhaï": ("songhaï",),
    "cure-casserole": ("cure-casserole",),
    "chasse-tampon": ("chasse-tampon",),
    "chaude-pisse": ("chaude-pisse",),
    "coupe-cigare": ("coupe-cigare",),
    "technicolor": ("technicolor",),
    "futurible": ("futurible",),
    "tac": ("tac",),
    "mille-pattes": ("mille-pattes",),
    "porte-charbon": ("porte-charbon",),
    "medicine-man": ("medicine-man",),
    "tire-gargousse": ("tire-gargousse",),
    "sans-dieu": ("sans-dieu",),
    "koumis": ("koumis",),
    "sous-végétation": ("sous-végétation",),
    "ball-trap": ("ball-trap",),
    "normannien": ("normannien",),
    "demi-caponnière": ("demi-caponnière",),
    "nagui": ("nagui",),
    "sous-catégorie": ("sous-catégorie",),
    "tige-poussoir": ("tige-poussoir",),
    "yiddish": ("yiddish",),
    "haschich": ("haschich",),
    "bague-allonge": ("bague-allonge",),
    "aveuglette": ("aveuglette",),
    "fauteuil-vase": ("fauteuil-vase",),
    "play-back": ("play-back",),
    "lave-vaisselle": ("lave-vaisselle",),
    "sous-chef": ("sous-chef",),
    "grand-halte": ("grand-halte",),
    "garde-crotte": ("garde-crotte",),
    "kief": ("kief",),
    "post-scriptum": ("post-scriptum",),
    "fouette": ("fouette",),
    "ferme-circuit": ("ferme-circuit",),
    "moins-disant": ("moins-disant",),
    "roméique": ("roméique",),
    "scoured": ("scoured",),
    "hosteau": ("hosteau",),
    "nagari": ("nagari",),
    "non-emploi": ("non-emploi",),
    "non-existence": ("non-existence",),
    "sous-carbonate": ("sous-carbonate",),
    "nord-ouest": ("nord-ouest",),
    "florès": ("florès",),
    "arrière-train": ("arrière-train",),
    "oiseau-tempête": ("oiseau-tempête",),
    "porte-mètre": ("porte-mètre",),
    "voyage-marathon": ("voyage-marathon",),
    "garde-corps": ("garde-corps",),
    "aberdeen-angus": ("aberdeen-angus",),
    "levant": ("levant",),
    "faux-bourdon": ("faux-bourdon",),
    "après-midi": ("après-midi",),
    "indium": ("indium",),
    "demi-sourire": ("demi-sourire",),
    "passe-couloir": ("passe-couloir",),
    "avant-plan": ("avant-plan",),
    "semi-carbazide": ("semi-carbazide",),
    "pèse": ("pèse",),
    "garde-temps": ("garde-temps",),
    "sien": ("sien",),
    "core": ("core",),
    "garde-nappe": ("garde-nappe",),
    "demi-certitude": ("demi-certitude",),
    "oedipe": ("oedipe",),
    "tube-canon": ("tube-canon",),
    "mélange-maître": ("mélange-maître",),
    "électro-oculographie": ("électro-oculographie",),
    "demi-palier": ("demi-palier",),
    "pérical": ("pérical",),
    "stendhal": ("stendhal",),
    "semi-fonction": ("semi-fonction",),
    "femme-grenouille": ("femme-grenouille",),
    "trucmuche": ("trucmuche",),
    "europium": ("europium",),
    "porte-montre": ("porte-montre",),
    "porte-brancard": ("porte-brancard",),
    "pare-soleil": ("pare-soleil",),
    "tangible": ("tangible",),
    "cessez-le-feu": ("cessez-le-feu",),
    "gros-vert": ("gros-vert",),
    "casse-écrou": ("casse-écrou",),
    "ronde-bosse": ("ronde-bosse",),
    "buenos-aires": ("buenos-aires",),
    "outrepasse": ("outrepasse",),
    "chantilly": ("chantilly",),
    "rhétien": ("rhétien",),
    "cheval-heure": ("cheval-heure",),
    "arrière-port": ("arrière-port",),
    "effet-boomerang": ("effet-boomerang",),
    "rousse": ("rousse",),
    "tigré": ("tigré",),
    "calf": ("calf",),
    "après-minuit": ("après-minuit",),
    "fesse-mathieu": ("fesse-mathieu",),
    "tupi-guarani": ("tupi-guarani",),
    "bécasseau-échasse": ("bécasseau-échasse",),
    "know-how": ("know-how",),
    "à-venir": ("à-venir",),
    "envi": ("envi",),
    "chewing-gum": ("chewing-gum",),
    "self-excitation": ("self-excitation",),
    "oeil-de-mouche": ("oeil-de-mouche",),
    "objet-souvenir": ("objet-souvenir",),
    "soixante-dixième": ("soixante-dixième",),
    "assurance-vieillesse": ("assurance-vieillesse",),
    "cache-maille": ("cache-maille",),
    "trop-plein": ("trop-plein",),
    "calambre": ("calambre",),
    "time-sharing": ("time-sharing",),
    "aléoute": ("aléoute",),
    "ytterbium": ("ytterbium",),
    "porte-cordeau": ("porte-cordeau",),
    "avion-école": ("avion-école",),
    "sir": ("sir",),
    "kha": ("kha",),
    "passe-temps": ("passe-temps",),
    "café-brasserie": ("café-brasserie",),
    "blanc-russe": ("blanc-russe",),
    "ça": ("ça",),
    "pince-étoffe": ("pince-étoffe",),
    "tchocoatl": ("tchocoatl",),
    "pire": ("pire",),
    "quasi-société": ("quasi-société",),
    "protège-parapluie": ("protège-parapluie",),
    "conimène": ("conimène",),
    "lutétium": ("lutétium",),
    "après-coup": ("après-coup",),
    "affleureuse-défonceuse": ("affleureuse-défonceuse",),
    "avant-jeu": ("avant-jeu",),
    "dupont": ("dupont",),
    "gastro-entérologie": ("gastro-entérologie",),
    "baby-sitting": ("baby-sitting",),
    "coupe-collets": ("coupe-collets",),
    "spinoza": ("spinoza",),
    "pied-de-griffon": ("pied-de-griffon",),
    "sous-comptoir": ("sous-comptoir",),
    "appuie-nuque": ("appuie-nuque",),
    "molière": ("molière",),
    "appuie-tête": ("appuie-tête",),
    "champoreau": ("champoreau",),
    "sex-symbol": ("sex-symbol",),
    "ginguet": ("ginguet",),
    "philo": ("philo",),
    "palmyrénien": ("palmyrénien",),
    "kirghize": ("kirghize",),
    "saint-sylvestre": ("saint-sylvestre",),
    "inserm": ("inserm",),
    "soufre": ("soufre",),
    "pied-de-loup": ("pied-de-loup",),
    "jet-society": ("jet-society",),
    "serre-livres": ("serre-livres",),
    "porte-mouchettes": ("porte-mouchettes",),
    "dum-dum": ("dum-dum",),
    "brise-roche": ("brise-roche",),
    "théréen": ("théréen",),
    "roi-prêtre": ("roi-prêtre",),
    "porte-guigne": ("porte-guigne",),
    "national-socialisme": ("national-socialisme",),
    "prétantaine": ("prétantaine",),
    "chasse-fiente": ("chasse-fiente",),
    "saignant": ("saignant",),
    "saint-frusquin": ("saint-frusquin",),
    "radio-réveil": ("radio-réveil",),
    "bus-bibliothèque": ("bus-bibliothèque",),
    "ex-urss": ("ex-urss",),
    "accoutumée": ("accoutumée",),
    "penser": ("penser",),
    "dos-à-dos": ("dos-à-dos",),
    "micro-univers": ("micro-univers",),
    "porte-trésor": ("porte-trésor",),
    "picpoule": ("picpoule",),
    "agro-alimentaire": ("agro-alimentaire",),
    "tulu": ("tulu",),
    "faire-valoir": ("faire-valoir",),
    "essuie-main": ("essuie-main",),
    "assurance-maternité": ("assurance-maternité",),
    "demi-concentrateur": ("demi-concentrateur",),
    "francique": ("francique",),
    "bombance": ("bombance",),
    "tire-braise": ("tire-braise",),
    "jussion": ("jussion",),
    "potron-minet": ("potron-minet",),
    "saint-hubert": ("saint-hubert",),
    "non-sens": ("non-sens",),
    "non-dit": ("non-dit",),
    "mister": ("mister",),
    "thyréophyma": ("thyréophyma",),
    "sous-délégation": ("sous-délégation",),
    "échelle-observatoire": ("échelle-observatoire",),
    "jupe-culotte": ("jupe-culotte",),
    "micro-informatique": ("micro-informatique",),
    "disque-jockey": ("disque-jockey",),
    "cul-doré": ("cul-doré",),
    "ramasse-miettes": ("ramasse-miettes",),
    "garde-infante": ("garde-infante",),
    "sans-parti": ("sans-parti",),
    "rupia": ("rupia",),
    "tien": ("tien",),
    "chamito-sémitique": ("chamito-sémitique",),
    "corynébactérium": ("corynébactérium",),
    "oye": ("oye",),
    "sous-quadruple": ("sous-quadruple",),
    "cherche-fil": ("cherche-fil",),
    "gas-oil": ("gas-oil",),
    "casse-pieds": ("casse-pieds",),
    "gâte-filles": ("gâte-filles",),
    "francium": ("francium",),
    "sous-utilisation": ("sous-utilisation",),
    "sous-délégué": ("sous-délégué",),
    "chauffe-bain": ("chauffe-bain",),
    "blush": ("blush",),
    "plein-jeu": ("plein-jeu",),
    "ruine-de-rome": ("ruine-de-rome",),
    "porte-chance": ("porte-chance",),
    "porte-bouteille": ("porte-bouteille",),
    "meurette": ("meurette",),
    "dam": ("dam",),
    "médecin-commandant": ("médecin-commandant",),
    "omerta": ("omerta",),
    "body-building": ("body-building",),
    "contre-plaqué": ("contre-plaqué",),
    "ouvre-huître": ("ouvre-huître",),
    "firmware": ("firmware",),
    "florental": ("florental",),
    "wagon-poste": ("wagon-poste",),
    "piedra": ("piedra",),
    "femme-agent": ("femme-agent",),
    "croco": ("croco",),
    "yacht-club": ("yacht-club",),
    "potassium": ("potassium",),
    "couteau-hélice": ("couteau-hélice",),
    "non-recevoir": ("non-recevoir",),
    "queue-de-voile": ("queue-de-voile",),
    "hi-fi": ("hi-fi",),
    "inexpliqué": ("inexpliqué",),
    "ginder": ("ginder",),
    "grande-bretagne": ("grande-bretagne",),
    "non-stoechiométrie": ("non-stoechiométrie",),
    "beau": ("beau",),
    "sous-trait": ("sous-trait",),
    "opéra-comique": ("opéra-comique",),
    "sous-battage": ("sous-battage",),
    "astate": ("astate",),
    "yin": ("yin",),
    "belle-soeur": ("belle-soeur",),
    "porte-bijoux": ("porte-bijoux",),
    "niobium": ("niobium",),
    "flouse": ("flouse",),
    "non-violence": ("non-violence",),
    "monte-charge": ("monte-charge",),
    "topo-guide": ("topo-guide",),
    "bellevue": ("bellevue",),
    "homère": ("homère",),
    "prétentaine": ("prétentaine",),
    "haute-lissier": ("haute-lissier",),
    "jet-set": ("jet-set",),
    "sans-travail": ("sans-travail",),
    "grand-rue": ("grand-rue",),
    "montre-bracelet": ("montre-bracelet",),
    "motou": ("motou",),
    "lab": ("lab",),
    "judéo-espagnol": ("judéo-espagnol",),
    "encontre": ("encontre",),
    "sans-abri": ("sans-abri",),
    "garde-pile": ("garde-pile",),
    "horse-guard": ("horse-guard",),
    "armoire-toile": ("armoire-toile",),
    "ska": ("ska",),
    "austro-hongrois": ("austro-hongrois",),
    "chauffe-liquide": ("chauffe-liquide",),
    "gastro-ferrine": ("gastro-ferrine",),
    "mont-de-piété": ("mont-de-piété",),
    "demi-queue": ("demi-queue",),
    "saint-julien": ("saint-julien",),
    "tailleur-pantalon": ("tailleur-pantalon",),
    "extrême-onction": ("extrême-onction",),
    "état-tampon": ("état-tampon",),
    "finno-ougrien": ("finno-ougrien",),
    "vo": ("vo",),
    "belle-de-jour": ("belle-de-jour",),
    "bas-officier": ("bas-officier",),
    "attrape-nigaud": ("attrape-nigaud",),
    "photo-finish": ("photo-finish",),
    "avant-choeur": ("avant-choeur",),
    "knock-out": ("knock-out",),
    "marathi": ("marathi",),
    "trouble-fête": ("trouble-fête",),
    "bulletin-réponse": ("bulletin-réponse",),
    "j'm'en-foutisme": ("j'm'en-foutisme",),
    "casse-tête": ("casse-tête",),
    "partie-cycle": ("partie-cycle",),
    "radio-immunisation": ("radio-immunisation",),
    "contre-expertise": ("contre-expertise",),
    "garde-rivière": ("garde-rivière",),
    "taille-pré": ("taille-pré",),
    "néosyriaque": ("néosyriaque",),
    "chauffe-fer": ("chauffe-fer",),
    "messidor": ("messidor",),
    "radon": ("radon",),
    "non-tanin": ("non-tanin",),
    "arrache-bouchon": ("arrache-bouchon",),
    "portrait-charge": ("portrait-charge",),
    "tennis-elbow": ("tennis-elbow",),
    "attaque-suicide": ("attaque-suicide",),
    "poisson-lune": ("poisson-lune",),
    "groove": ("groove",),
    "pied-de-coq": ("pied-de-coq",),
    "sous-diaconat": ("sous-diaconat",),
    "petit-déjeuner": ("petit-déjeuner",),
    "invitation-prestige": ("invitation-prestige",),
    "hadith": ("hadith",),
    "couvre-plat": ("couvre-plat",),
    "eros": ("eros",),
    "trou-trou": ("trou-trou",),
    "sous-virage": ("sous-virage",),
    "invisible": ("invisible",),
    "polyane": ("polyane",),
    "floréal": ("floréal",),
    "goutte-à-goutte": ("goutte-à-goutte",),
    "électro-endosmose": ("électro-endosmose",),
    "demi-hiatus": ("demi-hiatus",),
    "demi-pirouette": ("demi-pirouette",),
    "demi-cloison": ("demi-cloison",),
    "sodium": ("sodium",),
    "frise-beurre": ("frise-beurre",),
    "sous-investissement": ("sous-investissement",),
    "brick-goélette": ("brick-goélette",),
    "micro-cravate": ("micro-cravate",),
    "bicane": ("bicane",),
    "saint-nectaire": ("saint-nectaire",),
    "pied-cornier": ("pied-cornier",),
    "double-quatre": ("double-quatre",),
    "barrage-voûte": ("barrage-voûte",),
    "gâte-maison": ("gâte-maison",),
    "visible": ("visible",),
    "quasi-entreprise": ("quasi-entreprise",),
    "humide": ("humide",),
    "demi-quart": ("demi-quart",),
    "trouble-paix": ("trouble-paix",),
    "soûl": ("soûl",),
    "antistreptodornase": ("antistreptodornase",),
    "haladi": ("haladi",),
    "bouche-trou": ("bouche-trou",),
    "porte-lance": ("porte-lance",),
    "sous-location": ("sous-location",),
    "cyclo-cross": ("cyclo-cross",),
    "cache-époutis": ("cache-époutis",),
    "fourgon-pompe": ("fourgon-pompe",),
    "lanthane": ("lanthane",),
    "halobentos": ("halobentos",),
    "baby-foot": ("baby-foot",),
    "incontinentia": ("incontinentia",),
    "antimoine": ("antimoine",),
    "nouvelle-guinée": ("nouvelle-guinée",),
    "impossible": ("impossible",),
    "lance-fusées": ("lance-fusées",),
    "olympia": ("olympia",),
    "sellerie-bourrellerie": ("sellerie-bourrellerie",),
    "ripieno": ("ripieno",),
    "mi-carême": ("mi-carême",),
    "semi-fluide": ("semi-fluide",),
    "quasi-unanimité": ("quasi-unanimité",),
    "mini-ordinateur": ("mini-ordinateur",),
    "pole-position": ("pole-position",),
    "béryllium": ("béryllium",),
    "flouze": ("flouze",),
    "cash-flow": ("cash-flow",),
    "bloc-notes": ("bloc-notes",),
    "serre-câble": ("serre-câble",),
    "sous-consommation": ("sous-consommation",),
    "faux-pont": ("faux-pont",),
    "sous-voltage": ("sous-voltage",),
    "coupe-batterie": ("coupe-batterie",),
    "mien": ("mien",),
    "lance-patates": ("lance-patates",),
    "orthopédiste-bandagiste": ("orthopédiste-bandagiste",),
    "hard-bop": ("hard-bop",),
    "porte-dais": ("porte-dais",),
    "pick-up": ("pick-up",),
    "fox-trot": ("fox-trot",),
    "valdiguier": ("valdiguier",),
    "julius": ("julius",),
    "indicateur-jauge": ("indicateur-jauge",),
    "hâle-à-bord": ("hâle-à-bord",),
    "surnaturel": ("surnaturel",),
    "vélotaxi": ("vélotaxi",),
    "chat-pard": ("chat-pard",),
    "surréel": ("surréel",),
    "primo-invasion": ("primo-invasion",),
    "tiers-monde": ("tiers-monde",),
    "ventôse": ("ventôse",),
    "pousse-pointe": ("pousse-pointe",),
    "grille-marron": ("grille-marron",),
    "maison-blanche": ("maison-blanche",),
    "porte-plongeur": ("porte-plongeur",),
    "gobe-or": ("gobe-or",),
    "iridium": ("iridium",),
    "en-soi": ("en-soi",),
    "pince-fil": ("pince-fil",),
    "baise-pied": ("baise-pied",),
    "titane": ("titane",),
    "greg": ("greg",),
    "grippe-coquin": ("grippe-coquin",),
    "taillardier": ("taillardier",),
    "agon": ("agon",),
    "rahat-loukoum": ("rahat-loukoum",),
    "brahmi": ("brahmi",),
    "sémitique": ("sémitique",),
    "remue-ménage": ("remue-ménage",),
    "basse-contre": ("basse-contre",),
    "défense-recours": ("défense-recours",),
    "barbe-de-vache": ("barbe-de-vache",),
    "porte-bonnet": ("porte-bonnet",),
    "porte-à-faux": ("porte-à-faux",),
    "pied-à-terre": ("pied-à-terre",),
    "hale-avant": ("hale-avant",),
    "black-out": ("black-out",),
    "croche-pied": ("croche-pied",),
    "raï": ("raï",),
    "croix-rouge": ("croix-rouge",),
    "vrac": ("vrac",),
    "xocoatl": ("xocoatl",),
    "escient": ("escient",),
    "sud": ("sud",),
    "porte-bobine": ("porte-bobine",),
    "inexprimable": ("inexprimable",),
    "guide-ligne": ("guide-ligne",),
    "demi-botte": ("demi-botte",),
    "sous-groupement": ("sous-groupement",),
    "passé-maître": ("passé-maître",),
    "ballon-pilote": ("ballon-pilote",),
    "gage-contre": ("gage-contre",),
    "perce-feuille": ("perce-feuille",),
    "méta": ("méta",),
    "ruthénium": ("ruthénium",),
    "shuttle-car": ("shuttle-car",),
    "contre-pied": ("contre-pied",),
    "sécu": ("sécu",),
    "montrachet": ("montrachet",),
    "tennis-barbe": ("tennis-barbe",),
    "attrape-mouches": ("attrape-mouches",),
    "sous-genre": ("sous-genre",),
    "prairial": ("prairial",),
    "kongo": ("kongo",),
    "joue-à-joue": ("joue-à-joue",),
    "épine-vinette": ("épine-vinette",),
    "extrême-orient": ("extrême-orient",),
    "dessus-de-lit": ("dessus-de-lit",),
    "remue-méninges": ("remue-méninges",),
    "dol": ("dol",),
    "gueusaille": ("gueusaille",),
    "menu-gros": ("menu-gros",),
    "demi-monde": ("demi-monde",),
    "casse-pipe": ("casse-pipe",),
    "atlantique": ("atlantique",),
    "double-croche": ("double-croche",),
    "fouille-merde": ("fouille-merde",),
    "psychique": ("psychique",),
    "sous-échantillon": ("sous-échantillon",),
    "boucherie-charcuterie": ("boucherie-charcuterie",),
    "non-dénonciation": ("non-dénonciation",),
    "cross-country": ("cross-country",),
    "difool": ("difool",),
    "sélénium": ("sélénium",),
    "sous-secteur": ("sous-secteur",),
    "lance-missiles": ("lance-missiles",),
    "rhodium": ("rhodium",),
    "pittoresque": ("pittoresque",),
    "impulsion-obsession": ("impulsion-obsession",),
    "strontium": ("strontium",),
    "bore": ("bore",),
    "vive-arête": ("vive-arête",),
    "montesquieu": ("montesquieu",),
    "quart-de-pouce": ("quart-de-pouce",),
    "train-famille": ("train-famille",),
    "roman-feuilleton": ("roman-feuilleton",),
    "lance-grenades": ("lance-grenades",),
    "on-dit": ("on-dit",),
    "porte-lof": ("porte-lof",),
    "plein-temps": ("plein-temps",),
    "pique-feuille": ("pique-feuille",),
    "mont-blanc": ("mont-blanc",),
    "brain-trust": ("brain-trust",),
    "guèze": ("guèze",),
    "bec-de-corbeau": ("bec-de-corbeau",),
    "cool": ("cool",),
    "gros-yeux": ("gros-yeux",),
    "grille-écran": ("grille-écran",),
    "cap-vert": ("cap-vert",),
    "kawi": ("kawi",),
    "sauve-qui-peut": ("sauve-qui-peut",),
    "tournemain": ("tournemain",),
    "avion-mammouth": ("avion-mammouth",),
    "brome": ("brome",),
    "cure-langue": ("cure-langue",),
    "sous-veau": ("sous-veau",),
    "active": ("active",),
    "vive-eau": ("vive-eau",),
    "navire-usine": ("navire-usine",),
    "trachéo-laryngotomie": ("trachéo-laryngotomie",),
    "etats-unis": ("etats-unis",),
    "amour-propre": ("amour-propre",),
    "guili-guili": ("guili-guili",),
    "sainte-alliance": ("sainte-alliance",),
    "social-démocratie": ("social-démocratie",),
    "libyque": ("libyque",),
    "lyre-cithare": ("lyre-cithare",),
    "aluminium": ("aluminium",),
    "llandeilien": ("llandeilien",),
    "ex-femme": ("ex-femme",),
    "ci-devant": ("ci-devant",),
    "narco-analyste": ("narco-analyste",),
    "vide-ordures": ("vide-ordures",),
    "feud": ("feud",),
    "xhosa": ("xhosa",),
    "tire-botte": ("tire-botte",),
    "basket-ball": ("basket-ball",),
    "indispensable": ("indispensable",),
    "rendez-vous": ("rendez-vous",),
    "solaire": ("solaire",),
    "rez-de-chaussée": ("rez-de-chaussée",),
    "passe-pierre": ("passe-pierre",),
    "kiff": ("kiff",),
    "arrière-fond": ("arrière-fond",),
    "mini-informatique": ("mini-informatique",),
    "après-communisme": ("après-communisme",),
    "sous-exploitation": ("sous-exploitation",),
    "hasch": ("hasch",),
    "avant-quart": ("avant-quart",),
    "saint-jean": ("saint-jean",),
    "avant-bouche": ("avant-bouche",),
    "cover-crop": ("cover-crop",),
    "sous-preneur": ("sous-preneur",),
    "mélangeur-décanteur": ("mélangeur-décanteur",),
    "tokelau": ("tokelau",),
    "néogrec": ("néogrec",),
    "butyral": ("butyral",),
    "tiers-an": ("tiers-an",),
    "médullo-surrénalome": ("médullo-surrénalome",),
    "taille-vent": ("taille-vent",),
    "orang-outang": ("orang-outang",),
    "xénon": ("xénon",),
    "lit-cage": ("lit-cage",),
    "gobe-baleine": ("gobe-baleine",),
    "non-engagement": ("non-engagement",),
    "permo-carbonifère": ("permo-carbonifère",),
    "phénindione": ("phénindione",),
    "demi-espace": ("demi-espace",),
    "sous-test": ("sous-test",),
    "zirconium": ("zirconium",),
    "amharique": ("amharique",),
    "après-manger": ("après-manger",),
    "dakin": ("dakin",),
    "technétium": ("technétium",),
    "lève-glace": ("lève-glace",),
    "quatre-vingts": ("quatre-vingts",),
    "plate-tombe": ("plate-tombe",),
    "adénosine-phosphate": ("adénosine-phosphate",),
    "miso": ("miso",),
    "show-biz": ("show-biz",),
    "contre-courant": ("contre-courant",),
    "vulgaire": ("vulgaire",),
    "anglo": ("anglo",),
    "iso-immunisation": ("iso-immunisation",),
    "connu": ("connu",),
    "vis-à-vis": ("vis-à-vis",),
    "breveté": ("breveté",),
    "pare-étoupille": ("pare-étoupille",),
    "passe-vin": ("passe-vin",),
    "rat-taupe": ("rat-taupe",),
    "porte-papier": ("porte-papier",),
    "laisser-passer": ("laisser-passer",),
    "porte-baguette": ("porte-baguette",),
    "joran": ("joran",),
    "mangy": ("mangy",),
    "rhétique": ("rhétique",),
    "tête-de-nègre": ("tête-de-nègre",),
    "oumiak": ("oumiak",),
    "goscinny": ("goscinny",),
    "semi-conserve": ("semi-conserve",),
    "gomme-résine": ("gomme-résine",),
    "petit-neveu": ("petit-neveu",),
    "crédit-bail": ("crédit-bail",),
    "sous-programme": ("sous-programme",),
    "médecin-spécialiste": ("médecin-spécialiste",),
    "polonium": ("polonium",),
    "échantillon-témoin": ("échantillon-témoin",),
    "mitterrandisme": ("mitterrandisme",),
    "animus": ("animus",),
    "flash-back": ("flash-back",),
    "surprise-party": ("surprise-party",),
    "mort-bois": ("mort-bois",),
    "entre-axes": ("entre-axes",),
    "cache-sexe": ("cache-sexe",),
    "sang-froid": ("sang-froid",),
    "tire-fond": ("tire-fond",),
    "torah": ("torah",),
    "semi-conduction": ("semi-conduction",),
    "vraisemblable": ("vraisemblable",),
    "martel": ("martel",),
    "tao": ("tao",),
    "tête-de-maure": ("tête-de-maure",),
    "spatial": ("spatial",),
    "porte-clapet": ("porte-clapet",),
    "taille-haie": ("taille-haie",),
    "sellier-bourrelier": ("sellier-bourrelier",),
    "uranium": ("uranium",),
    "gras-double": ("gras-double",),
    "prince-de-galles": ("prince-de-galles",),
    "sous-affluent": ("sous-affluent",),
    "vest": ("vest",),
    "ouest": ("ouest",),
    "vercingétorix": ("vercingétorix",),
    "double-as": ("double-as",),
    "garde-boue": ("garde-boue",),
    "navire-citerne": ("navire-citerne",),
    "sacro-iléite": ("sacro-iléite",),
    "sans-papiers": ("sans-papiers",),
    "frisquet": ("frisquet",),
    "connection": ("connection",),
    "andi": ("andi",),
    "pare-brise": ("pare-brise",),
    "couvre-terre": ("couvre-terre",),
    "chapeau-melon": ("chapeau-melon",),
    "hindoustani": ("hindoustani",),
    "chausse-trape": ("chausse-trape",),
    "pied-de-poule": ("pied-de-poule",),
    "skeet": ("skeet",),
    "carême-prenant": ("carême-prenant",),
    "dondaine": ("dondaine",),
    "contre-réforme": ("contre-réforme",),
    "pis-aller": ("pis-aller",),
    "alfénide": ("alfénide",),
    "perestroïka": ("perestroïka",),
    "non-conformiste": ("non-conformiste",),
    "cache-aiguilles": ("cache-aiguilles",),
    "économique": ("économique",),
    "skye-terrier": ("skye-terrier",),
    "impensé": ("impensé",),
    "néogothique": ("néogothique",),
    "gastro-jéjunostomie": ("gastro-jéjunostomie",),
    "possible": ("possible",),
    "haidérisme": ("haidérisme",),
    "volley-ball": ("volley-ball",),
    "sang-de-boeuf": ("sang-de-boeuf",),
    "ex-maire": ("ex-maire",),
    "amrita": ("amrita",),
    "franco-canadien": ("franco-canadien",),
    "perfectivité": ("perfectivité",),
    "tire-veine": ("tire-veine",),
    "quatre-moines": ("quatre-moines",),
    "réfrigérateur-congélateur": ("réfrigérateur-congélateur",),
    "navire-hôpital": ("navire-hôpital",),
    "porte-aune": ("porte-aune",),
    "viniyoga": ("viniyoga",),
    "vice-consul": ("vice-consul",),
    "casse-sucre": ("casse-sucre",),
    "pare-pierres": ("pare-pierres",),
    "sous-équipement": ("sous-équipement",),
    "in-quarto": ("in-quarto",),
    "cache-coeur": ("cache-coeur",),
    "hors-jeu": ("hors-jeu",),
    "grandiose": ("grandiose",),
    "high-tech": ("high-tech",),
    "sous-lieutenant": ("sous-lieutenant",),
    "grécal": ("grécal",),
    "borne-fontaine": ("borne-fontaine",),
    "thio-indigo": ("thio-indigo",),
    "fima": ("fima",),
    "grill-express": ("grill-express",),
    "aide-mémoire": ("aide-mémoire",),
    "protège-radiateur": ("protège-radiateur",),
    "quasi-rente": ("quasi-rente",),
    "moyen-age": ("moyen-age",),
    "moulin-à-vent": ("moulin-à-vent",),
    "demi-vie": ("demi-vie",),
    "loir-et-cher": ("loir-et-cher",),
    "lapis-lazuli": ("lapis-lazuli",),
    "écart-type": ("écart-type",),
    "bien-aller": ("bien-aller",),
    "guinée-bissau": ("guinée-bissau",),
    "thora": ("thora",),
    "évite-molettes": ("évite-molettes",),
    "faux-sens": ("faux-sens",),
    "vade-mecum": ("vade-mecum",),
    "cherche-pôles": ("cherche-pôles",),
    "super-g": ("super-g",),
    "décor-praticable": ("décor-praticable",),
    "kammerspiel": ("kammerspiel",),
    "cul-terreux": ("cul-terreux",),
    "café-tabac": ("café-tabac",),
    "azote": ("azote",),
    "grand-angle": ("grand-angle",),
    "sous-verre": ("sous-verre",),
    "sous-niveau": ("sous-niveau",),
    "crédit-vacance": ("crédit-vacance",),
    "glosso-pharyngien": ("glosso-pharyngien",),
    "va-nu-pieds": ("va-nu-pieds",),
    "cobalt": ("cobalt",),
    "chabrol": ("chabrol",),
    "belle-maman": ("belle-maman",),
    "bren": ("bren",),
    "turlurette": ("turlurette",),
    "addendum": ("addendum",),
    "hot": ("hot",),
    "marie-jeanne": ("marie-jeanne",),
    "super": ("super",),
    "salon-boudoir": ("salon-boudoir",),
    "harari": ("harari",),
    "version-lit": ("version-lit",),
    "tour-operator": ("tour-operator",),
    "auto-ambulance": ("auto-ambulance",),
    "sous-clavière": ("sous-clavière",),
    "micro-satellite": ("micro-satellite",),
    "aragon": ("aragon",),
    "épargne-logement": ("épargne-logement",),
    "arrière-bras": ("arrière-bras",),
    "tyrrhénien": ("tyrrhénien",),
    "afro-asiatique": ("afro-asiatique",),
    "mini-usine": ("mini-usine",),
    "allumette-bougie": ("allumette-bougie",),
    "risque-tout": ("risque-tout",),
    "peintre-cartonnier": ("peintre-cartonnier",),
    "frisbee": ("frisbee",),
    "trading": ("trading",),
    "relève-gravure": ("relève-gravure",),
    "casse-graine": ("casse-graine",),
    "sous-ministre": ("sous-ministre",),
    "non-usage": ("non-usage",),
    "boîte-chargeur": ("boîte-chargeur",),
    "bateau-hôpital": ("bateau-hôpital",),
    "pima": ("pima",),
    "queue-de-morue": ("queue-de-morue",),
    "poisson-clown": ("poisson-clown",),
    "pur-sang": ("pur-sang",),
    "lancelot": ("lancelot",),
    "javel": ("javel",),
    "putamen": ("putamen",),
    "entre-deux-mers": ("entre-deux-mers",),
    "wagon-bar": ("wagon-bar",),
    "water-mangle": ("water-mangle",),
    "coupe-coupe": ("coupe-coupe",),
    "nobélium": ("nobélium",),
    "thoraco-phéno-laparotomie": ("thoraco-phéno-laparotomie",),
    "pigeon-hirondelle": ("pigeon-hirondelle",),
    "porte-objectif": ("porte-objectif",),
    "amuse-gueule": ("amuse-gueule",),
    "quatre-quatre": ("quatre-quatre",),
    "franc-bord": ("franc-bord",),
    "porte-tolet": ("porte-tolet",),
    "tom-pouce": ("tom-pouce",),
    "sous-colle": ("sous-colle",),
    "hachisch": ("hachisch",),
    "metal": ("metal",),
    "agrég": ("agrég",),
    "éblaïte": ("éblaïte",),
    "obsession-impulsion": ("obsession-impulsion",),
    "bar-restaurant": ("bar-restaurant",),
    "arrière-saison": ("arrière-saison",),
    "kodacolor": ("kodacolor",),
    "hors-cote": ("hors-cote",),
    "avant-propos": ("avant-propos",),
    "tjäle": ("tjäle",),
    "garde-côtière": ("garde-côtière",),
    "archal": ("archal",),
    "quatre-vingt": ("quatre-vingt",),
    "quasi-homonyme": ("quasi-homonyme",),
    "menstrue": ("menstrue",),
    "prochain": ("prochain",),
    "knock-down": ("knock-down",),
    "oreille-de-chèvre": ("oreille-de-chèvre",),
    "gaélique": ("gaélique",),
    "porte-aéronefs": ("porte-aéronefs",),
    "lèse-majesté": ("lèse-majesté",),
    "ballet-pantomime": ("ballet-pantomime",),
    "garde-manger": ("garde-manger",),
    "tout-terrain": ("tout-terrain",),
    "paranormal": ("paranormal",),
    "presse-purée": ("presse-purée",),
    "chez-moi": ("chez-moi",),
    "thrombicula": ("thrombicula",),
    "jôruri": ("jôruri",),
    "débotter": ("débotter",),
    "plain-chant": ("plain-chant",),
    "lutécium": ("lutécium",),
    "canne-siège": ("canne-siège",),
    "ostpolitik": ("ostpolitik",),
    "ramasse-plis": ("ramasse-plis",),
    "tobogganing": ("tobogganing",),
    "cramé": ("cramé",),
    "gâte-métier": ("gâte-métier",),
    "aquagym": ("aquagym",),
    "kalisme": ("kalisme",),
    "hors-marché": ("hors-marché",),
    "avant-bras": ("avant-bras",),
    "sous-productivité": ("sous-productivité",),
    "sous-acquéreur": ("sous-acquéreur",),
    "arrière-radier": ("arrière-radier",),
    "flora": ("flora",),
    "ballet-théâtre": ("ballet-théâtre",),
    "oméga-complétude": ("oméga-complétude",),
    "demi-pause": ("demi-pause",),
    "nomenklatura": ("nomenklatura",),
    "puszta": ("puszta",),
    "yang": ("yang",),
    "garçon-boucher": ("garçon-boucher",),
    "fer-blanc": ("fer-blanc",),
    "palper": ("palper",),
    "passe-lacet": ("passe-lacet",),
    "pet-de-nonne": ("pet-de-nonne",),
    "mi-chaussette": ("mi-chaussette",),
    "théoricon": ("théoricon",),
    "khamti": ("khamti",),
    "vice-sénéchal": ("vice-sénéchal",),
    "avant-pied": ("avant-pied",),
    "grande-chartreuse": ("grande-chartreuse",),
    "troy": ("troy",),
    "abat-foin": ("abat-foin",),
    "dharma": ("dharma",),
    "garde-vue": ("garde-vue",),
    "premier-mai": ("premier-mai",),
    "gastro-colite": ("gastro-colite",),
    "demi-brique": ("demi-brique",),
    "tout-puissant": ("tout-puissant",),
    "mah-jong": ("mah-jong",),
    "water-drive": ("water-drive",),
    "sous-main": ("sous-main",),
    "sous-fifre": ("sous-fifre",),
    "tire-lire": ("tire-lire",),
    "porte-mains": ("porte-mains",),
    "navire-atelier": ("navire-atelier",),
    "oto-rhino-laryngologiste": ("oto-rhino-laryngologiste",),
    "saut-de-mouton": ("saut-de-mouton",),
    "neptunium": ("neptunium",),
    "essuie-tout": ("essuie-tout",),
    "area": ("area",),
    "mètre-semaine": ("mètre-semaine",),
    "shadow-boxing": ("shadow-boxing",),
    "taille-buissons": ("taille-buissons",),
    "mandat-contribution": ("mandat-contribution",),
    "diesel-électrique": ("diesel-électrique",),
    "ice-boat": ("ice-boat",),
    "saint-sulpicien": ("saint-sulpicien",),
    "bien-dire": ("bien-dire",),
    "brise-balle": ("brise-balle",),
    "columbium": ("columbium",),
    "ost": ("ost",),
    "bismuth": ("bismuth",),
    "serre-papiers": ("serre-papiers",),
    "néohébreu": ("néohébreu",),
    "narquois": ("narquois",),
    "hard-core": ("hard-core",),
    "semi-centrifugation": ("semi-centrifugation",),
    "garde-feu": ("garde-feu",),
    "vice-royauté": ("vice-royauté",),
    "hépato-entérostomie": ("hépato-entérostomie",),
    "pillow-lava": ("pillow-lava",),
    "iode": ("iode",),
    "chirurgien-dentiste": ("chirurgien-dentiste",),
    "radium": ("radium",),
    "haute-vienne": ("haute-vienne",),
    "madourais": ("madourais",),
    "sainte-maure": ("sainte-maure",),
    "étrusque": ("étrusque",),
    "saint-bernard": ("saint-bernard",),
    "non-agression": ("non-agression",),
    "sous-intendant": ("sous-intendant",),
    "milady": ("milady",),
    "mini-aciérie": ("mini-aciérie",),
    "lave-linge": ("lave-linge",),
    "pèse-vin": ("pèse-vin",),
    "porte-allumettes": ("porte-allumettes",),
    "matérielle": ("matérielle",),
    "emporte-pièce": ("emporte-pièce",),
    "sous-fermier": ("sous-fermier",),
    "pas-de-porte": ("pas-de-porte",),
    "nuoc-mâm": ("nuoc-mâm",),
    "non-entendant": ("non-entendant",),
    "würm": ("würm",),
    "phosphore": ("phosphore",),
    "sous-triple": ("sous-triple",),
    "bichlamar": ("bichlamar",),
    "heur": ("heur",),
    "porte-mesure": ("porte-mesure",),
    "imprécis": ("imprécis",),
    "est": ("est",),
    "oumma": ("oumma",),
    "panchen-lama": ("panchen-lama",),
    "double-caponnière": ("double-caponnière",),
    "arrière-bief": ("arrière-bief",),
    "saint-pourcin": ("saint-pourcin",),
    "hausse-queue": ("hausse-queue",),
    "tête-de-chat": ("tête-de-chat",),
    "gros-bout": ("gros-bout",),
    "serre-frein": ("serre-frein",),
    "arrache-moyeu": ("arrache-moyeu",),
    "haute-garonne": ("haute-garonne",),
    "self-induction": ("self-induction",),
    "sur-mesure": ("sur-mesure",),
    "pèse-nitre": ("pèse-nitre",),
    "cache-cache": ("cache-cache",),
    "pince-sans-rire": ("pince-sans-rire",),
    "arrière-corps": ("arrière-corps",),
    "traîne-sabre": ("traîne-sabre",),
    "bercail": ("bercail",),
    "euclide": ("euclide",),
    "filtre-bouchon": ("filtre-bouchon",),
    "hache-sarments": ("hache-sarments",),
    "cinéscope": ("cinéscope",),
    "porte-monnaie": ("porte-monnaie",),
    "ille-et-vilaine": ("ille-et-vilaine",),
    "saint-péray": ("saint-péray",),
    "pousse-fiche": ("pousse-fiche",),
    "porte-étendard": ("porte-étendard",),
    "rince-bouteilles": ("rince-bouteilles",),
    "prie-dieu": ("prie-dieu",),
    "gros-plant": ("gros-plant",),
    "golde": ("golde",),
    "tallöl": ("tallöl",),
    "judéo-christianisme": ("judéo-christianisme",),
    "gentleman-cambrioleur": ("gentleman-cambrioleur",),
    "tout-paris": ("tout-paris",),
    "hélium": ("hélium",),
    "sans-soin": ("sans-soin",),
    "terre-à-terre": ("terre-à-terre",),
    "agnella": ("agnella",),
    "réveille-matin": ("réveille-matin",),
    "porte-pelle": ("porte-pelle",),
    "cash": ("cash",),
    "cache-platine": ("cache-platine",),
    "mini-golf": ("mini-golf",),
    "praséodyme": ("praséodyme",),
    "zaghaoua": ("zaghaoua",),
    "éolien": ("éolien",),
    "hydro-injecteur": ("hydro-injecteur",),
    "melaena": ("melaena",),
    "laisser-aller": ("laisser-aller",),
    "madonna": ("madonna",),
    "couche-tard": ("couche-tard",),
    "tohu-bohu": ("tohu-bohu",),
    "tétras-lyre": ("tétras-lyre",),
    "rami": ("rami",),
    "porte-pincettes": ("porte-pincettes",),
    "sous-affrètement": ("sous-affrètement",),
    "porte-cierge": ("porte-cierge",),
    "porte-éponge": ("porte-éponge",),
    "lawn-tennis": ("lawn-tennis",),
    "chauffe-eau": ("chauffe-eau",),
    "demi-succès": ("demi-succès",),
    "anarcho-syndicaliste": ("anarcho-syndicaliste",),
    "après-demain": ("après-demain",),
    "petit-lait": ("petit-lait",),
    "bon-chrétien": ("bon-chrétien",),
    "demi-glace": ("demi-glace",),
    "roumiya": ("roumiya",),
    "telougou": ("telougou",),
    "trachée-artère": ("trachée-artère",),
    "presse-étoupe": ("presse-étoupe",),
    "surmoi": ("surmoi",),
    "contre-effet": ("contre-effet",),
    "contre-partie": ("contre-partie",),
    "juge-consul": ("juge-consul",),
    "porte-verge": ("porte-verge",),
    "porte-lunettes": ("porte-lunettes",),
    "banlon": ("banlon",),
    "pince-nez": ("pince-nez",),
    "surplace": ("surplace",),
    "oïl": ("oïl",),
    "champagne-ardenne": ("champagne-ardenne",),
    "pathétique": ("pathétique",),
    "cadeau-surprise": ("cadeau-surprise",),
    "vice-reine": ("vice-reine",),
    "viêt-minh": ("viêt-minh",),
    "offshore": ("offshore",),
    "afro-asiatisme": ("afro-asiatisme",),
    "brigadier-chef": ("brigadier-chef",),
    "ph-métrie": ("ph-métrie",),
    "coffre-fort": ("coffre-fort",),
    "larme-du-christ": ("larme-du-christ",),
    "country-music": ("country-music",),
    "fbi": ("fbi",),
    "néo-impressionnisme": ("néo-impressionnisme",),
    "saint-pierre": ("saint-pierre",),
    "palma-christi": ("palma-christi",),
    "edge": ("edge",),
    "echo": ("echo",),
    "carbon": ("carbon",),
    "bébé-éprouvette": ("bébé-éprouvette",),
    "sex-appeal": ("sex-appeal",),
    "demi-porte": ("demi-porte",),
    "nu-pieds": ("nu-pieds",),
    "clivus": ("clivus",),
    "coupe-gorge": ("coupe-gorge",),
    "box-calf": ("box-calf",),
    "sud-est": ("sud-est",),
    "porte-couronne": ("porte-couronne",),
    "porte-entonnoir": ("porte-entonnoir",),
    "gemara": ("gemara",),
    "couvre-selle": ("couvre-selle",),
    "sex-ratio": ("sex-ratio",),
    "cache-entrée": ("cache-entrée",),
    "belle-doche": ("belle-doche",),
    "poisson-lanterne": ("poisson-lanterne",),
    "pli-faille": ("pli-faille",),
    "demi-bec": ("demi-bec",),
    "coupe-cercle": ("coupe-cercle",),
    "ekiri": ("ekiri",),
    "ranci": ("ranci",),
    "huyghe": ("huyghe",),
    "pas-d'âne": ("pas-d'âne",),
    "porte-flambeau": ("porte-flambeau",),
    "pehlevi": ("pehlevi",),
    "arrière-scène": ("arrière-scène",),
    "lord-lieutenance": ("lord-lieutenance",),
    "sit-in": ("sit-in",),
    "gold-point": ("gold-point",),
    "mange-mil": ("mange-mil",),
    "papy-boom": ("papy-boom",),
    "non-discrimination": ("non-discrimination",),
    "mille-trous": ("mille-trous",),
    "porte-clefs": ("porte-clefs",),
    "lance-grenades-sous-marines": ("lance-grenades-sous-marines",),
    "descente-homme": ("descente-homme",),
    "concret": ("concret",),
    "asahi": ("asahi",),
    "script-girl": ("script-girl",),
    "avant-souper": ("avant-souper",),
    "oreille-de-rat": ("oreille-de-rat",),
    "white-spirit": ("white-spirit",),
    "angelus": ("angelus",),
    "tiers-mondisme": ("tiers-mondisme",),
    "macro-zoom": ("macro-zoom",),
    "facteur-chance": ("facteur-chance",),
    "feuille-morte": ("feuille-morte",),
    "ougaritique": ("ougaritique",),
    "au-delà": ("au-delà",),
    "sec": ("sec",),
    "saint-estèphe": ("saint-estèphe",),
    "ecce-homo": ("ecce-homo",),
    "entre-deux": ("entre-deux",),
    "orientale": ("orientale",),
    "walk-over": ("walk-over",),
    "demi-arrêt": ("demi-arrêt",),
    "chaland-citerne": ("chaland-citerne",),
    "hors-sol": ("hors-sol",),
    "porte-fenêtre": ("porte-fenêtre",),
    "stock-option": ("stock-option",),
    "stato-fusée": ("stato-fusée",),
    "tritium": ("tritium",),
    "seine-et-marne": ("seine-et-marne",),
    "globe-trotter": ("globe-trotter",),
    "guide-coke": ("guide-coke",),
    "netéconomie": ("netéconomie",),
    "porte-chaise": ("porte-chaise",),
    "vice-versa": ("vice-versa",),
    "sous-dominante": ("sous-dominante",),
    "fisher": ("fisher",),
    "natrum": ("natrum",),
    "passe-billot": ("passe-billot",),
    "sous-commissaire": ("sous-commissaire",),
    "demi-ronde": ("demi-ronde",),
    "trade-unionisme": ("trade-unionisme",),
    "perce-neige": ("perce-neige",),
    "demi-sel": ("demi-sel",),
    "double-torsion": ("double-torsion",),
    "non-rétroactivité": ("non-rétroactivité",),
    "basse-fosse": ("basse-fosse",),
    "broche-queue": ("broche-queue",),
    "girl-friend": ("girl-friend",),
    "porte-bride": ("porte-bride",),
    "improviste": ("improviste",),
    "oeil-de-boeuf": ("oeil-de-boeuf",),
    "étrange": ("étrange",),
    "judéo-chrétien": ("judéo-chrétien",),
    "panier-repas": ("panier-repas",),
    "morvandiau": ("morvandiau",),
    "free-martinisme": ("free-martinisme",),
    "guide-fil": ("guide-fil",),
    "moteur-canon": ("moteur-canon",),
    "procolis": ("procolis",),
    "halaka": ("halaka",),
    "fixe-serviette": ("fixe-serviette",),
    "kodachrome": ("kodachrome",),
    "shéol": ("shéol",),
    "garde-française": ("garde-française",),
    "anglo-américain": ("anglo-américain",),
    "sous-stade": ("sous-stade",),
    "semi-groupe": ("semi-groupe",),
    "dopamine": ("dopamine",),
    "poll-tax": ("poll-tax",),
    "thallium": ("thallium",),
    "fusée-détonateur": ("fusée-détonateur",),
    "lock-out": ("lock-out",),
    "tranche-tête": ("tranche-tête",),
    "avant-mur": ("avant-mur",),
    "osmium": ("osmium",),
    "assurance-invalidité": ("assurance-invalidité",),
    "socrate": ("socrate",),
    "porte-tampon": ("porte-tampon",),
    "tantra": ("tantra",),
    "langue-de-cerf": ("langue-de-cerf",),
    "social": ("social",),
    "sous-tangente": ("sous-tangente",),
    "porte-bagages": ("porte-bagages",),
    "brumaire": ("brumaire",),
    "paraître": ("paraître",),
    "batterie-tampon": ("batterie-tampon",),
    "non-valeur": ("non-valeur",),
    "prochaine": ("prochaine",),
    "micro-trottoir": ("micro-trottoir",),
    "reine-claude": ("reine-claude",),
    "éventuel": ("éventuel",),
    "repose-pied": ("repose-pied",),
    "élémental": ("élémental",),
    "demi-livre": ("demi-livre",),
    "crayon-lèvre": ("crayon-lèvre",),
    "divin": ("divin",),
    "guanche": ("guanche",),
    "toutim": ("toutim",),
    "irréel": ("irréel",),
    "lance-roquettes": ("lance-roquettes",),
    "demi-décime": ("demi-décime",),
    "etats-généraux": ("etats-généraux",),
    "antistreptokinase": ("antistreptokinase",),
    "dom": ("dom",),
    "canoë-kayak": ("canoë-kayak",),
    "live": ("live",),
    "sim": ("sim",),
    "ourdou": ("ourdou",),
    "fox-hound": ("fox-hound",),
    "coupe-bourse": ("coupe-bourse",),
    "saint-simonisme": ("saint-simonisme",),
    "lance-engins": ("lance-engins",),
    "paso-doble": ("paso-doble",),
    "bêta-test": ("bêta-test",),
    "yeshiva": ("yeshiva",),
    "quatre-heures": ("quatre-heures",),
    "sanskrit": ("sanskrit",),
    "trois-huit": ("trois-huit",),
    "rhénium": ("rhénium",),
    "sans-gêne": ("sans-gêne",),
    "fest-noz": ("fest-noz",),
    "merlot": ("merlot",),
    "pirandello": ("pirandello",),
    "austro-asiatique": ("austro-asiatique",),
    "avant-toit": ("avant-toit",),
    "hand-balleur": ("hand-balleur",),
    "courte-lettre": ("courte-lettre",),
    "king's": ("king's",),
    "chapeau-cloche": ("chapeau-cloche",),
    "chaise-lit": ("chaise-lit",),
    "alsace-lorraine": ("alsace-lorraine",),
    "timbre-taxe": ("timbre-taxe",),
    "publi-information": ("publi-information",),
    "porte-maillot": ("porte-maillot",),
    "instar": ("instar",),
    "guerdon": ("guerdon",),
    "binns": ("binns",),
    "passe-sauce": ("passe-sauce",),
    "parthe": ("parthe",),
    "grill-room": ("grill-room",),
    "fla-fla": ("fla-fla",),
    "pense-bête": ("pense-bête",),
    "papier-cul": ("papier-cul",),
    "punching-ball": ("punching-ball",),
    "panjabi": ("panjabi",),
    "taille-légumes": ("taille-légumes",),
    "natrium": ("natrium",),
    "fourre-tout": ("fourre-tout",),
    "porte-pieds": ("porte-pieds",),
    "semi-grossiste": ("semi-grossiste",),
    "hippocrate": ("hippocrate",),
    "hand-ball": ("hand-ball",),
    "non-satisfaction": ("non-satisfaction",),
    "serre-vêtements": ("serre-vêtements",),
    "entre-deux-guerres": ("entre-deux-guerres",),
    "suffisant": ("suffisant",),
    "cabinet-conseil": ("cabinet-conseil",),
    "demi-castor": ("demi-castor",),
    "athéna": ("athéna",),
    "non-utilisation": ("non-utilisation",),
    "mansi": ("mansi",),
    "proto-industrialisation": ("proto-industrialisation",),
    "haute-fidélité": ("haute-fidélité",),
    "court-circuit": ("court-circuit",),
    "demi-normale": ("demi-normale",),
    "tellure": ("tellure",),
    "star-system": ("star-system",),
    "after-shave": ("after-shave",),
    "tourne-oreille": ("tourne-oreille",),
    "coq-à-l'âne": ("coq-à-l'âne",),
    "pare-cendres": ("pare-cendres",),
    "tifinagh": ("tifinagh",),
    "demi-douaire": ("demi-douaire",),
    "beau-papa": ("beau-papa",),
    "schopenhauer": ("schopenhauer",),
    "pomme-cannelle": ("pomme-cannelle",),
    "pehlvi": ("pehlvi",),
    "après-shampooing": ("après-shampooing",),
    "semi-coke": ("semi-coke",),
    "en-but": ("en-but",),
    "helios": ("helios",),
    "quasi-certitude": ("quasi-certitude",),
    "trop-perçu": ("trop-perçu",),
    "point-virgule": ("point-virgule",),
    "skinn-effect": ("skinn-effect",),
    "porte-chapeau": ("porte-chapeau",),
    "traîne-buisson": ("traîne-buisson",),
    "samarium": ("samarium",),
    "porte-dîner": ("porte-dîner",),
    "oiseau-serpent": ("oiseau-serpent",),
    "staline": ("staline",),
    "aquaboxing": ("aquaboxing",),
    "moyen-métrage": ("moyen-métrage",),
    "tout-petit": ("tout-petit",),
    "coupe-sifflet": ("coupe-sifflet",),
    "après-match": ("après-match",),
    "inexplicable": ("inexplicable",),
    "attache-lettre": ("attache-lettre",),
    "aquabuilding": ("aquabuilding",),
    "sénatus-consulte": ("sénatus-consulte",),
    "calcium": ("calcium",),
    "intrapreneurship": ("intrapreneurship",),
    "sleeping-car": ("sleeping-car",),
    "va-et-vient": ("va-et-vient",),
    "compte-gouttes": ("compte-gouttes",),
    "lemon-grass": ("lemon-grass",),
    "porte-dieu": ("porte-dieu",),
    "tagada": ("tagada",),
    "périsélène": ("périsélène",),
    "stand-by": ("stand-by",),
    "double-fenêtre": ("double-fenêtre",),
    "presse-papiers": ("presse-papiers",),
    "casse-croûte": ("casse-croûte",),
    "homme-robot": ("homme-robot",),
    "homme-dieu": ("homme-dieu",),
    "hard-top": ("hard-top",),
    "divine": ("divine",),
    "rail-route": ("rail-route",),
    "aide-ménagère": ("aide-ménagère",),
    "couvre-chef": ("couvre-chef",),
    "lave-pieds": ("lave-pieds",),
    "bec-cueilleur": ("bec-cueilleur",),
    "demi-orange": ("demi-orange",),
    "rétique": ("rétique",),
    "séance-marathon": ("séance-marathon",),
    "rederico ": ("rederico ",),
    "caesium": ("caesium",),
    "ceinture-piège": ("ceinture-piège",),
    "sous-chevron": ("sous-chevron",),
    "jobelin": ("jobelin",),
    "étonnant": ("étonnant",),
    "lawrencium": ("lawrencium",),
    "mi-bas": ("mi-bas",),
    "pahlavi": ("pahlavi",),
    "avant-veille": ("avant-veille",),
    "bow-string": ("bow-string",),
    "mât-tour": ("mât-tour",),
    "indo-germanique": ("indo-germanique",),
    "intifada": ("intifada",),
    "major-général": ("major-général",),
    "bateau-balise": ("bateau-balise",),
    "non-événement": ("non-événement",),
    "halakha": ("halakha",),
    "subjectif": ("subjectif",),
    "craps": ("craps",),
    "ogham": ("ogham",),
    "casse-cul": ("casse-cul",),
    "étolien": ("étolien",),
    "après-concile": ("après-concile",),
    "tinea": ("tinea",),
    "jin-seng": ("jin-seng",),
    "cnrs": ("cnrs",),
    "agui": ("agui",),
    "hakka": ("hakka",),
    "boxer-short": ("boxer-short",),
    "jomon": ("jomon",),
    "gâte-cuir": ("gâte-cuir",),
    "radio-iode": ("radio-iode",),
    "laisser-faire": ("laisser-faire",),
    "tressalier": ("tressalier",),
    "arrête-boeuf": ("arrête-boeuf",),
    "néo-hébridais": ("néo-hébridais",),
    "ex-recordman": ("ex-recordman",),
    "protège-mine": ("protège-mine",),
    "éditique": ("éditique",),
    "in-octavo": ("in-octavo",),
    "court-jus": ("court-jus",),
    "auber": ("auber",),
    "capital-risque": ("capital-risque",),
    "khoisan": ("khoisan",),
    "porte-graine": ("porte-graine",),
    "shoah": ("shoah",),
    "étouffe-chrétien": ("étouffe-chrétien",),
    "dysprosium": ("dysprosium",),
    "sainte-trinité": ("sainte-trinité",),
    "torche-pot": ("torche-pot",),
    "mesure-choc": ("mesure-choc",),
    "régnié": ("régnié",),
    "tv": ("tv",),
    "semi-peigné": ("semi-peigné",),
    "blaid": ("blaid",),
    "porte-cure-dents": ("porte-cure-dents",),
    "medium": ("medium",),
    "tire-lait": ("tire-lait",),
    "coupe-ficelle": ("coupe-ficelle",),
    "jiu-jitsu": ("jiu-jitsu",),
    "grand-oncle": ("grand-oncle",),
    "thrombo-élastogramme": ("thrombo-élastogramme",),
    "porte-queue": ("porte-queue",),
    "judéo-allemand": ("judéo-allemand",),
    "débotté": ("débotté",),
    "iléo-colite": ("iléo-colite",),
    "habdala": ("habdala",),
    "sang-dragon": ("sang-dragon",),
    "sapeur-mineur": ("sapeur-mineur",),
    "brise-mottes": ("brise-mottes",),
    "plat-pont": ("plat-pont",),
    "rajasthani": ("rajasthani",),
    "cric-crac": ("cric-crac",),
    "vulgum-pecus": ("vulgum-pecus",),
    "plus-bas": ("plus-bas",),
    "vanadium": ("vanadium",),
    "micro-irrigation": ("micro-irrigation",),
    "hale-haut": ("hale-haut",),
    "porte-stylo": ("porte-stylo",),
    "boy-scoutisme": ("boy-scoutisme",),
    "free-jazz": ("free-jazz",),
    "orang-outan": ("orang-outan",),
    "presse-citron": ("presse-citron",),
    "révérend-père": ("révérend-père",),
    "vide-pomme": ("vide-pomme",),
    "toute-science": ("toute-science",),
    "thanatos": ("thanatos",),
    "traîne-lattes": ("traîne-lattes",),
    "grécale": ("grécale",),
    "timbre-amende": ("timbre-amende",),
    "cul-de-poule": ("cul-de-poule",),
    "porte-avions": ("porte-avions",),
    "aurantium": ("aurantium",),
    "brise-glace": ("brise-glace",),
    "ponant": ("ponant",),
    "gratte-ciel": ("gratte-ciel",),
    "perlimpinpin": ("perlimpinpin",),
    "fructidor": ("fructidor",),
    "poisson-entonnoir": ("poisson-entonnoir",),
    "lance-bombes": ("lance-bombes",),
    "coupe-foin": ("coupe-foin",),
    "boeuf-mode": ("boeuf-mode",),
    "cadmium": ("cadmium",),
    "holmium": ("holmium",),
    "plastoche": ("plastoche",),
    "haute-volta": ("haute-volta",),
    "pied-de-corneille": ("pied-de-corneille",),
    "fume-cigarette": ("fume-cigarette",),
    "européenne": ("européenne",),
    "sous-pull": ("sous-pull",),
    "sous-refroidisseur": ("sous-refroidisseur",),
    "haute-taille": ("haute-taille",),
    "gastro-entérite": ("gastro-entérite",),
    "new-look": ("new-look",),
    "teuf-teuf": ("teuf-teuf",),
    "batman": ("batman",),
    "arrière-monde": ("arrière-monde",),
    "marie-antoinette": ("marie-antoinette",),
    "contre-pouvoir": ("contre-pouvoir",),
    "lumpenproletaria": ("lumpenproletaria",),
    "eskuara": ("eskuara",),
    "contre-offensive": ("contre-offensive",),
    "florentine": ("florentine",),
    "mondaine": ("mondaine",),
    "tâte-poule": ("tâte-poule",),
    "pêle-mêle": ("pêle-mêle",),
    "beaumarchais": ("beaumarchais",),
    "terlenka": ("terlenka",),
    "dent-de-lion": ("dent-de-lion",),
    "appui-nuque": ("appui-nuque",),
    "faux-filet": ("faux-filet",),
    "câble-chaîne": ("câble-chaîne",),
    "morte-eau": ("morte-eau",),
    "aquaelicium": ("aquaelicium",),
    "halley": ("halley",),
    "arrière-cavité": ("arrière-cavité",),
    "saint-siège": ("saint-siège",),
    "grand-guignol": ("grand-guignol",),
    "duffle-coat": ("duffle-coat",),
    "couvre-joint": ("couvre-joint",),
    "non-délivrance": ("non-délivrance",),
    "cha-cha-cha": ("cha-cha-cha",),
    "carbone": ("carbone",),
    "aristote": ("aristote",),
    "pète-sec": ("pète-sec",),
    "black-bottom": ("black-bottom",),
    "broncho-pneumonie": ("broncho-pneumonie",),
    "pseudo-adiabatique": ("pseudo-adiabatique",),
    "roman-fleuve": ("roman-fleuve",),
    "trois-quarts": ("trois-quarts",),
    "realpolitik": ("realpolitik",),
    "quatre-saisons": ("quatre-saisons",),
    "sous-arbrisseau": ("sous-arbrisseau",),
    "zef": ("zef",),
    "plutonium": ("plutonium",),
    "bouton-boule": ("bouton-boule",),
    "septimontium": ("septimontium",),
    "contre-culture": ("contre-culture",),
    "ecstasy": ("ecstasy",),
    "tranche-gazon": ("tranche-gazon",),
    "protège-boulet": ("protège-boulet",),
    "porte-arquebuse": ("porte-arquebuse",),
    "demi-groupe": ("demi-groupe",),
    "haute-autorité": ("haute-autorité",),
    "insu": ("insu",),
    "compte-fils": ("compte-fils",),
    "chouchoute": ("chouchoute",),
    "savoir-vivre": ("savoir-vivre",),
    "serre-bosse": ("serre-bosse",),
    "pousse-wagon": ("pousse-wagon",),
    "garde-à-vous": ("garde-à-vous",),
    "henri": ("henri",),
    "sans-souci": ("sans-souci",),
    "arrière-petite-fille": ("arrière-petite-fille",),
    "tout-à-l'égout": ("tout-à-l'égout",),
    "strech": ("strech",),
    "tambour-major": ("tambour-major",),
    "avant-noël": ("avant-noël",),
    "voiture-salon": ("voiture-salon",),
    "serre-bauquière": ("serre-bauquière",),
    "trench-coat": ("trench-coat",),
    "immédiat": ("immédiat",),
    "tire-moyeu": ("tire-moyeu",),
    "croque-monsieur": ("croque-monsieur",),
    "anima": ("anima",),
    "non-jureur": ("non-jureur",),
    "passe-collet": ("passe-collet",),
    "garde-boutique": ("garde-boutique",),
    "fume-cigare": ("fume-cigare",),
    "aalénien": ("aalénien",),
    "gré": ("gré",),
    "demi-brigade": ("demi-brigade",),
    "néoperse": ("néoperse",),
    "dry-farming": ("dry-farming",),
    "manx": ("manx",),
    "saute-mouton": ("saute-mouton",),
    "bourvil": ("bourvil",),
    "anacoste": ("anacoste",),
    "pont-aux-ânes": ("pont-aux-ânes",),
    "fait-tout": ("fait-tout",),
    "bat-flanc": ("bat-flanc",),
    "nida": ("nida",),
    "lot-et-garonne": ("lot-et-garonne",),
    "sous-embranchement": ("sous-embranchement",),
    "fusée-sonde": ("fusée-sonde",),
    "nord": ("nord",),
    "fesse-maille": ("fesse-maille",),
    "porte-baïonnette": ("porte-baïonnette",),
    "garde-but": ("garde-but",),
    "boogie-woogie": ("boogie-woogie",),
    "surprise-partie": ("surprise-partie",),
    "bruges": ("bruges",),
    "einsteinium": ("einsteinium",),
    "côte-d'azur": ("côte-d'azur",),
    "cache-museau": ("cache-museau",),
    "sainte-touche": ("sainte-touche",),
    "quasimodo": ("quasimodo",),
    "entrée-sortie": ("entrée-sortie",),
    "ludien": ("ludien",),
    "cache-nez": ("cache-nez",),
    "abat-faim": ("abat-faim",),
    "face-à-face": ("face-à-face",),
    "batteur-dégraisseur": ("batteur-dégraisseur",),
    "ouï-dire": ("ouï-dire",),
    "assa-foetida": ("assa-foetida",),
    "demi-volée": ("demi-volée",),
    "porte-masse": ("porte-masse",),
    "pare-chocs": ("pare-chocs",),
    "porte-conteneurs": ("porte-conteneurs",),
    "guilledou": ("guilledou",),
    "vice-chancelier": ("vice-chancelier",),
    "nôtre": ("nôtre",),
    "protège-livre": ("protège-livre",),
    "occident": ("occident",),
    "chasse-buffle": ("chasse-buffle",),
    "foire-exposition": ("foire-exposition",),
    "territoriale": ("territoriale",),
    "gratte-pieds": ("gratte-pieds",),
    "sous-régime": ("sous-régime",),
    "yé-yé": ("yé-yé",),
    "micro-instruction": ("micro-instruction",),
    "élève-caporal": ("élève-caporal",),
    "spotting": ("spotting",),
    "allocation-logement": ("allocation-logement",),
    "coupe-tranche": ("coupe-tranche",),
    "dom-tom": ("dom-tom",),
    "stochasticité": ("stochasticité",),
    "drive-in": ("drive-in",),
    "brise-coeur": ("brise-coeur",),
    "quasi-totalité": ("quasi-totalité",),
    "arrière-fief": ("arrière-fief",),
    "sweat-shirt": ("sweat-shirt",),
    "ile-de-france": ("ile-de-france",),
    "cant": ("cant",),
    "sous-couche": ("sous-couche",),
    "franc-jeu": ("franc-jeu",),
    "médecin-lieutenant": ("médecin-lieutenant",),
    "roi-pontife": ("roi-pontife",),
    "reine-mère": ("reine-mère",),
    "venture-capital": ("venture-capital",),
    "cui-cui": ("cui-cui",),
    "trois-pièces": ("trois-pièces",),
    "koumys": ("koumys",),
    "chauffe-bécher": ("chauffe-bécher",),
    "traîne-charrue": ("traîne-charrue",),
    "gagne-pain": ("gagne-pain",),
    "lance-flammes": ("lance-flammes",),
    "schiedam": ("schiedam",),
    "porte-bât": ("porte-bât",),
    "magnésium": ("magnésium",),
    "bar-mitsva": ("bar-mitsva",),
    "demi-corde": ("demi-corde",),
    "stéréo-isomérie": ("stéréo-isomérie",),
    "harauti": ("harauti",),
    "jurassique": ("jurassique",),
    "bien-être": ("bien-être",),
    "germanium": ("germanium",),
    "permo-trias": ("permo-trias",),
    "alcoran": ("alcoran",),
    "coufique": ("coufique",),
    "pèse-jus": ("pèse-jus",),
    "grand-ville": ("grand-ville",),
    "pareille": ("pareille",),
    "arrière-front": ("arrière-front",),
    "poisson-savon": ("poisson-savon",),
    "bas-rhin": ("bas-rhin",),
    "èbe": ("èbe",),
    "tantôt": ("tantôt",),
    "grappa": ("grappa",),
    "tardiglaciaire": ("tardiglaciaire",),
    "pochette-surprise": ("pochette-surprise",),
    "coluche": ("coluche",),
    "comprenette": ("comprenette",),
    "entre-deux-eaux": ("entre-deux-eaux",),
    "gin-rami": ("gin-rami",),
    "web": ("web",),
    "non-comparution": ("non-comparution",),
    "demi-couronne": ("demi-couronne",),
    "bottier-chausseur": ("bottier-chausseur",),
    "happe-bourse": ("happe-bourse",),
    "jazz-band": ("jazz-band",),
    "mieux-disant": ("mieux-disant",),
    "perce-bouchon": ("perce-bouchon",),
    "après-vente": ("après-vente",),
    "hard": ("hard",),
    "perce-membrane": ("perce-membrane",),
    "chaud-froid": ("chaud-froid",),
    "arrache-étai": ("arrache-étai",),
    "contre-espionnage": ("contre-espionnage",),
    "divan-coffre": ("divan-coffre",),
    "malleomyces": ("malleomyces",),
    "tire-fesses": ("tire-fesses",),
    "contre-feu": ("contre-feu",),
    "rabiot": ("rabiot",),
    "marie-louise": ("marie-louise",),
    "surf-casting": ("surf-casting",),
    "rose-croix": ("rose-croix",),
    "cocoon": ("cocoon",),
    "iléo-transversostomie": ("iléo-transversostomie",),
    "rhéto-roman": ("rhéto-roman",),
    "deux-pièces": ("deux-pièces",),
    "struma": ("struma",),
    "avant-guerre": ("avant-guerre",),
    "handling": ("handling",),
    "vôtre": ("vôtre",),
    "sans-logis": ("sans-logis",),
    "brise-béton": ("brise-béton",),
    "bluff": ("bluff",),
    "tourne-disque": ("tourne-disque",),
    "bacchus": ("bacchus",),
    "dépannage-remorquage": ("dépannage-remorquage",),
    "sous-oeuvre": ("sous-oeuvre",),
    "chrome-nickel": ("chrome-nickel",),
    "ouvre-manchettes": ("ouvre-manchettes",),
    "barrage-gravité": ("barrage-gravité",),
    "désennui": ("désennui",),
    "menuse": ("menuse",),
    "café-théâtre": ("café-théâtre",),
    "porte-haillons": ("porte-haillons",),
    "non-spécialiste": ("non-spécialiste",),
    "rab": ("rab",),
    "cache-misère": ("cache-misère",)
}
